/*******************************************************************************
 Gera scripts de criaao das tabelas

 Chamada: m4 -Ddb=banco este_arquivo > arq_saida
					banco = oracle|mssql|firebird|pgsql|mysql|db2

 Usar as seguintes definicoes de campo:
 varchar(n)   - String de comprimento variavel
 char(n)      - String de comprimento fixo
 integer      - Numero inteiro (ate 10 digitos)
 decimal(t,d) - Numero decimal de tamanho t com d casas decimais
 date         - Data/Hora
 float        - Numero de ponto flutuante
 text         - Texto livre
 blob         - Blob binario                  

 Para criar sequencias:
 sequence(nome_da_sequencia);
 
 include(db.m4)
*******************************************************************************/

/**
 * Sequencias
 */
sequence(nw_acs_seq);
sequence(nw_acs_sub_seq);
sequence(nw_fix_seq);
sequence(nw_mnu_seq);
sequence(nw_jobs_seq);
sequence(nw_jobs_log_seq);
sequence(nw_msgs_seq);
sequence(nw_tarefas_seq);
sequence(nw_audt_seq);

/**
 * Tabelas
 */

/**
 * Controle de Acesso
 */
create table nw_acs (
		aplic  varchar(30) not null,
		bloco  varchar(30) not null,
		usr    varchar(20),
		id     integer not null,
		constraint nw_acs_pk primary key (aplic, id)
) __opc;

/**
 * Aplicativo
 */
create table nw_apl (
		aplic      varchar(30) not null,
		titulo     varchar(100),
		autor      varchar(100),
		copyr      varchar(100),
		keyw       varchar(100),
		descricao  varchar(100),
		estilo     varchar(30),
		mensagem   varchar(30),
		rodape     varchar(30),
		cabec      varchar(30),
		constraint nw_apl_pk primary key (aplic)
) __opc;


/**
 * Estilos
 */
create table nw_etl (
		estilo     varchar(30) not null,
		descricao  varchar(100) not null,
		constraint nw_etl_pk primary key (estilo)
) __opc;


/**
 * Blocos fixos nas paginas
 */
create table nw_fix (
		aplic  varchar(30) not null,
		id     integer not null,
		aba    integer not null,
		cln    integer not null,
		seq    integer not null,
		bloco  varchar(30) not null,
		constraint nw_fix_pk primary key (aplic, id),
		constraint nw_fix_uk1 unique (aplic, aba, cln, seq)
) __opc;


/**
 * Grupos de usuarios
 */
create table nw_grp (
		grupo      varchar(20) not null,
		descricao  varchar(100) not null,
		constraint nw_grp_pk primary key (grupo)
) __opc;


/**
 * Relacao usuarios x grupos
 */
create table nw_mbr (
		usr    varchar(20) not null,
		grupo  varchar(20) not null,
		constraint nw_mbr_pk  primary key (usr, grupo)
) __opc;


/**
 * Itens de menu
 */
create table nw_mnu (
		aplic      varchar(30) not null,
		id         integer not null check (id > 0),
		texto      varchar(200) not null,
		destino    varchar(200),
		pai        integer,
		descricao  varchar(100),
		bloco      varchar(30),
		cln        integer,
		seq        integer,
		sta        integer,
		col0       varchar(100),
		col1       varchar(100),
		col2       varchar(100),
		col3       varchar(100),
		col4       varchar(100),
		targ       varchar(30),
		img        varchar(100),
		imgx       varchar(100),
		modulo     varchar(100),
		ordem      integer,
		constraint nw_mnu_pk primary key (aplic, id)
) __opc;


/**
 * Controle de sessoes
 */
create table nw_sess (
		sesskey    varchar(32) not null,
		expiry     integer not null,
		expireref  varchar(64),
		sessdata   text,
		constraint nw_sess_pk primary key (sesskey)
) __opc;


/**
 * Usuarios
 */
create table nw_usr (
		usr       varchar(20) not null,
		nome      varchar(100) not null,
		senha     varchar(100) not null,
		adm       integer not null check (adm in (0,1)),
		email     varchar(100),
		uex       integer not null check (uex in (0,1)),
		bloq      integer not null check (bloq in (0,1)),
		xsen      date,
		nerr      integer,
		ulog      date,
		sec       integer not null check (sec in (0,1)),
		constraint nw_usr_pk primary key (usr)
) __opc;


/**
 * Historico de senhas
 */
create table nw_usr_sen (
		usr       varchar(20) not null,
		senha     varchar(100) not null,
		data      date,
		constraint nw_usr_sen_pk primary key (usr,senha)
) __opc;


/**
 * Parametros gerais do sistema
 */
create table nw_param (
		id_param   varchar(10) not null,
		descricao  varchar(100) not null,
		valor      varchar(4000),
		constraint nw_param_pk primary key (id_param)
) __opc;

/**
 * Jobs
 */
create table nw_jobs (
		id_job     integer not null,
		descricao  varchar(100) not null,
		comando    varchar(100) not null,
		prx        date,
		interv     integer not null,
		unid       char(1) not null check (unid in ('S','M','H')),
		stat       integer not null check (stat in (0,1)),
		constraint nw_jobs_pk primary key (id_job)
) __opc;

/**
 * Logs de Jobs
 */
create table nw_jobs_log (
		id_job    integer not null,
		id_log    integer not null,
		msg       varchar(200) not null,
		constraint nw_jobs_log_pk primary key (id_job,id_log)
) __opc;

/**
 * Correio interno
 */
create table nw_msgs (
		id_msg    integer not null,
		id_usr    varchar(20) not null,
		id_rem    varchar(20) not null,
		dt_msg    date not null,
		assunto   varchar(100),
		mensagem  text,
		dt_envio  date,
		evento    varchar(100),
		constraint nw_msgs_pk primary key (id_msg)
) __opc;

/**
 * Tarefas 
 */
create table nw_tarefas (
		id_usr    varchar(20) not null,
		id_tar    integer not null,
		dt_tar    date not null,
		hora      varchar(5),
		descricao varchar(4000),
		id_sit    integer not null check(id_sit in (0,1,2)),
		email     integer not null check(email in (0,1)),
		ds_ant    integer,
		hr_ant    integer,
		constraint nw_tarefas_pk primary key (id_usr, id_tar)
) __opc;

/**
 * Auditoria
 */
create table nw_audt (
		aplic    varchar(30) not null,
		id_aud   integer not null,
		dt_aud   date not null,
		usr_aud  varchar(20) not null,
		id_mnu   integer,
		oper     varchar(1000),
		refer    text,
		ip       varchar(20),
		adm      integer not null check (adm in (0,1)),
		bloco    varchar(30),
		constraint nw_audt_pk primary key (aplic, id_aud)
) __opc;

/**
 * Parametros para Auditoria de menus
 */
create table nw_mnu_aud (
		aplic    varchar(30) not null,
		id       integer not null,
		usr      varchar(20),
		constraint nw_mnu_aud_pk primary key (aplic, id, usr)
) __opc;

/**
 * Parametros para Auditoria de menus
 */
create table nw_mnu_mdl (
		aplic     varchar(30) not null,
		id        integer not null,
		mdl       varchar(30) not null,
		descricao varchar(100),
		constraint nw_mnu_mdl_pk primary key (aplic, id, mdl)
) __opc;

/**
 * Parametros para Auditoria geral
 */
create table nw_acs_aud (
		aplic    varchar(30) not null,
		opr      integer not null check (opr in (0,1)),
		usr      varchar(20),
		constraint nw_acs_aud_pk primary key (aplic, opr, usr)
) __opc;

/**
 * Controle de Acesso por subfuncao
 */
create table nw_acs_sub (
		aplic  varchar(30) not null,
		bloco  varchar(30) not null,
		sub    integer not null,
		func   varchar(30) not null,
		usr    varchar(20),
		constraint nw_acs_sub_pk primary key (aplic, bloco, sub)
) __opc;

/**
 * Usuarios por empresas
 */
create table nw_usr_emp (
    usr    varchar(20) not null,
    emp    integer not null,
    adm    integer not null check (adm in (0,1)),
    sec    integer not null check (sec in (0,1)),
    constraint nw_usr_emp_pk primary key (usr,emp)
) __opc;

/**
 * Grupos por empresas
 */
create table nw_grp_emp (
    grupo  varchar(20) not null,
    emp    integer not null,
    constraint nw_grp_emp_pk primary key (grupo,emp)
) __opc;


/**
 * Indices
 */

create index nw_msgs_ak1 on nw_msgs (dt_envio);
create index nw_mbr_ak1 on nw_mbr (grupo,usr);
create index nw_audt_ak1 on nw_audt (aplic, dt_aud);
create index nw_audt_ak2 on nw_audt (aplic, usr_aud);

/**
 * Views
 */
create view v_nw_user(codigo, tipo, nome) as
select usr as codigo, 'U' as tipo, nome from nw_usr
union all
select grupo as codigo, 'G' as tipo, descricao as nome from nw_grp;

create view v_nw_grupos(codigo, tipo, nome) as
select 'PUBLIC' as codigo, 'G' as tipo, 'PUBLIC - Qualquer usurio autenticado' as nome from rdb$database
union all
select 'ANON' as codigo, 'G' as tipo, 'ANON - Usurios no autenticados' as nome from rdb$database
union all
select null as codigo, 'G' as tipo, 'Nulo - Acesso livre'as nome from rdb$database
union all
select usr as codigo, 'U' as tipo, nome from nw_usr
union all
select grupo as codigo, 'G' as tipo, descricao as nome from nw_grp;

