<?php
/**
 * Manutencao de parametros de auditoria
 *
 * @author Gonalo Franco
 * @version $Id: nw_ace.php 366 2005-04-27 18:46:11Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_acs_aud_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $stmt = "select * from nw_acs_aud where aplic = ? and opr = ? and usr = ?";
    $db = nwx_db::conexao();
    if ($this->inicio()) {
      $rs = $db->execute($stmt, $this->id);
      if (!$rs->EOF) {
        $this->valor('aplic',$rs->fields['aplic']);
        $this->valor('opr',$rs->fields['opr']);
        $this->valor('usr',$rs->fields['usr']);
      }
    }
  }

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function prepara() {

    $db = nwx_db::conexao();
    $oper = $this->oper;
    $ic = nwx_qico('nw_acs_aud');
    $st = nwx_qsta('nw_acs_aud');
    
    switch ($oper) {

    case 'Relatrio' :
      $this->reset_opr();
      $u = $rs->fields['id_uni'];
      header("Location: " . NWX_RDX . NWX_LOC . "?blc=nw_audt_rel&col=1&seq=10&sta=$st&ico=$ic");
      break;

    case 'Registros' :
      $this->reset_opr();
      $u = $rs->fields['id_uni'];
      header("Location: " . NWX_RDX . NWX_LOC . "?blc=nw_audt_reg&col=1&seq=10&sta=$st&ico=$ic");
      break;
    
    }
    
    return true;
  }

  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $p = nwx_qval('nw_acs_aud');
    $pai = $p['p0'];
    $db = nwx_db::conexao();
    
    $rb = $db->execute("select bloco from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pai));
    $bloco = $rb->fields['bloco'];
    
    if ($this->oper == 'Incluir') {
      $stm = "insert into nw_acs_aud values(?,?,?)";
      $p = array(NWX_SIS
                ,$this->post('opr')
                ,strtoupper($this->post('usr'))
      );
      $this->sair = false;
    } elseif ($this->oper == 'Excluir') {
      $stm = "delete from nw_acs_aud where aplic = ? and opr = ? and usr = ?";
      $p = $this->id;
      $this->sair = true;
    } else {
      $this->sair = true;
      return;       
    }

    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$db->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    }
    else {
      nwx_repaginar();
    }
    nwx_db::audita($this->oper, $this->bloco, $p);
    nwx_db::end_trans();
  }

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_acs_aud extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _("Parmetros de Auditoria");
    $this->fixo = 0;

  } //__construct

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $db = nwx_db::conexao();
    $aplic = NWX_SIS;
    
    // Objeto grid
    $grid = new nwx_grid($this,"select * from nw_acs_aud","aplic = '$aplic'",'aplic,opr,usr');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('opr',  _('Operao'), 'C')
                         ,array('usr',  _('Usurio'),   'C')
                         );

    // Array de formatos para coluna de grupo
    $oper = array('0 - Conexes','1 - Manutenes');
    $priv = array('PUBLIC' => 'Todos os usurios'
                 );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('opr',  _('Operao'), '15%','E','N',$oper)
                          ,array('usr',  _('Usurio'), '85%','E','C',$priv)
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('aplic','opr','usr');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_acs_aud_form("nw_acs_aud_form","nw_acs_aud");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f1 = new nwx_form_lista('opr',   'N', 10,0,false,false);
    $f2 = new nwx_form_text('usr',   'C', 20,0,false,false);

    $f1->opcoes = $oper;
    
    $f2->display("select nome from v_nw_grupos where codigo = ?", 'nome', 'size="80"');
    // LOV para campo reponsavel
    $lov = new nwx_lov($this->id,'Usurios','select * from v_nw_grupos',"codigo is not null and codigo <> 'ANON'",'codigo');
    $lov->filtro = array(array('codigo', 'Cdigo', 'C'),
                         array('tipo',   'U/G',    'C'),
                         array('nome',   'Nome',   'C')
                        );
    $lov->colunas = array(array('codigo', 'Cdigo', '20%','E','C',''),
                          array('tipo',   'U/G',    '5%','C','C',''),
                          array('nome',   'Nome',   '75%','E','C','')
                         );
    $lov->pk = 'codigo';
    $lov->linhas = 8;
    $lov->height = 300;
    $f2->lov = $lov;
    
    $f1->ajuda = _('Tipo de operao a que se refere');
    $f2->ajuda = _('Usurio ou grupo a auditar');
    
    $form->input($f1,_('Operao'),  '','',true);
    $form->input($f2,_('Usurio/Grupo'),  '','size="15"',false);

    $ro = $_SESSION['nwx_sec'] ? false : true;
    
    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    if (!$ro) {
      $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                          'Excluir' => array(_('Excluir'),$form,true,false),
                          'Registros' => array(_('Registros'),$form,true,false),
                          'Relatrio' => array(_('Relatrio'),$form,true,false)
                         );
    } else {
      $grid->oper = array('Registros' => array(_('Registros'),$form,true,false),
                          'Relatrio' => array(_('Relatrio'),$form,true,false)
                         );
    }
    // Mostra o grid na pagina
    $grid->mostra($this);
  }

}
// vim:et:sw=2:ts=2:nowrap