<?php
/**
 * COnsulta registros de auditoria
 *
 * @author Gonalo Franco
 * @version $Id$
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_audt_reg_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $stmt = "select a.*, b.texto as menu from nw_audt a 
               left join nw_mnu b on (a.aplic = b.aplic and a.id_mnu = b.id)
             where a.aplic = ? and a.id_aud = ?";
    $db = nwx_db::conexao();
    if ($this->inicio()) {
      $rs = $db->execute($stmt, $this->id);
      if (!$rs->EOF) {
        $this->valor('aplic',$rs->fields['aplic']);
        $this->valor('id_aud',$rs->fields['id_aud']);
        $this->valor('dt_aud',$rs->fields['dt_aud']);
        $this->valor('usr_aud',$rs->fields['usr_aud']);
        $this->valor('id_mnu',$rs->fields['id_mnu']);
        $this->valor('oper',$rs->fields['oper']);
        $this->valor('refer',$rs->fields['refer']);
        $this->valor('ip',$rs->fields['ip']);
        $this->valor('adm',$rs->fields['adm']);
        $this->valor('bloco',$rs->fields['bloco']);
        $this->valor('menu',$rs->fields['menu']);
      }
    }
  }

  /**
   * Processamento do formulario
   */
  function processa($_sair) {

  }

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_audt_reg extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _("Registros de Auditoria");
    $this->fixo = 0;

  } //__construct

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $db = nwx_db::conexao();
    $aplic = NWX_SIS;
    
    // Objeto grid
    $grid = new nwx_grid($this,"select a.*, b.texto as menu 
                                  from nw_audt a
                                  left join nw_mnu b on (a.aplic = b.aplic and a.id_mnu = b.id)",
                                  "a.aplic = '$aplic'",'a.dt_aud');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('a.id_aud',  _('Numero'),    'N')
                         ,array('a.dt_aud',  _('Data/Hora'), 'D')
                         ,array('a.usr_aud', _('Usurio'),   'C')
                         ,array('a.oper',    _('Operao'),  'C')
                         ,array('a.bloco',   _('Mdulo'),    'C')
                         ,array('a.ip',      _('IP'),        'C')
                         ,array('b.texto',    _('Menu'),      'C')
                         );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('id_aud',  _('Nmero'),    '8%','E','N','','a.id_aud')
                          ,array('dt_aud',  _('Data/Hora'), '12%','E','D','%d/%m/%Y %H:%M','a.dt_aud')
                          ,array('usr_aud', _('Usurio'),   '15%','E','C','','a.usr_aud')
                          ,array('oper',    _('Operao'),  '20%','E','C','','a.oper')
                          ,array('menu',    _('Menu'),      '20%','E','C','','b.texto')
                          ,array('bloco',   _('Mdulo'),    '15%','E','C','','a.bloco')
                          ,array('ip',      _('IP'),         '10%','E','C','','a.ip')
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('aplic','id_aud');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_audt_reg_form("nw_audt_reg_form","nw_audt_reg");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f0 = new nwx_form_text('dt_aud',   'T', 15,0,false,false);
    $f1 = new nwx_form_text('id_aud',   'N', 10,0,false,false);
    $f2 = new nwx_form_text('usr_aud',   'C', 20,0,false,false);
    $f3 = new nwx_form_text('menu',      'C', 100,0,false,false);
    $f4 = new nwx_form_text('oper',      'C', 100,0,false,false);
    $f5 = new nwx_form_textarea('refer',  'C', 32000,0,false,false);
    $f6 = new nwx_form_text('ip',        'C', 20,0,false,false);
    $f7 = new nwx_form_check('adm',      'N', 10,0,false,false);
    $f8 = new nwx_form_text('bloco',     'C', 30,0,false,false);

    $form->tab("tab1",_("Registro"));
    $form->tab("tab2",_("Detalhes"));
    
    $f5->linhas = 10;
    $f2->display("select usr, nome from nw_usr where usr = ?", 'nome', 'size="80"');
    
    $form->input($f1,_('Numero'),    '','size="10"',false);
    $form->input($f0,_('Data/Hora'), '','size="15"',true);

    $form->input_tab('tab1', $f2, _('Usurio'), '','size="15"',true);
    $form->input_tab('tab1', $f3, _('Menu'), '','size="80"',true);
    $form->input_tab('tab1', $f4, _('Operao'), '','size="80"',true);
    $form->input_tab('tab1', $f8, _('Mdulo'), '','size="20"',false);
    $form->input_tab('tab1', $f6, _('Endereo IP'), '','size="20"',false);
    $form->input_tab('tab1', $f7, _('Administrador'), '','',true);
    
    $form->input_tab('tab2', $f5, _('Detalhes do registro'), '','',true);
    
    
    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    $grid->oper = array('Consultar' => array(_('Consultar'),$form,true,false)
                       );

    // Mostra o grid na pagina
    $grid->mostra($this);
  }

}
// vim:et:sw=2:ts=2:nowrap
