<?php
/**
 * Manutencao da tabela de privilegios de acesso
 *
 * @author Gonalo Franco
 * @version $Id: nw_ace.php 366 2005-04-27 18:46:11Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_blo_ace_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $stmt = "select * from nw_acs where aplic = ? and id = ?";
    $DB = nwx_db::conexao();
    if ($this->inicio()) {
      $rs = $DB->execute($stmt, array(NWX_SIS, $this->id[0]));
      if (!$rs->EOF) {
        $this->valor('bloco',$rs->fields['bloco']);
        $this->valor('usr',$rs->fields['usr']);
      }
    }
  }

  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $p = nwx_qval('nw_blo_ace');
    $bloco = $p['b'];
    $DB = nwx_db::conexao();
    
    if ($this->oper == 'Alterar') {
      $stm = "update nw_acs set usr = ? where aplic = ? and id = ?";
      $p = array($this->post('usr')
                ,NWX_SIS
                ,$this->id[0]
      );
      $this->sair = $_sair;
    } elseif ($this->oper == 'Incluir') {
      $stm = "insert into nw_acs(aplic,id,bloco,usr) values(?,?,?,?)";
      $p = array(NWX_SIS
                ,$DB->GenID('nw_acs_seq')
                ,$bloco
                ,$this->post('usr')
      );
      $this->sair = false;
    } elseif ($this->oper == 'Excluir') {
      $stm = "delete from nw_acs where aplic = ? and id = ?";
      $p = array(NWX_SIS, $this->id[0]);
      $this->sair = true;
    } else {
      $this->sair = true;
      return;       
    }

    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$DB->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    }
    else {
      nwx_repaginar();
    }
    nwx_db::end_trans();
  }

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_blo_ace extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _("Permisses de Acesso");
    $this->fixo = 0;

  } //__construct

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $DB = nwx_db::conexao();
    $aplic = NWX_SIS;
    $p = nwx_qval('nw_blo_ace');
    $bloco = $p['b'];
    
    // Objeto grid
    $grid = new nwx_grid($this,"select * from nw_acs","aplic = '$aplic' and bloco = '$bloco'",'usr');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('usr',    'Acesso', 'C')
                         );

    // Array de formatos para coluna de grupo
    $priv = array('PUBLIC' => _('PUBLIC - Qualquer usurio autenticado'),
                  'ANON' => _('ANON - Usurios no autenticados'),
                  '' => _('Nulo - Acesso livre')
                 );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('usr', _('Acessos'), '100%','E','C',$priv)
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('id');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_blo_ace_form("nw_blo_ace_form","nw_blo_ace");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f2 = new nwx_form_lista('usr',   'C', 20,0,true,false);
    $f2->opcoes = array(""       => _("Nulo - Acesso livre"),
                        "PUBLIC" => _("PUBLIC - Qualquer usurio autenticado"),
                        "ANON"   => _("ANON - Usurios no autenticados")
                       );

    $c1 = $DB->concat("grupo","' (G) - '");
    $c1 = $DB->concat($c1, "descricao");
    $c2 = $DB->concat("usr","' (U) - '");
    $c2 = $DB->concat($c2,"nome");
    $sql = "select grupo, $c1 as descricao from nw_grp union all " .
           "select usr as grupo, $c2 as descricao from nw_usr";
    $f2->query = $sql;
    
    $f2->ajuda = _('Usurio ou grupo a quem atribuir acesso');
    
    $form->input($f2,_('Acesso'),  '','size="1"',false);

    $grid->mensagem = _("Mdulo").": $bloco";
    $form->mensagem = _("Mdulo").": $bloco";
    
    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                        'Alterar' => array(_('Alterar'),$form,false,false),
                        'Excluir' => array(_('Excluir'),$form,true,false)
                       );

    // Mostra o grid na pagina
    $grid->mostra($this);
  }

}
// vim:et:sw=2:ts=2:nowrap
