<?php
/**
 * Manutencao da tabela de grupos
 *
 * @author Gonalo Franco
 * @version $Id: nw_grp.php 884 2006-12-09 14:56:22Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_grp_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $stmt = "select * from nw_grp where grupo = ?";
    $db = nwx_db::conexao();
    if ($this->inicio()) {
      $rs = $db->execute($stmt, array($this->id[0]));
      if (!$rs->EOF) {
        $this->valor('grupo',$rs->fields['grupo']);
        $this->valor('descricao',$rs->fields['descricao']);
        $this->valor('membros',$rs->fields['grupo']);
      }
    }
  }

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function prepara() {

    $db = nwx_db::conexao();
    $oper = $this->oper;
    $ic = nwx_qico('nw_grp');
    $st = nwx_qsta('nw_grp');
    
    switch ($oper) {

    case 'Mapa' :
      $this->reset_opr();
      $u = $rs->fields['id_uni'];
      header("Location: " . NWX_RDX . NWX_LOC . "?blc=nw_grp_map&col=1&seq=10&sta=2&ico=$ic");
      break;

    }
    
    return true;
  }
  
  /**
   * Verifica se entradas corretas
   */
  function verifica() {
    
    $db = nwx_db::conexao();
    if ($this->oper == 'Incluir') {
      $id_grupo = strtoupper($this->post('grupo'));
      $rs = $db->execute('select * from nw_grp where grupo=?', array($id_grupo));
      if (!$rs->EOF) {
        $this->erro(_('Grupo j existe com este cdigo em alguma empresa'));
      }
    }
  }
  
  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $db = nwx_db::conexao();
    if ($this->oper == 'Alterar') {
      $id_grupo = $this->id[0];
      $stm = "update nw_grp set descricao = ? where grupo = ?";
      $p = array($this->post('descricao')
                ,$id_grupo
      );
      $this->sair = $_sair;
    }
    elseif ($this->oper == 'Incluir') {
      $id_grupo = strtoupper($this->post('grupo'));
      $stm = "insert into nw_grp(grupo,descricao) values(?,?)";
      $p = array($id_grupo
                ,$this->post('descricao')
      );
      $this->sair = false;
    }
    elseif ($this->oper == 'Excluir') {
      $id_grupo = $this->id[0];
      $stm = "delete from nw_grp where grupo = ?";
      $p = array($this->id[0]);
      $this->sair = true;
    } else {
      $this->sair = false;
      return;
    }

    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$db->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    } else {
      if (NWX_EMPRESAS) {
        if ($this->oper == 'Incluir') {
          $db->execute("insert into nw_grp_emp values (?,?)", array($p[0], $_SESSION['nwx_emp']));  
        }
      }
      // Verifica se tem grupos do usuario a acertar
      $stm = "delete from nw_mbr where grupo = ?";
      $db->execute($stm, array($id_grupo));
      $lst = $this->post('membros_lst');
      if (!empty($lst)) {
        $sep = substr($lst,0,1);
        $grp = explode($sep,substr($lst,1));
        if (is_array($grp) && count($grp) > 0) {
          foreach ($grp as $g) {
            $stm = "insert into nw_mbr(grupo,usr) values (?,?)";
            $db->execute($stm, array($id_grupo, $g));
          }
        }
      }
      nwx_repaginar();
    }
    nwx_db::audita($this->oper, $this->bloco, $p);
    nwx_db::end_trans();
    
  }

} // class nw_grp_form

class nw_grp_form2 extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {
    $this->valor('origem',$this->id[0]);
  }

  /**
   * Verifica se entradas corretas
   */
  function verifica() {
    if ($this->post('origem') == $this->post('destino')) {
      $this->erro(_('Perfil origem no deve ser igual ao destino'));
    }
  }
  
  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $db = nwx_db::conexao();
    $sis = NWX_SIS;
    $this->sair = true;
    if ($this->oper == 'Copiar') {
      $origem = $this->post('origem');
      $destino = $this->post('destino');
    } else {
      return;
    }
    // Processamento final no Banco de Dados
    nwx_db::begin_trans();
    $db->execute("delete from nw_acs where aplic = ? and usr = ?", array($sis, $destino));
    $rs = $db->execute("select * from nw_acs where aplic = ? and usr = ?", array($sis, $origem));     
    while (!$rs->EOF) {
      $id = $db->GenID("nw_acs_seq");
      $db->Execute("insert into nw_acs values(?,?,?,?)", array($sis,$rs->fields['bloco'],$destino,$id));
      $rs->MoveNext();
    }
    nwx_db::audita($this->oper, $this->bloco, $p);
    nwx_db::end_trans();
    
  }

} // class nw_grp_form2


/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_grp extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _("Grupos");
    $this->fixo = 0;
 
  }

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    // Objeto grid
    if (NWX_EMPRESAS) {
      $emp = $_SESSION['nwx_emp'];
      $grid = new nwx_grid($this,"select a.* from nw_grp a inner join nw_grp_emp b on (b.grupo = a.grupo and b.emp=$emp)",'','a.grupo');
    } else {
      $grid = new nwx_grid($this,'select a.* from nw_grp a','','a.grupo');
    }

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('a.grupo',     _('Grupo'), 'C'),
                          array('a.descricao', _('Descrio'), 'C')
                          );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('grupo',      _('Grupo'), '20%','E','C','','a.grupo'),
                           array('descricao',  _('Descrio'), '80%','E','C','','a.descricao')
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('grupo');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_grp_form("nw_grp_form","nw_grp");
    $form2 = new nw_grp_form2("nw_grp_form2","nw_grp");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;
    $form2->grid = $grid->nome;

    $ro = $_SESSION['nwx_sec'] ? false : true;
    
    // Cria os campos do formulario e sua representacao
    $f1 = new nwx_form_text('grupo','C',20,0,false,true);
    $f2 = new nwx_form_text('descricao','C',100,0,false,false);
    $f3 = new nwx_form_lista('membros','C',10,0,true,false);

    $db = nwx_db::conexao();
    
    $c1 = $db->concat("usr","' - '");
    $c1 = $db->concat($c1, "nome");
    $f3->query = "select usr, $c1 as descricao from nw_usr where usr in (select usr from nw_mbr where grupo = ?) order by nome";
    
    if (NWX_EMPRESAS) {
      $_e = $_SESSION['nwx_emp'];
      $sql = "select a.* from nw_usr a 
                inner join nw_usr_emp u on (a.usr = u.usr and u.emp = {$_e})";
    } else {
      $sql = 'select a.* from nw_usr a';
    }   
    
    $lov = new nwx_lov($this->id,'Usurios',$sql,'','a.usr');
    $lov->filtro = array(array('a.usr',  _('Cdigo'), 'C'),
                         array('a.nome',  _('Nome'),   'C')
                        );
    $lov->colunas = array(array('usr', _('Cdigo'), '5%','E','C','','a.usr'),
                          array('nome', _('Nome'),   '95%','E','C','','a.nome')
                         );
    $lov->pk = 'usr';
    $lov->linhas = 8;
    $lov->height = 300;
    $lov->query2 = "select usr, $c1 as descricao from nw_usr where usr = ?";
    $lov->lista = 'descricao';
    $f3->lov = $lov;
    
    $f1->ajuda = _('Cdigo que identifica o grupo (Obrigatrio)');
    $f2->ajuda = _('Descrio do grupo (Obrigatrio)');
    $f3->ajuda = _('Usurios que so membros do grupo (Pode adicionar vrios)');
    
    $form->input($f1,_('Grupo'),'','size="30"',true);
    $form->input($f2,_('Descrio'),'','size="80"',true);
    $form->input($f3,_('Membros'),'','size="5" multiple="yes"',false);

    $g1 = new nwx_form_text('origem','C',20,0,false,true);
    $g2 = new nwx_form_lista('destino','C',20,0,true,false);
    $g2->query = "select grupo, grupo || ' - ' || descricao as descricao from nw_grp order by 2";
    $form2->input($g1,_('Origem'),'','size="15"',true);
    $form2->input($g2,_('Destino'),'','size="1"',true);
    
    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    if (!$ro) {
      $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                          'Alterar' => array(_('Alterar'),$form,false,false),
                          'Excluir' => array(_('Excluir'),$form,true,false),
                          'Copiar' => array(_('Copiar Acessos'),$form2,true,false,'Copiar acessos para outro grupo/perfil'),
                          'Mapa' => array(_('Mapa de Acessos'),$form,true,false,'Mostra todos os perfis e acessos')
                         );
    } else {
      $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                          'Alterar' => array(_('Alterar'),$form,false,false),
                          'Excluir' => array(_('Excluir'),$form,true,false)
                         );
    }

    // Mostra o grid na pagina
    $grid->mostra($this);
  
  }

} // class nw_grp
// vim:et:sw=2:ts=2:nowrap
