<?php
/**
 * Login do usuario no Banco de Dados
 *
 * @file nw_login.php
 * @author Gonalo Franco
 * @version $Id: nw_login.php 924 2007-01-11 18:36:37Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");

/**
 * Define formulario para login
 *
 */
class nw_login_frm extends nwx_form {

  function carrega() {

    // Tenta ler ultima escolha de empresa do cookie
    if (isset($_COOKIE['nwx_emp'])) {
      $this->valor('empresa', $_COOKIE['nwx_emp']);
    }
    
  }
	
  function processa($_sair) {

		// Le parametros de seguranca
		$dias = nwx_param('PASS_EXP');
		$max_erros = nwx_param('MAX_ERROS');
		
		if ($dias) {
			$nxsen = nwx_time::data_iso(nwx_time::soma_dias(date(nwx_time::date_format()), $dias));
		} else {
			$nxsen = null;
		}
    
    if (NWX_EMPRESAS) {
      $empresa = $this->post('empresa');
    } else {
      $empresa = 0;
    }
		
		// Se tiver funcao extendida de login: usa-la para fazer a conexao
		if (defined('NWX_EXT_LOGIN') && NWX_EXT_LOGIN) {
			if (file_exists(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_LOGIN . ".php")) {
				include_once(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_LOGIN . ".php");
				if (function_exists('nwx_ext_login')) {
					$mensagem = '';
					$erro = nwx_ext_login($this->post('usr'), $this->post('senha'), $mensagem);
					if (!$erro) {
						if ($mensagem) $_SESSION['nwx_alr2'] = $mensagem;
						nwx_db::audita('Autenticao');
						nwx_repaginar();
					} else {
						$this->erro($mensagem);
					}
					return;
				}
			}
		}
		
		$db = nwx_db::conexao();
		if (!$db) {
			$this->erro('No h conexo ao Banco de Dados');
			return;
		}
		
		$stm = "select * from nw_usr where usr = ?";
		$usr = strtoupper($this->post('usr'));
		$rs = $db->execute($stm, array(strtoupper($usr)));
		$nerr = $rs->fields['nerr'] ? $rs->fields['nerr'] : 0;
		$erro = 0;
    $emp_adm = 0;
    $emp_sec = 0;
		$_SESSION['nwx_ulog'] = $rs->fields['ulog'] ? nwx_time::datetime_db($rs->fields['ulog']) : '';
		if (!$rs) {
			$this->erro($db->errormsg());
		} else if ($rs->EOF) {
			$this->erro(_("Usurio, senha ou autenticao invlidos"));
		} else if ($rs->fields['bloq']) {
			$this->erro(_("Usurio foi bloqueado"));
		} else {
      if (!$rs->fields['adm'] && NWX_EMPRESAS) {
        $rs2 = $db->execute("select * from nw_usr_emp where usr=? and emp=?", array(strtoupper($usr), $empresa));
        if (!$rs2 || $rs2->EOF){
          $this->erro(_("Usurio no acessa esta empresa"));
          return;
        }
        $emp_adm = $rs2->fields['adm'];
        $emp_sec = $rs2->fields['sec'];
      }
			// Autenticacao interna
			if ($rs->fields['uex']) {
				$uex = 1;
				// Login: senha expirou
				if (nwx_xsen($usr)) {
					$erro = 2;
					$_SESSION['nwx_xsen'] = 1;
				} else if ($rs->fields['senha'] != md5($this->post('senha'))) {
					$erro = 1;
				}
			// Autenticacao por LDAP
			} else {
				$uex = 0;
				$dcontrol = '';
				$dominio = '';
				if (defined('NWX_DOMINIO'))
					$dominio = NWX_DOMINIO;
				if (defined('NWX_DOMCONTROL'))
					$dcontrol = NWX_DOMCONTROL;
				if (!nwx_ldap_bind($dcontrol ,$usr, $this->post('senha'), $dominio)) {
					$erro = 7;
				}
			}
			if ($erro) {
				if ($erro == 1) {
					$this->erro(_("Acesso negado"));
					if ($max_erros) {
						if ($nerr == $max_erros) {
							$db->execute("update nw_usr set bloq=1, nerr=0 where usr = ?", array($usr));
						} else { 
							++$nerr;
							$db->execute("update nw_usr set nerr=$nerr where usr = ?", array($usr));
						}
					}
				} else if ($erro == 2) {
					$this->erro(_("Senha expirou. Entrar com nova senha"));
					nwx_repaginar();
				} else if ($erro == 7) {
					$this->erro(_("Acesso negado"));
				} else if ($erro == 8) {
					$this->erro(_("Acesso negado") . ": $mensagem");
				}
			} else {  
				$db->execute("update nw_usr set nerr=0 where usr = ?", array($usr));
				session_regenerate_id(true);      
				$_SESSION['nwx_usr'] = $usr;
				$_SESSION['nwx_adm'] = $rs->fields['adm'];
				$_SESSION['nwx_sec'] = $rs->fields['sec'];
				$_SESSION['nwx_uex'] = $uex;
				$_SESSION['nwx_nom'] = $rs->fields['usr'] . ' (' .$rs->fields['nome'].')';
				$_SESSION['nwx_ini'] = date('d/m/Y H:i');
				$_SESSION['nwx_conn'] = 1;
        $_SESSION['nwx_logout'] = 0;
        $_SESSION['nwx_emp'] = $empresa;
        $_SESSION['nwx_adm2'] = $emp_adm;
        $_SESSION['nwx_sec2'] = $emp_sec;
        $_SESSION['nwx_rdx'] = NWX_RDX;
        setcookie('nwx_emp',$empresa,time()+NWX_COOKIE);
				$db->execute("update nw_usr set ulog = ? where usr = ?",array(nwx_time::current_time(), $usr));
				nwx_db::audita('Autenticao');
				nwx_repaginar();
			}
		}
	}

}

/**
 * Define quadro contendo formulario de login
 *
 */
class nw_login extends nwx_quadro {

	/**
	 * Construtor: ajusta o titulo e tipo
	 */
	function __construct($id) {
		
		parent::__construct($id);
		textdomain('nwx');
		$this->titulo = _("Autenticao");
		$this->fixo = 1;
		$this->width = '400px';
		$this->margin = '12px 0px 0px 24px';

	}

	function monta() {
		
    if (isset($_SESSION['nwx_xsen']) && $_SESSION['nwx_xsen']) {
			$alt = true;
		} else {
			$alt = false;
		}
    
    $f1 = new nwx_form_text('usr','C',20,0,false,false);
		$f2 = new nwx_form_pass('senha','C',20,0,false,false);
		
		$form = new nw_login_frm("nw_login_frm","nw_login");
		
    if (NWX_EMPRESAS) {
      $f0 = new nwx_form_lista('empresa', 'N',10,0,true,false);
      $f0->opcoes = explode(':',NWX_EMPRESAS);
      $f0->ajuda = _("Informar a empresa");
    }
		
    $f1->ajuda = _("Informar cdigo do usurio");
		$f2->ajuda = _("Informar a senha de acesso");
		
		$arq1 = NWX_HTD . DIRECTORY_SEPARATOR . "img" . DIRECTORY_SEPARATOR . NWX_SIS . '_login.png';
		
		if (file_exists($arq1))
			$arq = "/" . NWX_APL . "/img/" . NWX_SIS . "_login.png";
		else 
			$arq = "/nwx/img/nwx_login.png";  
		
		if ($alt) {
			$form->cabec = _("Senha expirou. Mude sua senha para efetuar conexo");
		} else if (isset($_SESSION['nwx_alr2']) && $_SESSION['nwx_alr2']) {
			$form->cabec = $_SESSION['nwx_alr2'];
			unset($_SESSION['nwx_alr2']);
		} else {
			$form->cabec = _("Informar seu cdigo de usurio e senha para autenticao");
		}
		
		$form->mensagem = "<img src=\"$arq\" style=\"vertical-align:middle;\" />";
		
		$form->submit = _('Conectar');
		$form->detalhe(_('Mudar Senha'),'nwx_senha_login',true);
		$form->reset = '';
		$form->cancel = '';
		$form->salvar = '';
    
    if (NWX_EMPRESAS) {
      $form->input($f0,_('Empresa'),'','size="1"',true);
    }
		
    $form->input($f1,_('Usurio'),'','size="40"',true);
		$form->input($f2,_('Senha'),'','size="40"',true);
		
		$form->mostra();
		
	}

}
// vim:et:sw=2:ts=2:nowrap