<?php
/**
 * Manutencao da tabela de privilegios de acesso
 *
 * @author Gonalo Franco
 * @version $Id: nw_ace.php 366 2005-04-27 18:46:11Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_mnu_ace_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $stmt = "select * from nw_acs where aplic = ? and id = ?";
    $DB = nwx_db::conexao();
    if ($this->inicio()) {
      $rs = $DB->execute($stmt, array($this->id[0], $this->id[1]));
      if (!$rs->EOF) {
        $this->valor('bloco',$rs->fields['bloco']);
        $this->valor('usr',$rs->fields['usr']);
      }
    }
  }

  /**
  * Verificacao dos campos para confirmacao
  */
  function verifica() {

    if ($this->oper != 'Alterar' && $this->oper != 'Incluir') return;
    
    $p = nwx_qval('nw_mnu_ace');
    $pai = $p['p0'];
    $db = nwx_db::conexao();
    
    $rb = $db->execute("select bloco from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pai));
    $bloco = $rb->fields['bloco'];
    
    if (!$bloco) {
      $this->erro(_("Incluso invlida: Mdulo no contm cdigo de bloco ( uma pasta)"));
    }
      
  }
  
  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $p = nwx_qval('nw_mnu_ace');
    $pai = $p['p0'];
    $DB = nwx_db::conexao();
    
    $rb = $DB->execute("select bloco from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pai));
    $bloco = $rb->fields['bloco'];
    
    if ($this->oper == 'Alterar') {
      $stm = "update nw_acs set usr = ? where aplic = ? and id = ?";
      $p = array(strtoupper($this->post('usr'))
                ,$this->id[0]
                ,$this->id[1]
      );
      $this->sair = $_sair;
    } elseif ($this->oper == 'Incluir') {
      $stm = "insert into nw_acs(aplic,id,bloco,usr) values(?,?,?,?)";
      $p = array(NWX_SIS
                ,$DB->GenID('nw_acs_seq')
                ,$bloco
                ,strtoupper($this->post('usr'))
      );
      $this->sair = false;
    } elseif ($this->oper == 'Excluir') {
      $stm = "delete from nw_acs where aplic = ? and id = ?";
      $p = array($this->id[0], $this->id[1]);
      $this->sair = true;
    } else {
      $this->sair = true;
      return;       
    }

    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$DB->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    }
    else {
      nwx_repaginar();
    }
    nwx_db::audita($this->oper, 'nw_pgn', $p);
    nwx_db::end_trans();
  }

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_mnu_ace extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _("Permisses de Acesso");
    $this->fixo = 0;

  } //__construct

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $DB = nwx_db::conexao();
    $aplic = NWX_SIS;
    $p = nwx_qval('nw_mnu_ace');
    $pai = $p['p0'];
    
    $rb = $DB->execute("select bloco, texto from nw_mnu where aplic = ? and id = ?", array(NWX_SIS,$pai));
    $bloco = $rb->fields['bloco'];
    $texto = $rb->fields['texto'];
    
    // Objeto grid
    $grid = new nwx_grid($this,"select * from nw_acs","aplic = '$aplic' and bloco = '$bloco'",'usr');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('usr',    'Acesso', 'C')
                         );

    // Array de formatos para coluna de grupo
    $priv = array('PUBLIC' => 'PUBLIC - Qualquer usurio autenticado',
                  'ANON' => 'ANON - Usurios no autenticados',
                  "EXT"  => "EXT - Qualquer usurio EXTERNO autenticado",
                  '' => 'Nulo - Acesso livre'
                 );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('usr',    _('Acessos'), '100%','E','C',$priv)
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('aplic','id');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_mnu_ace_form("nw_mnu_ace_form","nw_mnu_ace");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f2 = new nwx_form_text('usr',   'C', 20,0,true,false);

    if (NWX_EMPRESAS) {
      $_e = $_SESSION['nwx_emp'];
      $sql = "select a.*, u.usr as c_usr, g.grupo as c_grupo from v_nw_grupos a 
                left join nw_usr_emp u on (a.codigo = u.usr and u.emp = {$_e})
                left join nw_grp_emp g on (a.codigo = g.grupo and g.emp = {$_e})
                ";
      $w = "(u.usr is not null or g.grupo is not null or a.codigo = 'PUBLIC')";
    } else {
      $sql = 'select a.* from v_nw_grupos a';
      $w = '';
    }   
    
    $f2->display("select nome from v_nw_grupos where codigo = ?", 'nome', 'size="80"');
    // LOV para campo reponsavel
    $lov = new nwx_lov($this->id, _('Usurios'), $sql, $w, 'a.codigo');
    $lov->filtro = array(array('a.codigo', _('Cdigo'), 'C'),
                         array('a.tipo',   _('U/G'),    'C'),
                         array('a.nome',   _('Nome'),   'C')
                        );
    $lov->colunas = array(array('codigo', _('Cdigo'), '20%','E','C','','a.codigo'),
                          array('tipo',   _('U/G'),    '5%','C','C','','a.tipo'),
                          array('nome',   _('Nome'),   '75%','E','C','','a.nome')
                         );
    $lov->pk = 'codigo';
    $lov->linhas = 8;
    $lov->height = 300;
    $f2->lov = $lov;
    
    $f2->ajuda = _('Usurio ou grupo a quem atribuir acesso');
    
    $form->input($f2, _('Acesso'),  '','size="15"',false);

    $pga = nwx_qval('nw_pgn_mnu');
    $pg = $pga['p'];
    
    $rs = $DB->execute("select * from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pg));
    $pagina = $rs->fields['texto'];
    
    $grid->mensagem = _("Pgina / Item").": $pagina / $texto";
    $form->mensagem = _("Pgina / Item").": $pagina / $texto";
    
    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                        'Alterar' => array(_('Alterar'),$form,false,false),
                        'Excluir' => array(_('Excluir'),$form,true,false)
                       );

    // Mostra o grid na pagina
    $grid->mostra($this);
  }

}
// vim:et:sw=2:ts=2:nowrap