<?php
/**
 * Manutencao da tabela de auditoria por menu
 *
 * @author Gonalo Franco
 * @version $Id: nw_ace.php 366 2005-04-27 18:46:11Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_mnu_aud_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $stmt = "select * from nw_mnu_aud where aplic = ? and id = ? and usr = ?";
    $db = nwx_db::conexao();
    if ($this->inicio()) {
      $rs = $db->execute($stmt, $this->id);
      if (!$rs->EOF) {
        $this->valor('aplic',$rs->fields['aplic']);
        $this->valor('id',$rs->fields['id']);
        $this->valor('usr',$rs->fields['usr']);
      }
    }
  }

  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $p = nwx_qval('nw_mnu_aud');
    $pai = $p['p0'];
    $db = nwx_db::conexao();
    
    $rb = $db->execute("select bloco from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pai));
    $bloco = $rb->fields['bloco'];
    
    if ($this->oper == 'Incluir') {
      $stm = "insert into nw_mnu_aud values(?,?,?)";
      $p = array(NWX_SIS
                ,$pai
                ,strtoupper($this->post('usr'))
      );
      $this->sair = false;
    } elseif ($this->oper == 'Excluir') {
      $stm = "delete from nw_mnu_aud where aplic = ? and id = ? and usr = ?";
      $p = $this->id;
      $this->sair = true;
    } else {
      $this->sair = true;
      return;       
    }

    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$db->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    }
    else {
      nwx_repaginar();
    }
    nwx_db::audita($this->oper, $this->bloco, $p);
    nwx_db::end_trans();
  }

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_mnu_aud extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _("Auditoria");
    $this->fixo = 0;

  } //__construct

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $db = nwx_db::conexao();
    $aplic = NWX_SIS;
    $p = nwx_qval('nw_mnu_aud');
    $pai = $p['p0'];
    
    $rb = $db->execute("select bloco, texto from nw_mnu where aplic = ? and id = ?", array(NWX_SIS,$pai));
    $bloco = $rb->fields['bloco'];
    $texto = $rb->fields['texto'];
    
    // Objeto grid
    $grid = new nwx_grid($this,"select * from nw_mnu_aud","aplic = '$aplic' and id = $pai",'usr');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('usr',  'Usurio', 'C')
                         );

    // Array de formatos para coluna de grupo
    $priv = array('PUBLIC' => 'Todos os usurios',
                 );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('usr',  _('Usurio'), '100%','E','C',$priv)
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('aplic','id','usr');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_mnu_aud_form("nw_mnu_aud_form","nw_mnu_aud");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f2 = new nwx_form_text('usr',   'C', 20,0,true,false);

    $f2->display("select nome from v_nw_grupos where codigo = ?", 'nome', 'size="80"');
    // LOV para campo reponsavel
    $lov = new nwx_lov($this->id,'Usurios','select * from v_nw_grupos',"codigo is not null and codigo <> 'ANON'",'codigo');
    $lov->filtro = array(array('codigo', _('Cdigo'), 'C'),
                         array('tipo',   _('U/G'),    'C'),
                         array('nome',   _('Nome'),   'C')
                        );
    $lov->colunas = array(array('codigo', _('Cdigo'), '20%','E','C',''),
                          array('tipo',   _('U/G'),    '5%','C','C',''),
                          array('nome',   _('Nome'),   '75%','E','C','')
                         );
    $lov->pk = 'codigo';
    $lov->linhas = 8;
    $lov->height = 300;
    $f2->lov = $lov;
    
    $f2->ajuda = _('Usurio ou grupo a auditar');
    
    $form->input($f2, _('Usurio/Grupo'),  '','size="15"',false);

    $pga = nwx_qval('nw_pgn_mnu');
    $pg = $pga['p'];
    
    $rs = $db->execute("select * from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pg));
    $pagina = $rs->fields['texto'];
    
    $grid->mensagem = _("Pgina / Item").": $pagina / $texto";
    $form->mensagem = _("Pgina / Item").": $pagina / $texto";
    
    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                        'Excluir' => array(_('Excluir'),$form,true,false)
                       );

    // Mostra o grid na pagina
    $grid->mostra($this);
  }

}
// vim:et:sw=2:ts=2:nowrap