<?php
/**
 * Manutencao da tabela de modulos por menu
 *
 * @author Gonalo Franco
 * @version $Id$
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_mnu_aud_form extends nwx_form {

	/**
	 * Carrega dados do BD nos campos do formulario
	 */
	function carrega() {

		if ($this->oper == 'Incluir')
			return null;
		$stmt = "select * from nw_mnu_mdl where aplic = ? and id = ? and mdl = ?";
		$db = nwx_db::conexao();
		if ($this->inicio()) {
			$rs = $db->execute($stmt, $this->id);
			if (!$rs->EOF) {
				$this->valor('aplic',$rs->fields['aplic']);
				$this->valor('id',$rs->fields['id']);
				$this->valor('mdl',$rs->fields['mdl']);
				$this->valor('descricao',$rs->fields['descricao']);
			}
		}
	}

	/**
	 * Processamento do formulario
	 */
	function processa($_sair) {

		$p = nwx_qval('nw_mnu_mdl');
		$pai = $p['p0'];
		$db = nwx_db::conexao();
		
		if ($this->oper == 'Incluir') {
			$stm = "insert into nw_mnu_mdl values(?,?,?,?)";
			$p = array(NWX_SIS
								,$pai
								,$this->post('mdl')
								,$this->post('descricao')
								);
			$this->sair = false;
		} else if ($this->oper == 'Alterar') {
			$stm = "update nw_mnu_mdl set descricao = ? where aplic = ? and id = ? and mdl = ?";
			$p = array($this->post('descricao')
								,$this->id[0]
								,$this->id[1]
								,$this->id[2]
								);
			$this->sair = true;
		} else if ($this->oper == 'Excluir') {
			$stm = "delete from nw_mnu_mdl where aplic = ? and id = ? and mdl = ?";
			$p = $this->id;
			$this->sair = true;
		} else {
			$this->sair = true;
			return;       
		}

		// Processamento final no Banco de Dados
		// Se houver erro mostra mensagem do Banco na area de mensagens
		nwx_db::begin_trans();
		if (!$db->execute($stm, $p)) {
			$this->sair = false;
			$this->erro(nwx_db::erro());
			nwx_db::fail_trans();
		}
		else {
			nwx_repaginar();
		}
		nwx_db::audita($this->oper, $this->bloco, $p);
		nwx_db::end_trans();
	}

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_mnu_mdl extends nwx_quadro {

	/**
	 * Construtor: ajusta o titulo e tipo
	 */
	function __construct($id) {
		
		textdomain('nwx');
		parent::__construct($id);
		$this->titulo = _("Mdulos adicionais");
		$this->fixo = 0;

	} //__construct

	/**
	 * Monta o conteudo do quadro
	 */
	function monta() {

		$db = nwx_db::conexao();
		$aplic = NWX_SIS;
		$p = nwx_qval('nw_mnu_mdl');
		$pai = $p['p0'];
		
		$rb = $db->execute("select texto from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $pai));
		$pagina = $rb->fields['texto'];
		
		// Objeto grid
		$grid = new nwx_grid($this,"select * from nw_mnu_mdl","aplic = '$aplic' and id = $pai", 'mdl');

		// Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
		$grid->filtro = array(array('mdl',  'Mdulo', 'C')
												 ,array('descricao',  'Descrio', 'C')
												 );

		// Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
		$grid->colunas = array(array('mdl',        _('Mdulo'), '20%','E','C','')
													,array('descricao',  _('Descrio'), '80%','E','C','')
													);

		// Nome da coluna que identifica a linha
		$grid->pk = array('aplic', 'id', 'mdl');

		// Numero de linhas por pagina
		$grid->linhas(10,18);

		// Cria o formulario para processamento do registros
		$form = new nw_mnu_aud_form("nw_mnu_mdl_form","nw_mnu_mdl");

		// Guarda o nome do grid internamente no formulario
		$form->grid = $grid->nome;

		// Cria os campos do formulario e sua representacao
		$f1 = new nwx_form_text('mdl',       'C', 30,0, false, true);
		$f2 = new nwx_form_text('descricao', 'C', 100,0, false, false);

		$f1->ajuda = _('Nome do arquivo do mdulo sem extenso');
		$f2->ajuda = _('Descrio do mdulo');
		
		$form->input($f1, _('Mdulo'),   '','size="30"',true);
		$form->input($f2, _('Descrio'),'','size="80"',false);

		$pga = nwx_qval('nw_pgn_mnu');
		$pg = $pga['p'];
		
		$grid->mensagem = _("Pgina / Item").": $pagina";
		$form->mensagem = _("Pgina / Item").": $pagina";
		
		// Cria os botoes para funcoes do grid
		// Array indexado pelo label do botao, contendo :
		// (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
		$grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
												'Alterar' => array(_('Alterar'),$form,false,false),
												'Excluir' => array(_('Excluir'),$form,true,false)
											 );

		// Mostra o grid na pagina
		$grid->mostra($this);
	}

}
// vim:et:sw=2:ts=2:nowrap