<?php
/**
 * Manutencao da tabela de funcoes por menu
 *
 * @author Gonalo Franco
 * @version $Id$
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de grupos
 */
class nw_mnu_sub_form extends nwx_form {

	/**
	 * Carrega dados do BD nos campos do formulario
	 */
	function carrega() {

		if ($this->oper == 'Incluir')
			return null;
		$stmt = "select * from nw_acs_sub where aplic = ? and bloco = ? and sub = ?";
		$db = nwx_db::conexao();
		if ($this->inicio()) {
			$rs = $db->execute($stmt, $this->id);
			if (!$rs->EOF) {
				$this->valor('aplic',$rs->fields['aplic']);
				$this->valor('bloco',$rs->fields['bloco']);
				$this->valor('sub',$rs->fields['sub']);
				$this->valor('func',$rs->fields['func']);
				$this->valor('usr',$rs->fields['usr']);
			}
		}
	}

	/**
	 * Processamento do formulario
	 */
	function processa($_sair) {

		$db = nwx_db::conexao();
		
		$ida = nwx_qval('nw_pgn_mnu_det');
		$id = $ida['i'];
		$rb = $db->execute("select bloco from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $id));
		$pai = $rb->fields['bloco'];
		
		if ($this->oper == 'Incluir') {
			$sub = $db->GenId('nw_acs_sub_seq');
			$stm = "insert into nw_acs_sub values(?,?,?,?,?)";
			$p = array(NWX_SIS
								,$pai
								,$sub
								,strtoupper($this->post('func'))
								,strtoupper($this->post('usr'))
								);
			$this->sair = false;
		} else if ($this->oper == 'Alterar') {
			$stm = "update nw_acs_sub set func = ?, usr = ? where aplic = ? and bloco = ? and sub = ?";
			$p = array(strtoupper($this->post('func'))
								,strtoupper($this->post('usr'))
								,$this->id[0]
								,$this->id[1]
								,$this->id[2]
								);
			$this->sair = true;
		} else if ($this->oper == 'Excluir') {
			$stm = "delete from nw_acs_sub where aplic = ? and bloco = ? and sub = ?";
			$p = $this->id;
			$this->sair = true;
		} else {
			$this->sair = true;
			return;       
		}

		// Processamento final no Banco de Dados
		// Se houver erro mostra mensagem do Banco na area de mensagens
		nwx_db::begin_trans();
		if (!$db->execute($stm, $p)) {
			$this->sair = false;
			$this->erro(nwx_db::erro());
			nwx_db::fail_trans();
		}
		else {
			nwx_repaginar();
		}
		nwx_db::audita($this->oper, $this->bloco, $p);
		nwx_db::end_trans();
	}

}

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_mnu_sub extends nwx_quadro {

	/**
	 * Construtor: ajusta o titulo e tipo
	 */
	function __construct($id) {
		
		textdomain('nwx');
		parent::__construct($id);
		$this->titulo = _("Acesso s funes");
		$this->fixo = 0;

	} //__construct

	/**
	 * Monta o conteudo do quadro
	 */
	function monta() {

		$db = nwx_db::conexao();
		$aplic = NWX_SIS;
		
		$p = nwx_qval('nw_mnu_sub');
		$pai = $p['p0'];
		
		$ida = nwx_qval('nw_pgn_mnu_det');
		$id = $ida['i'];
		
		$rb = $db->execute("select texto,bloco from nw_mnu where aplic = ? and id = ?", array(NWX_SIS, $id));
		$pagina = $rb->fields['texto'];
		$pai = $rb->fields['bloco'];
		
		// Objeto grid
		$grid = new nwx_grid($this,"select * from nw_acs_sub","aplic = '$aplic' and bloco = '$pai'", 'func');

		// Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
		$grid->filtro = array(array('func', 'Funo', 'C')
												 ,array('usr',  'Usurio', 'C')
												 );

		// Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
		$grid->colunas = array(array('func',  _('Funo'), '20%','E','C','')
													,array('usr',   _('Usurio/Grupo'), '80%','E','C','')
													);

		// Nome da coluna que identifica a linha
		$grid->pk = array('aplic', 'bloco', 'sub');

		// Numero de linhas por pagina
		$grid->linhas(10,18);

		// Cria o formulario para processamento do registros
		$form = new nw_mnu_sub_form("nw_mnu_sub_form","nw_mnu_sub");

		// Guarda o nome do grid internamente no formulario
		$form->grid = $grid->nome;

		// Cria os campos do formulario e sua representacao
		$f1 = new nwx_form_text('func',  'C', 30,0, false, false);
		$f2 = new nwx_form_text('usr',   'C', 20,0, false, false);

		$f2->display("select nome from v_nw_grupos where codigo = ?", 'nome', 'size="80"');
		// LOV para campo reponsavel
		$lov = new nwx_lov($this->id,'Usurios','select * from v_nw_grupos',"codigo is not null and codigo <> 'ANON'",'codigo');
		$lov->filtro = array(array('codigo', _('Cdigo'), 'C'),
												 array('tipo',   _('U/G'),    'C'),
												 array('nome',   _('Nome'),   'C')
												);
		$lov->colunas = array(array('codigo', _('Cdigo'), '20%','E','C',''),
													array('tipo',   _('U/G'),    '5%','C','C',''),
													array('nome',   _('Nome'),   '75%','E','C','')
												 );
		$lov->pk = 'codigo';
		$lov->linhas = 8;
		$lov->height = 300;
		$f2->lov = $lov;
		
		$f1->ajuda = _('Texto do boto identificando a funo (em maisculas e sem acentos) ou * para todos');
		$f2->ajuda = _('Usurio ou grupo a que se refere');
		
		$form->input($f1, _('Funo'),  '','size="30"',true);
		$form->input($f2, _('Usurio'), '','size="20"',false);

		$pga = nwx_qval('nw_pgn_mnu');
		$pg = $pga['p'];
		
		$grid->mensagem = _("Pgina / Item").": $pagina";
		$form->mensagem = _("Pgina / Item").": $pagina";
		
		// Cria os botoes para funcoes do grid
		// Array indexado pelo label do botao, contendo :
		// (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
		$grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
												'Alterar' => array(_('Alterar'),$form,false,false),
												'Excluir' => array(_('Excluir'),$form,true,false)
											 );

		// Mostra o grid na pagina
		$grid->mostra($this);
	}

}
// vim:et:sw=2:ts=2:nowrap