<?php
/**
 * Mensagens internas
 *
 * @author Gonalo Franco
 * @version $Id: nw_msgs.php 810 2006-07-07 12:19:44Z suporte $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao
 */
class nw_msgs_frm extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $db = nwx_db::conexao();
    $stmt = "select * from nw_msgs where id_msg = ?";
    if ($this->inicio()) {
      $rs = $db->execute($stmt, array($this->id[0]));
      if (!$rs->EOF) {
        $this->valor('id_msg',$rs->fields['id_msg']);
        $this->valor('id_usr',$rs->fields['id_usr']);
        $this->valor('id_rem',$rs->fields['id_rem']);
        $this->valor('dt_msg',$rs->fields['dt_msg']);
        $this->valor('assunto',$rs->fields['assunto']);
        $this->valor('mensagem',$rs->fields['mensagem']);
        $this->valor('dt_envio',$rs->fields['dt_envio']);
        $this->valor('evento',$rs->fields['evento']);
      }
    }
  }

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function prepara() {

    $db = nwx_db::conexao();
    $oper = $this->oper;
    
    switch ($oper) {

    case 'Excluir Tudo' :
      $stm = "delete from nw_msgs";
      $rs = $db->execute($stm);
      nwx_db::audita($this->oper, $this->bloco);
      return false;
      break;

    }
    
    return true;
  }
  
  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $db = nwx_db::conexao();
    if ($this->oper == 'Incluir') {
      $stm = "insert into nw_msgs values(?,?,?,?,?,?,?,?)";
      $p = array($db->GenId("nw_msgs_seq")
                ,$this->post('id_usr')
                ,$_SESSION['nwx_usr']
                ,nwx_time::current_time()
                ,$this->post('assunto')
                ,$this->post('mensagem')
                ,null
                ,null
      );
      $this->sair = false;
    } elseif ($this->oper == 'Excluir') {
      $stm = "delete from nw_msgs where id_msg = ?";
      $p = array($this->id[0]);
      $this->sair = true;
    } else {
      $this->sair = true;
      return;
    }
    
    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$db->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    }
    else {
      nwx_repaginar();
    }
    nwx_db::audita($this->oper, $this->bloco, $p);
    nwx_db::end_trans();

  }

}


/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_msgs extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    textdomain('nwx');
    parent::__construct($id);
    $this->titulo = _('Mensagens').'.';
    $this->fixo = 0;
    setcookie('nwx_ul_'.$_SESSION['nwx_usr'], time(), time()+NWX_COOKIE, '/');

  }
  
  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $db = nwx_db::conexao();
    
    $sql = "select a.*, b.nome, b.email from nw_msgs a
             inner join nw_usr b on (a.id_rem = b.usr)";
    if ($_SESSION['nwx_adm'])
      $w = '';
    else
      $w = "id_usr = '" . $_SESSION['nwx_usr'] . "'" . " or id_rem = '" . $_SESSION['nwx_usr'] . "'";
    
    // Objeto grid
    $grid = new nwx_grid($this,$sql,$w,'a.dt_msg');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('id_param',  _('Parametro'),  'C'),
                          array('descricao', _('Descrio'),  'C'),
                          array('id_usr',    _('Destinatrio'),  'C'),
                          array('id_rem',    _('Remetente'),  'C')
                         );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('dt_msg',   _('Data'),         '12%','E','D','%d/%m/%Y','a.dt_msg'),
                           array('assunto',  _('Assunto'),      '46%','E','C','','a.assunto'),
                           array('id_usr',   _('Destinatrio'), '15%','E','C','','a.id_usr'),
                           array('id_rem',   _('Remetente'),    '15%','E','C','','a.id_usr'),
                           array('dt_envio', _('E-Mail'),       '12%','E','D','%d/%m/%Y','a.dt_envio')
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('id_msg');

    // Ordem descendente de data
    $grid->descend();

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_msgs_frm("nw_msgs_frm","nw_msgs");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f1 = new nwx_form_text('dt_msg', 'D',10,0,true,true);
    $f2 = new nwx_form_text('assunto','C',100,0,false,true);
    $f3 = new nwx_form_textarea('mensagem', 'C',4000,0,true,true);
    $f4 = new nwx_form_text('id_rem','C',20,0,true,true);
    $f5 = new nwx_form_lista('id_usr','C',20,0,false,true);
    $f6 = new nwx_form_text('dt_envio','T',30,0,true,true);
    $f7 = new nwx_form_text('evento','C',100,0,true,true);

    $c1 = $db->concat("usr","' - '");
    $c1 = $db->concat($c1, "nome");
    $f5->query = "select usr,$c1 from nw_usr order by nome";

    $f1->automatico = true;
    $f4->automatico = true;
    $f6->automatico = true;
    $f7->automatico = true;
    
    $f3->linhas = 10;
    $f4->display("select nome from nw_usr where usr = ?", 'nome', 'size="60"');
    //$f5->display("select nome from nw_usr where usr = '%s'", 'nome', 'size="60"');

    $form->tab("tab1",_("Mensagem"));
    $form->tab("tab2",_("Detalhes"));

    $form->input($f1,_('Data'),'','size="10"',false);
    $form->input($f2,_('Assunto'),'','size="60"',true);
    $form->input($f5,_('Destinatrio'),'','size="1"',true);
    
    $form->input_tab('tab1',$f3,_('Mensagem'),  '','',true);
    $form->input_tab('tab2',$f4,_('Remetente'),'','size="10"',true);
    $form->input_tab('tab2',$f6,_('Envio'),'','size="20"',false);
    $form->input_tab('tab2',$f7,_('Erro'),'','size="60"',true);

    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    $grid->oper = array(//'Incluir' => array(_('Incluir'),$form,false,true),
                        'Consultar' => array(_('Consultar'),$form,true,false),
                        'Excluir' => array(_('Excluir'),$form,true,false),
                        'Excluir Tudo' => array(_('Excluir Tudo'),$form,true,false,_('Excluir todas as mensagens'),_('Confirme excluso de todas as mensagens'))
                       );

    // Mostra o grid na pagina
    $grid->mostra($this);
    
  }

}
// vim:et:sw=2:ts=2:nowrap
