<?php
/**
 * Manutencao da tabela de Parametros 
 *
 * @author Gonalo Franco
 * @version $Id: nw_param.php 842 2006-10-18 20:30:53Z suporte $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao
 */
class nw_param_frm extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    if ($this->oper == 'Incluir')
      return null;
    $db = nwx_db::conexao();
    $valor = nwx_db::cast('valor');
    $stmt = "select id_param, descricao, valor from nw_param where id_param = ?";
    if ($this->inicio()) {
      $rs = $db->execute($stmt, array($this->id[0]));
      if (!$rs->EOF) {
        $this->valor('id_param',$rs->fields['id_param']);
        $this->valor('descricao',$rs->fields['descricao']);
        $this->valor('valor',$rs->fields['valor']);
      }
    }
  }

  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $db = nwx_db::conexao();
    if ($this->oper == 'Alterar') {
      $stm = "update nw_param set descricao = ?,valor = ? where id_param = ?";
      $p = array($this->post('descricao')
                ,nwx_db::nulo($this->post('valor'))
                ,$this->id[0]
      );
      $this->sair = $_sair;
    }
    elseif ($this->oper == 'Incluir') {
      $stm = "insert into nw_param values(?,?,?)";
      $p = array(strtoupper($this->post('id_param'))
                ,$this->post('descricao')
                ,nwx_db::nulo($this->post('valor'))
      );
      $this->sair = false;
    }
    elseif ($this->oper == 'Excluir') {
      $stm = "delete from nw_param where id_param = ?";
      $p = array($this->id[0]);
      $this->sair = true;
    } else {
      $this->sair = false;
      return;
    }

    // Processamento final no Banco de Dados
    // Se houver erro mostra mensagem do Banco na area de mensagens
    nwx_db::begin_trans();
    if (!$db->execute($stm, $p)) {
      $this->sair = false;
      $this->erro(nwx_db::erro());
      nwx_db::fail_trans();
    } else {
      nwx_repaginar();
    }
    nwx_db::audita($this->oper, $this->bloco, $p);
    nwx_db::end_trans();

  }

}


/**
 * Cria o quadro que contem o grid de manutencao
 */
class nw_param extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    parent::__construct($id);
    $this->titulo = _("Parmetros de Seguraa");
    $this->fixo = 0;

  }

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $db = nwx_db::conexao();
    $substr = $db->substr;

    // Objeto grid
    $grid = new nwx_grid($this,"select id_param, descricao, valor from nw_param",'','id_param');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('id_param',  _('Parmetro'),  'C'),
                          array('descricao', _('Descrio'),  'C')
                         );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('id_param',  _('Parmetro'), '20%','E','N',''),
                           array('descricao', _('Descrio'), '60%','E','C',''),
                           array('valor',     _('Valor'),     '20%','E','C','')
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('id_param');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

    // Cria o formulario para processamento do registros
    $form = new nw_param_frm("nw_param_frm","nw_param");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    $ro = $_SESSION['nwx_sec'] ? false : true;
    
    // Cria os campos do formulario e sua representacao
    $f1 = new nwx_form_text('id_param', 'C',10,0,false,true);
    $f2 = new nwx_form_text('descricao','C',100,0,false,false);
    $f3 = new nwx_form_text('valor', 'C',100,0,true,false);

    $f1->ajuda = _('Cdigo do Parmetro at 10 caracteres (Obrigatrio)');
    $f2->ajuda = _('Descrio do Parmetro');
    $f3->ajuda = _('Valor do Parmetro');
    
    //$f3->linhas = 10;

    $form->input($f1,_('Parmetro'),'','size="20"',true);
    $form->input($f2,_('Descrio'),'','size="80"',true);
    $form->input($f3,_('Valor'),    '','size="80"',true);

    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    if (!$ro) {
      $grid->oper = array('Incluir' => array(_('Incluir'),$form,false,true),
                          'Alterar' => array(_('Alterar'),$form,false,false),
                          'Excluir' => array(_('Excluir'),$form,true,false)
                         );
    } else {
      $grid->oper = array('Consultar' => array(_('Consultar'),$form,true,false,_("Consultar registro"))
                         );
    }

    // Mostra o grid na pagina
    $grid->mostra($this);
  }

}
// vim:et:sw=2:ts=2:nowrap
