<?php
/**
 * Controle de acesso
 *
 * @author Gonalo Franco
 * @version $Id: nwx_nwpag.php 877 2006-12-05 20:34:59Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_db.php");

/**
 * Controle de permissao de acesso a blocos e menus
 */
class nwx_acesso {

	/**
	 * Verifica se bloco liberado para uso
	 *
	 * @param $bloco Nome do bloco
	 * @return Se bloco liberado (true/false)
	 */
	static function bloco($bloco) {

		// Bloco de login e' caso especial
		if ($bloco == 'nw_login') {
			if (isset($_SESSION['nwx_usr'])) {
				return false;
			} else {
				return true;
			}
		}
		
		// Monta o cache de permissoes,grupos e menus se nao existir
		if (isset($_SESSION['nwx_usr']) && $_SESSION['nwx_usr'] && !isset($_SESSION['nwx_cache'])) {
			$db = nwx_db::conexao();
			$_SESSION['nwx_cache'][NWX_SIS]['blo'] = array();
			$_SESSION['nwx_cache'][NWX_SIS]['acs'] = array();
			$_SESSION['nwx_cache'][NWX_SIS]['mbr'] = array();
			$rs = $db->execute("select distinct bloco from nw_mnu where aplic = ? and bloco is not null", array(NWX_SIS));
			while ($reg = $rs->fetchrow()) {
				$_SESSION['nwx_cache'][NWX_SIS]['blo'][] = $reg['bloco'];
			}
			$rs = $db->execute("select distinct bloco from nw_fix where aplic = ? and bloco is not null", array(NWX_SIS));
			while ($reg = $rs->fetchrow()) {
				$_SESSION['nwx_cache'][NWX_SIS]['blo'][] = $reg['bloco'];
			}
			$rs = $db->execute("select * from nw_acs where aplic = ?", array(NWX_SIS));
			while ($reg = $rs->fetchrow()) {
				$_SESSION['nwx_cache'][NWX_SIS]['acs'][] = array($reg['usr'], $reg['bloco']);
			}
			// Se tiver funcao extendida para acessos: usa-la para novas entradas de acesso
			if (defined('NWX_EXT_ACL') && NWX_EXT_ACL) {
				if (file_exists(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_ACL . ".php")) {
					include_once(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_ACL . ".php");
					if (function_exists('nwx_ext_acl')) {
						$acls = nwx_ext_acl();
						foreach ($acls as $acl) {
							$_SESSION['nwx_cache'][NWX_SIS]['acs'][] = $acl;
						}
					}
				}
			}
			$rs = $db->execute("select grupo from nw_mbr where usr = ?", array($_SESSION['nwx_usr']));
			while ($reg = $rs->fetchrow()) {
				$_SESSION['nwx_cache'][NWX_SIS]['mbr'][] = $reg['grupo'];
			}
			$_SESSION['nwx_cache'][NWX_SIS]['mnu'] = array();
			$rs = $db->execute("select * from nw_mnu where aplic = ? order by ordem,id", array(NWX_SIS));
			while ($reg = $rs->fetchrow()) {
				if ($reg['modulo'] == '1') continue;
        $_SESSION['nwx_cache'][NWX_SIS]['mnu'][] = $reg;
			}
		}
		
		// Se for administrador (geral ou da empresa): liberado
		if (isset($_SESSION['nwx_usr'])) {
			// Se p/usuario anonimo, nao mostra
			//$rs = $db->execute("select * from nw_acs where aplic = ? and bloco = ? and usr = 'ANON'", array(NWX_SIS,$bloco));
			//if (!$rs->EOF) return false;
			if ($bloco == 'nw_login') {
				return false;
			}
			if (!empty($bloco) && ((isset($_SESSION['nwx_adm']) && $_SESSION['nwx_adm'] == 1) || 
                             (isset($_SESSION['nwx_adm2']) && $_SESSION['nwx_adm2'] == 1)))
				return true;
		}
				
		// Se tem cache usar as variaveis de sessao e nao acessar banco de dados
		if (isset($_SESSION['nwx_cache'][NWX_SIS])) {
			// Se bloco nao e de menu: liberado
			if (isset($_SESSION['nwx_usr'][NWX_SIS])) {
				if (array_search($bloco, $_SESSION['nwx_cache'][NWX_SIS]['blo']) === false) return true;
			}
			$ok = false;
			// Usuario logado: procura pelo usuario ou grupos PUBLIC e null
			if (isset($_SESSION['nwx_usr'])) {
				foreach ($_SESSION['nwx_cache'][NWX_SIS]['acs'] as $reg) {
					if ($reg[1] == $bloco) {
						if (!$reg[0] || $reg[0] == $_SESSION['nwx_usr'] || $reg[0] == 'PUBLIC') {
							$ok = true;  
							break;
						}
					}
				}
			// Nao logado: apenas null e 'ANON'
			} else {
				foreach ($_SESSION['nwx_cache'][NWX_SIS]['acs'] as $reg) {
					if ($reg[1] == $bloco) {
						if (!$reg[0] || $reg[0] == 'ANON') {
							$ok = true;  
							break;
						}
					}
				}
			}
			// Se nao encontrou ate agora : procura nos grupos do usuario
			if (!$ok && isset($_SESSION['nwx_usr'])) {
				foreach ($_SESSION['nwx_cache'][NWX_SIS]['mbr'] as $gru) {
					foreach ($_SESSION['nwx_cache'][NWX_SIS]['acs'] as $reg) {
						if ($reg[1] == $bloco && $reg[0] == $gru) {
							$ok = true;  
							break;
						}
					}
				}
			}
			return $ok;    
		}
		
		// Nao usa cache: Le diretamente do Banco de Dados
		$db = nwx_db::conexao();
		if (isset($_SESSION['nwx_usr'])) {
			$rm1 = $db->execute("select bloco from nw_mnu where bloco = ?", $bloco);
			$rm2 = $db->execute("select bloco from nw_fix where bloco = ?", $bloco);
			if ($rm1->EOF && $rm2->EOF) return true;
		}
		
		// Procura pelo usuario ou grupos PUBLIC, ANON
		if (isset($_SESSION['nwx_usr'])) {
			$st = "select usr from nw_acs where aplic = ? and bloco = ? and (usr is null or usr = ? or usr = ?)";
			$par = array(NWX_SIS, $bloco, $_SESSION['nwx_usr'], 'PUBLIC');
		} else {
			$st = "select usr from nw_acs where aplic = ? and bloco = ? and (usr is null or usr = ?)";
			$par = array(NWX_SIS, $bloco, 'ANON');
		}

		$rs = $db->execute($st, $par);
		
		// Se nao encontrou ate agora : procura nos grupos do usuario
		if ($rs->EOF && isset($_SESSION['nwx_usr'])) {
			$rs2 = $db->execute("select grupo from nw_mbr where usr = ?", array($_SESSION['nwx_usr']));
			while (!$rs2->EOF) {
				$st = "select usr from nw_acs where aplic = ? and bloco = ? and usr = ?";
				$rs = $db->execute($st, array(NWX_SIS, $bloco, $rs2->fields['grupo']));
				if (!$rs->EOF)
					break;
				$rs2->MoveNext();
			}
		}

		return !$rs->EOF;

	}

	/**
	 * Verifica se submenu tem algum bloco liberado para uso
	 *
	 * @param $mnu Pagina
	 * @return Se submenu liberado
	 */
	static function menu($mnu, $inicio = true) {

		if (!isset($_SESSION['nwx_usr'])) return true;
		//if (isset($_SESSION['nwx_adm']) && $_SESSION['nwx_adm']) return true;
		
		// Se tem o menu em cache, nao acessa banco de dados
		if (isset($_SESSION['nwx_cache'][NWX_SIS]['mnu'])) {
			$ok = false;
			$nr = 0;
			foreach ($_SESSION['nwx_cache'][NWX_SIS]['mnu'] as $itm) {
				if ($itm['pai'] == $mnu) {
					if ($itm['destino'] && !$itm['bloco']) {
						$ok = true;
					} else {
						$id = $itm['id'];
						$blc = $itm['bloco'];
						if ($blc && self::bloco($blc))
							$ok = true;
						else
							$ok = self::menu($id, false);
					}
					if ($ok) break;
					++$nr;
				}
			}
			if ($inicio && $nr == 0) return true;
			return $ok;
		}
		
		// Nao tem cache: Le o menu do Banco de Dados
		$db = nwx_db::conexao();
		
		$st = "select * from nw_mnu where aplic = ? and pai = ?";
		$rs = $db->execute($st, array(NWX_SIS, $mnu));
		
		// Sem menu nenhum - libera
		if ($inicio && $rs->EOF) return true;
		
		$ok = false;
		while (!$rs->EOF && !$ok) {
			if ($rs->fields['destino'] && !$rs->fields['bloco']) {
				$ok = true;
			} else {
				$id = $rs->fields['id'];
				$blc = $rs->fields['bloco'];
				if ($blc && self::bloco($blc))
					$ok = true;
				else
					$ok = self::menu($id, false);
			}
			if ($ok) break;
			$rs->MoveNext();
		}
		return $ok;
	
	}
	
} // class nwx_acesso 
// vim:et:sw=2:ts=2:nowrap:
