<?php
/**
 * Acesso a Bancos de Dados
 *
 * Funoes genericas para Bancos de Dados.<br>
 * Usa biblioteca ADODB para fazer abstraao
 * 
 * @file nwx_db.php
 * @author Gonalo Franco
 * @version $Id: nwx_db.php 924 2007-01-11 18:36:37Z goncalo $
 */

include_once('adodb/adodb-time.inc.php');

// Biblioteca para Bancos de Dados
//include_once("adodb/adodb-exceptions.inc.php");
require_once("adodb/adodb.inc.php");
require_once("adodb/adodb-error.inc.php");

require_once('safecrypt/StonePhpSafeCrypt.php');

if (!defined("NWX_DSN")) {
	define("NWX_DSN","");
}

/**
 * Classe para gerenciamento de conexoes com Bancos de Dados
 * 
 * Implementa o padrao singleton para retonar sempre a mesma conexao
 */
class nwx_db {

	static $obj_DB;
	private $db;
		
	/**
	 * Construtor
	 * 
	 * Usando construtor privado para implementar padro singleton
	 */
	private function __construct($dsn) {

		if (!defined('ADODB_ASSOC_CASE')) define('ADODB_ASSOC_CASE',0);
		
		// Se DSN encriptado
		if (substr($dsn, 0, 1) == '0') {
			$dsn = nwx_decrypt($dsn);
		}
		
		$cn = false;
		if (substr($dsn,0,4) != 'odbc') {
			$per = '?persist';
		} else {
			$per = '';
		}
		if (substr($dsn, 0, 4) == 'bsmb') {
			if (!isset($_SESSION['bsmb']) || !$_SESSION['bsmb']) {
				$this->db = null;
				return;
			}
			$login = nwx_decrypt($_SESSION['bsmb']);
			$v1 = $login['Server'];
			$v2 = $login['Database'];
			$v3 = $login['uid'];
			$v4 = $login['pwd'];
			$drv = substr(NWX_DSN, 5);
			$odbc = "Driver={".$drv."};Server=$v1;Database=$v2;uid=$v3;pwd=$v4";  
			$cn = ADONewConnection('odbc_mssql');
			$cn->Connect($odbc);      
		} else if (substr($dsn,0,10) == 'odbc_mssql' && substr($dsn, 11, 2) != '//') {
			$cn = ADONewConnection('odbc_mssql');
			$odbc = substr($dsn, 11);  
			$cn->Connect($odbc);			
		}
		
		if (!$cn) {
			$url = parse_url($dsn);
			// Se host = '-' esta usando conexao local 
			if ($url['host'] == '-') {
				$cn = ADONewConnection("firebird");
				$cn->Connect(substr($url['path'],1),$url['user'],$url['pass']);
			} else {
				$cn = ADONewConnection($dsn.$per);
			} 
			if (!$cn) {
				$this->db = null;
				return;
			}
		}
		
		$tipo = strtolower(substr($cn->databaseType,0,3));
		$cn->SetFetchMode(ADODB_FETCH_BOTH);
		$cn->maxblobsize = 50000000;
		//$cn->debug = true;
		$ADODB_COUNTRECS = false;
		if ($cn && $tipo == 'oci')
			$cn->Execute("ALTER SESSION SET NLS_DATE_FORMAT='RRRR-MM-DD HH24:MI:SS'");
		$this->db = $cn;
		
	}

	/**
	 * Retorna conexao ao Banco de Dados
	 */
	static function conexao($dsn = NWX_DSN) {

		if (!$dsn) {
			return null;
		}
		if (!isset(self::$obj_DB) || self::$obj_DB == null) {
			self::$obj_DB = new nwx_db($dsn);
		}
		if (is_null(self::$obj_DB->db)) {
			self::$obj_DB = null;
			return null;
		}
		return self::$obj_DB->db;
		
	}

	/**
	 * Fecha a conexao ao Banco de Dados
	 */
	static function reset() {

		if (isset(self::$obj_DB)) {
			self::$obj_DB->db->Close();
			self::$obj_DB = null;
		}
		
	}

	/**
	 * Retorna o tipo de Banco de Dados
	 */
	static function tipo() {

		$db = self::conexao();
		if (is_null($db)) {
			return '';
		} else {
			return $db->databaseType;
		}
		//$tipo = explode(':', NWX_DSN);
		//return $tipo[0];

	}

	/**
	 * Determina se controla md5 do registro
	 *
	 * @param $nome Nome do bloco de referencia
	 * @param $sql SQL para ler o registro
	 */
	static function salva_md5($nome, $sql) {

		// Cria array e coloca o sql de referncia 
		$r = array();
		$r[] = $sql;
		// Le um registro segundo o sql
		$db = self::$obj_DB->db;
		$rs = $db->execute($sql);
		if ($rs->EOF) {
			return true;
		}
		// Concatena todos os campos retornados e calcula md5 do resultado
		$reg = '';
		foreach ($rs->fields as $f) {
			$reg .= $f;  
		}
		// Salva md5 na segunda posicao do array e guarda na sessao
		$r[] = md5($reg);
		$_SESSION['nwx_md5_'.$nome] = $r;
		return true;    

	}

	/**
	 * Determina se outro usuario modificou registro
	 *
	 * @param $nome Nome do bloco de referencia
	 */
	static function valida_md5($nome) {

		// Variavel de sessao nwx_md5_$nome deve ter um array com o SQL e seu md5
		if (!isset($_SESSION['nwx_md5_'.$nome])) {
			return true;
		}
		$r = $_SESSION['nwx_md5_'.$nome]; 
		if (empty($r[1])) {
			unset($_SESSION['nwx_md5_'.$nome]);
			return true;
		}
		// SQL na primeira posicao: executa
		$sql = $r[0];
		$db = self::$obj_DB->db;
		$rs = $db->execute($sql);
		if ($rs->EOF) {
			unset($_SESSION['nwx_md5_'.$nome]);
			return true;
		}
		// Concatena todos os campos retornados e calcula md5
		$reg = '';
		foreach ($rs->fields as $f) {
			$reg .= $f;  
		}
		// Se md5 calculado for diferente do guardado: registro mudou
		if ($r[1] == md5($reg)) {
			unset($_SESSION['nwx_md5_'.$nome]);
			return true;    
		} 

		return false;

	}

	/**
	 * Retorna null se argumento vazio
	 *
	 * @param $arg1 String argumento a comparar
	 * @param $arg2 String argumento a returnar se nao nulo
	 * @return 'null' se arg1 vazio ou arg2 ou arg1
	 */
	static function nulo($arg1, $arg2= '') {

		if (isset($arg1))
			$a1 = trim($arg1);
		else
			$a1 = ''; 
		if ($a1 == '')
			return null;
		elseif (empty($arg2))
			return $a1;
		else
			return $arg2;

	}

	/**
	 * Retorna clob nulo
	 *
	 * @param $drv String com nome do driver
	 * @return String significando um clob vazio
	 */
	function clob($drv) {

		if ($drv == 'oci8po' || $drv == 'oci8')
			return 'empty_clob()';
		else
			return 'null';

	}

	/**
	 * Retorna ultimo erro no Banco de Dados
	 */
	static function erro() {

		$erros = array('1'    => 'J existe um registro com mesmo cdigo ou chave'
									,'2292' => 'Existem outros registros apontando para este'
			);

		$db = self::$obj_DB->db;
		
		$ne = $db->ErrorNo();
		
		if (array_key_exists($ne, $erros))
			return $erros[$ne];
		else  
			return $db->ErrorMsg() . " ($ne)";
		
		
	}

	/**
	 * Faz Commit
	 */
	static function end_trans() {
		if (!defined('NWX_NOTRANS')) {
			$db = self::$obj_DB->db;
			$db->CompleteTrans();
		}
	}

	/**
	 * Faz Rollback
	 */
	static function fail_trans() {
		if (!defined('NWX_NOTRANS')) {
			$db = self::$obj_DB->db;
			$db->FailTrans();
		}
	}

	/**
	 * Inicia transacao
	 */
	static function begin_trans() {
		if (!defined('NWX_NOTRANS')) {
			$db = self::$obj_DB->db;
			$db->StartTrans();
		}
/*
		if (defined('NWX_AUDIT') && NWX_AUDIT) {
			$db = self::$obj_DB->db;
			if (isset($_SESSION['nwx_aud']) && is_array($_SESSION['nwx_aud']) && $_SESSION['nwx_aud']) {
				$tudo = true;
				if ($tudo) {
					$rs = $db->execute("select * from nw_mnu 
															 where aplic = ? and bloco = ?", array(NWX_SIS, $_SESSION['nwx_aud'][0]));
				} else {
					$rs = $db->execute("select a.* from nw_mnu_aud a 
															 inner join nw_mnu b on (a.aplic = b.aplic and a.id = b.id)
															 where a.aplic = ? and b.bloco = ?", array(NWX_SIS, $_SESSION['nwx_aud'][0]));
				}
				while (!$rs->EOF) {
					if (!$rs->fields['usr'] || nw_usr_grupo($rs->fields['usr'], $_SESSION['nwx_usr'])) {
						$p = array(NWX_SIS 
											,$db->GenID('nw_audt_seq')
											,nwx_time::current_time()
											,$_SESSION['nwx_usr']
											,$rs->fields['id']
											,$_SESSION['nwx_aud'][1]
											,$_SESSION['nwx_aud'][2]
											,$_SERVER['REMOTE_ADDR']
											,$_SESSION['nwx_adm']
											); 
						$db->execute("insert into nw_audt values(?,?,?,?,?,?,?,?,?)", $p);
						break;
					}
					$rs->MoveNext();
				}
				unset($_SESSION['nwx_aud']);
			}
		}
*/
	}

	/**
	 * Retorna cast para text 
	 *
	 * @param $col Nome da coluna
	 * @return Nome da coluna ou cast para tamanho desejado
	 */
	static function cast($col) {

		$db = self::$obj_DB->db;
		if ($db->databaseType == 'mssql') {
			return "cast($col as text) as $col";
		} else {
			return $col;
		}

	}

	/**
	 * Grava registro de auditoria
	 *
	 * @param $oper Nome da operacao
	 * @param $bloco Nome do Bloco
	 * @param $refer Array com chave de referencia
	 */
	static function audita($oper, $bloco = false, $refer = false) {
		
		// Se transacao falhou, desiste
		$db = self::conexao();
		if ($db->HasFailedTrans()) return;
		
		// Variavel onde guardar imagen anterior dos campos
		if (isset($_SESSION['nwx_imga'])) {
			$anterior = $_SESSION['nwx_imga'];
			unset($_SESSION['nwx_imga']);
		} else {
			$anterior = array();
		}
		
		// Se auditoria esta ligada
		if (defined('NWX_AUDIT') && NWX_AUDIT) {
			$chave1 = "";
			// Se tem imagen anterior dos campos
			if ($anterior) {
				$chave1 = "Registro Anterior:\n";
				// Monta o campo de referencia anterior
				foreach($anterior as $ref) {
					$chave1 .= "[$ref]";
				}
				$chave1 .= "\nNa Operao:\n";
			}
			// Monta o campo de referencia
			$chave = $chave1;
			if ($refer) {
				foreach($refer as $ref) {
				$chave .= "[$ref]";
				}
			}
			// Verifica se esta ativo geral
			// Se tem bloco e' uma operacao, senao e' do tipo generico (login/logout, etc)
			$opr = $bloco ? 1 : 0;
			$tudo = false;
			$rsa = $db->execute("select * from nw_acs_aud where aplic = ? and opr = $opr", array(NWX_SIS));
			while (!$rsa->EOF) {
				if ($rsa->fields['usr'] == 'PUBLIC' || nw_usr_grupo($rsa->fields['usr'], $_SESSION['nwx_usr'])) {
					$tudo = true;
					break;
				}
				$rsa->MoveNext();
			}
			// Ativo geral
			if ($tudo) {
				if ($bloco) {
					$rs = $db->execute("select * from nw_mnu 
															 where aplic = ? and bloco = ?", array(NWX_SIS, $bloco));
					$id = $rs->fields['id'];
				} else {
					$id = null;
				}
				if (!$bloco || !$rs->EOF) {
					$p = array(NWX_SIS 
										,$db->GenID('nw_audt_seq')
										,adodb_date('Y-m-d H:i:s')
										,$_SESSION['nwx_usr']
										,$id
										,$oper
										,$chave
										,$_SERVER['REMOTE_ADDR']
										,$_SESSION['nwx_adm']
										,self::nulo($bloco)
										); 
					$db->execute("insert into nw_audt values(?,?,?,?,?,?,?,?,?,?)", $p);
				}
			// Verifica se ativo pelo menu
			} else if ($bloco) {
				$rs = $db->execute("select a.* from nw_mnu_aud a 
														 inner join nw_mnu b on (a.aplic = b.aplic and a.id = b.id)
														 where a.aplic = ? and b.bloco = ?", array(NWX_SIS, $bloco));
				// Percorre os registros ate criar registro de auditoria
				while (!$rs->EOF) {
					if ($rs->fields['usr'] == 'PUBLIC' || nw_usr_grupo($rs->fields['usr'], $_SESSION['nwx_usr'])) {
						$p = array(NWX_SIS 
											,$db->GenID('nw_audt_seq')
											,adodb_date('Y-m-d H:i:s')
											,$_SESSION['nwx_usr']
											,$rs->fields['id']
											,$oper
											,$chave
											,$_SERVER['REMOTE_ADDR']
											,$_SESSION['nwx_adm']
											,self::nulo($bloco)
											); 
						$db->execute("insert into nw_audt values(?,?,?,?,?,?,?,?,?,?)", $p);
						break;
					}
					$rs->MoveNext();
				}
			}
		}

	}  
	
} // class nwx_db
// vim:et:sw=2:ts=2:nowrap:
