<?php
/**
 * Processamento de formularios HTML
 *
 * @author Gonalo Franco
 * @version $Id: nwx_form.php 924 2007-01-11 18:36:37Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_db.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_util.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_ctrl.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_cabec.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_check.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_label.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_lista.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_pass.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_radio.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_text.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_textarea.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_texteditor.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_upload.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_subgrid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_fieldset.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form_cmd.php");

/**
 * Definiao de Classe representando um formulario
 */
class nwx_form {

	public $nome;
	public $oper = 'ALT';
	public $submit = '   OK   ';
	public $salvar;
	public $reset;
	public $cancel;
	public $cabec;
	public $mensagem;
	public $grid = '';
	public $sair = false;
	public $bloco;
	public $foco = true;
	public $read_only = false;
	public $mostra_detalhes = false;
	public $novo = false;
	public $id;
	public $campos;
	public $campos_fs;
	public $registro;
	public $detalhe = false;
	public $tabs;
	public $domain; 
	
	private $erros;
	private $prefix = 'nwx_form_';
	private $detalhes;
	private $upfile = false;
	private $maxtam = 0;
	private $operacoes;
	
	/**
	 * Contrutor: Cria objeto formulario
	 *
	 * @param $nome Nome do formulario
	 * @param $bloco Nome do bloco
	 */
	function __construct($nome, $bloco) {

		$this->nome = $nome;
		$this->bloco = $bloco;
		$this->detalhes = array();
		$this->registro = array();
		$this->md5sql = '';
		$this->md5reg = '';
		$this->campos_fs = array();
		$this->campos = array();
		$this->domain = NWX_SIS;
		$dom = textdomain(null);
		textdomain('nwx');  
		$this->salvar = _('Salvar');
		//$this->reset = _('Reler');
    $this->reset = '';
		$this->cancel = _('Fechar');
		textdomain($dom);  
				
	}

	/**
	 * Determina se formulario faz upload
	 *
	 * @param $max Tamanho maximo (0 = sem verificacao)
	 */
	function upload($mx = 0) {
		
		$this->upfile = true;
		$this->maxtam = $mx;
		
	}
	
	/**
	 * Adiciona bloco de detalhes
	 *
	 * @param $bloco Nome do bloco de detalhes
	 * @param $ovr Se detalhe sobreescreve o anterior
	 */
	function detalhe($nome, $bloco, $ovr = true) {

		$det = array();
		$det[] = $nome;
		$det[] = $bloco;
		$det[] = $ovr;
		$this->detalhes[] = $det;

	}

	/**
	 * Adiciona operacoes
	 *
	 * @param $nome Nome da operacao
	 * @param $msg Mensagem de ajuda
	 * @param $conf Mensagem de confirmao
	 */
	function operacao($nome, $msg, $conf = '') {

		$det = array();
		$det[] = $nome;
		$det[] = $msg;
		$det[] = $conf;
		$this->operacoes[] = $det;

	}

	/**
	 * Retorna botao de submit pressionado
	 */
	function submit() {

		return isset($_POST["oper_$this->nome"]) ? trim($_POST["oper_$this->nome"]) : '';

	}
	
	/**
	 * Carrega valores iniciais no formulario
	 *
	 */
	function carrega() {
	}

	/**
	 * Validacao dos campos
	 *
	 */
	function validar() {

    $this->verifica();
		if (!$this->read_only) {
			foreach ($this->campos as $campo) {
				$valor = $this->post($campo->id);
				$m = $campo->verifica($valor);
				if ($m != '')
					$this->erro($m);
			}
			if (is_array($this->tabs) && count($this->tabs) > 0)
				foreach ($this->tabs as $c)
					foreach ($c[1] as $campo) {
						$valor = $this->post($campo->id);
						$m = $campo->verifica($valor);
						if ($m != '')
							$this->erro($m);
					}
			if (!nwx_db::valida_md5($this->bloco)) {
				$this->erro(_("Registro alterado por outro usurio."));
			}
		}

	}

	/**
	 * Validacao definida pelo usuario
	 *
	 */
	function verifica() {
	}

	/**
	 * Processa valores entrados
	 *
	 */
	function processa($_sair = true) {
	}

	/**
	 * Verificacao inicial definida pelo usuario
	 *
	 */
	function prepara() {

		return true;
		
	}

	/**
	 * Retorna se primeira chamada (sem $_POST)
	 *
	 */
	function inicio() {
		
		if (!isset($_POST['oper_'.$this->nome]))
			return true;
		else
			return false;
		
	}

	/**
	 * Bloqueio de registro 
	 * 
	 * Liga o controle por MD5 das alteracoes para implementar
	 * um bloqueio otimista de alteracoes por outros usuarios.
	 *
	 */
	function bloqueia($stmt) {
		
		nwx_db::salva_md5($this->bloco, $stmt);
		
	}
	
	/**
	 * Adiciona um campo ao formulario
	 *
	 * @param $input Objeto de entrada de dados
	 * @param $label Texto do label
	 * @param $valor Valor inicial
	 * @param $atributos Atributos html
	 * @param $br Vai para a proxima linha?
	 */
	function input($input, $label = '', $valor = '', $atributos = '', $br = true) {

		if (is_array($input)) {
			$n = 0;
			foreach ($input as $ipt) {
				$input[$n]->nome = $this->prefix.$this->nome.'_'.$input[$n]->id;
				$input[$n]->label = ($label == '') ? $input[$n]->id : $label;
				$input[$n]->valor = $valor;
				$input[$n]->atributos = $atributos[$n];
				$input[$n]->br = $br;
				$input[$n]->form = $this->nome;
				$input[$n]->bloco = $this->bloco;
				++$n;
			}
		} else {
			$input->nome = $this->prefix.$this->nome.'_'.$input->id;
			$input->label = ($label == '') ? $input->id : $label;
			$input->valor = $valor;
			$input->atributos = $atributos;
			$input->br = $br;
			$input->form = $this->nome;
			$input->bloco = $this->bloco;
		}
		$this->campos[] = $input;
		
	}

	/**
	 * Adiciona paginas tab ao formulario
	 *
	 * @param $tab Identif. da pagina
	 * @param $label Texto do label
	 */
	function tab($tab, $label) {
		
		$this->tabs[$tab] = array($label, array());
		
	}

	/**
	 * Adiciona um campo ao formulario em pagina tab
	 *
	 * @param $tab id da pagina tab
	 * @param $input Objeto de entrada de dados
	 * @param $label Texto do label
	 * @param $valor Valor inicial
	 * @param $atributos Atributos html
	 * @param $br Vai para a proxima linha?
	 */
	function input_tab($tab, $input, $label = '', $valor = '', $atributos = '', $br = true) {

		if (is_array($input)) {
			$n = 0;
			foreach ($input as $ipt) {
				$input[$n]->nome = $this->prefix.$this->nome.'_'.$input[$n]->id;
				$input[$n]->label = ($label == '') ? $input[$n]->id : $label;
				$input[$n]->valor = $valor;
				$input[$n]->atributos = $atributos[$n];
				$input[$n]->br = $br;
				$input[$n]->form = $this->nome;
				$input[$n]->bloco = $this->bloco;
				++$n;
			}
		} else {
			$input->nome = $this->prefix.$this->nome.'_'.$input->id;
			$input->label = ($label == '') ? $input->id : $label;
			$input->valor = $valor;
			$input->atributos = $atributos;
			$input->br = $br;
			$input->form = $this->nome;
			$input->bloco = $this->bloco;
		}
		$this->tabs[$tab][1][] = $input;
		
	}

	/**
	 * Coloca valor inicial em um campo
	 *
	 * @param $id Identificador do campo
	 * @param $valor Valor inicial do campo
	 * @param $ini Valor default e nao valor anterior lido
	 */
	function valor($id, $valor, $ini = false) {

		// Guardar imagen anterior dos campos
		if (!$ini) {
			if (!isset($_SESSION['nwx_imga'])) {
				$_SESSION['nwx_imga'] = array();
			}
			$_SESSION['nwx_imga'][$id] = $valor;
		}
		
		if (is_array($this->campos) && count($this->campos) > 0) {
			foreach ($this->campos as $k => $campo) {
				if (is_array($campo)) {
					$n = 0;
					foreach ($campo as $campo2) {
						if ($campo2->id == $id) {
							$this->campos[$k][$n]->valor = nwx_filtra_entra($valor);
							$this->registro[$id] = $valor;
							return;
						}
					++$n;
					}
				} else {
					if ($campo->id == $id) {
						$this->campos[$k]->valor = nwx_filtra_entra($valor);
						$this->registro[$id] = $valor;
						return;
					}
				}
			}
		}
		
		if (is_array($this->tabs) && count($this->tabs) > 0) {
			foreach ($this->tabs as $t => $c) {
				foreach ($c[1] as $k => $campo) {
					if (is_array($campo)) {
						$n = 0;
						foreach ($campo as $campo2) {
							if ($campo2->id == $id) {
								$this->tabs[$t][1][$k][$n]->valor = nwx_filtra_entra($valor);
								$this->registro[$id] = $valor;
								return;
							}
						++$n;
						}
					} else {
						if ($campo->id == $id) {
							$this->tabs[$t][1][$k]->valor = nwx_filtra_entra($valor);
							$this->registro[$id] = $valor;
							return;
						}
					}
				}
			}
		}
		$this->registro[$id] = $valor;

	}

	/**
	 * Coloca valor inicial em um campo
	 *
	 * @param $id Identificador do campo
	 * @param $valor Valor inicial do campo
	 */
	function fieldset($id, $valor) {

		$this->campos_fs[$id] = $valor;
	
	}
	
	/**
	 * Retorna valor inicial em um campo
	 *
	 * @param $id Identificador do campo
	 */
	function obter_valor($id) {

		foreach ($this->campos as $k => $campo) {
			if ($campo->id == $id) {
				return $this->campos[$k]->valor;
			}
		}
		if (is_array($this->tabs) && count($this->tabs) > 0)
			foreach ($this->tabs as $t => $c)
				foreach ($c[1] as $k => $campo) {
					if ($campo->id == $id) {
						return $this->tabs[$t][1][$k]->valor;
						break;
					}
				}

	}

	/**
	 * Retorna o valor "postado"
	 *
	 */
	function post($id) {

		if (isset($_POST[$this->prefix.$this->nome.'_'.$id]))
			return nwx_filtra($_POST[$this->prefix.$this->nome.'_'.$id]);
		else
			return '';

	}


	/**
	 * Reseta operacao iniciada no grid
	 */
	function reset_opr() {

		if ($this->grid <> '') {
			$_SESSION[NWX_SIS . '_grid'][$this->grid]['gopr'] = '';
		}
		
	}
	
	/**
	 * Registra erro no campo
	 */
	function erro($msg) {

		$this->erros[] = $msg;

	}

	/**
	 * Mostra o controle no form
	 */
	function mostra() {

		$_id = $this->nome;
		
		$form_oper = isset($_POST["oper_$this->nome"]) ? $_POST["oper_$this->nome"] : '';
		if ($form_oper && $form_oper != $this->submit && $form_oper != $this->salvar && 
				$form_oper != $this->reset && $form_oper != $this->cancel) 
			$this->oper = $form_oper;
				
		// Se pressionou o botao de cancelar : fecha o bloco onde esta o form
		if ($this->cancel && $form_oper == $this->cancel) {
			if ($this->grid <> '') {
				$_SESSION[NWX_SIS . '_grid'][$this->grid]['gopr'] = '';
			}
			// Se tiver blocos de detalhe, fecha-os tambem
			foreach ($this->detalhes as $det) {
				if (isset($_SESSION[NWX_SIS . '_grid'])) {
					foreach ($_SESSION[NWX_SIS . '_grid'] as $k => $a) {
						if ($a['gid'] == $det[1] && $a['gtb'] == $_SESSION[NWX_SIS . '_tab']) {
							nwx_fecha_grid($k);
						}
					}
				}
				nwx_fecha_bloco($det[1]);
			}
			if ($this->grid == '')
				nwx_fecha_bloco($this->bloco);
			else
				nwx_fecha_form_bloco($this->bloco);
			nwx_repaginar('', $this->detalhe);
			return;
		}

		$_sair = true;

		// Se pressionou o botao de detalhes : abre novo bloco
		if (substr($form_oper,0,4) == "det_") {
			$_b = '';
			$des = substr($form_oper,4); 
			foreach ($this->detalhes as $det)
				if ($det[0] == $des) {
					$_b = $det[1];
					$_b2 = $det[2];
					break;
				}
			if ($_b != '') {
				$t = $_SESSION[NWX_SIS . '_tab'];
				// Calcula a posicao do sub-bloco dependendo de quantos ja estao abertos para este bloco
				if ($_b2)
					$q = max(nwx_qseq($this->bloco,$t), 0);
				else {      
					$q = 0;
					if (isset($_SESSION[NWX_SIS . '_det']) && is_array($_SESSION[NWX_SIS . '_det'][$t]))
						foreach ($_SESSION[NWX_SIS . '_det'][$t] as $s => $r)
							if ($r == $this->bloco)
								if (nwx_qseq($s,$t) > $q)
									$q = nwx_qseq($s,$t);
					$q = ($q == 0) ? nwx_qseq($this->bloco,$t)+1 : ++$q;
				}
				$p = array();
				if ($this->id) {
					foreach ($this->id as $n => $v) {
						$p["p$n"] = $v;
					}
				}
				if ($_i = nwx_qico($this->bloco, $t)) $p['ico'] = $_i;
				$_SESSION[NWX_SIS . '_abre'][$t][$_b] = array(nwx_qcol($this->bloco,$t),$q,nwx_qsta($this->bloco,$t),$p);
				$_SESSION[NWX_SIS . '_det'][$t][$_b] = $this->bloco;
				$_sair = false;
			}
			nwx_repaginar('', $this->detalhe);
			return;
		}

		// Se pressionou o botao de salvar
		if ($this->salvar && $form_oper == $this->salvar) {
			$_sair = false;
		}

		// Carrega valores
		if ($this->inicio()) {
			// Variavel onde guardar imagen anterior dos campos
			unset($_SESSION['nwx_imga']);
			$this->carrega();
			if (!$this->prepara()) {
				if ($this->grid <> '') {
					$_SESSION[NWX_SIS . '_grid'][$this->grid]['gopr'] = '';
				}
				if ($this->grid == '')
					nwx_fecha_bloco($this->bloco);
				else
					nwx_fecha_form_bloco($this->bloco);
				nwx_repaginar('', $this->detalhe);
				exit;
			}
		// Verifica erros e processa
		} else {
			$this->validar();
			// Se nenhum erro encontrado - processa
			if (!is_array($this->erros) or count($this->erros) == 0)
				$this->processa($_sair);                                
			if (!is_array($this->erros) or count($this->erros) == 0) {
				if ($this->sair) {
					if ($this->grid <> '') {
						$_SESSION[NWX_SIS . '_grid'][$this->grid]['gopr'] = '';
					}
					// Se tiver blocos de detalhe, fecha-os tambem
					foreach ($this->detalhes as $det) {
						if (isset($_SESSION[NWX_SIS . '_grid'])) {
							foreach ($_SESSION[NWX_SIS . '_grid'] as $k => $a) {
								if ($a['gid'] == $det[1] && $a['gtb'] == $_SESSION[NWX_SIS . '_tab']) {
									nwx_fecha_grid($k);
								}
							}
						}
						nwx_fecha_bloco($det[1]);
					}
					if ($this->grid == '')
						nwx_fecha_bloco($this->bloco);
					else
						nwx_fecha_form_bloco($this->bloco);
					nwx_repaginar('', $this->detalhe);
					exit;
				}
				if ($this->detalhe) nwx_repaginar('', $this->detalhe);
			
			}
		}

		$n = 0;
		$lin[0] = 0;
		$max = 0;
		// Percorre os campos para determinar layout de linhas/colunas
		foreach ($this->campos as $campo) {
			++$lin[$n];
			if ($lin[$n] > $max)
				$max = $lin[$n];
			// Se for um array, eh um grupo de campos. Basta verificar o primeiro
			if (is_array($campo))
				$c1 = $campo[0];
			else
				$c1 = $campo;
			if ($c1->br) {
				++$n;
				$lin[$n] = 0;
			}
		}

		// Se campo de upload
		if ($this->upfile) {
			$mpar = 'enctype="multipart/form-data"';
		} else {
			$mpar = "";
		}
		
		// Inicio do formulario
		echo "<form method=\"post\" $mpar name=\"$this->nome\" style=\"display:inline;margin:0;\">\n";
		if ($this->maxtam) {
			echo "<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"$this->maxtam\">\n";  
		}
		
		echo "<table class=\"form\" cellspacing=\"0\" class=\"layout\"><tr>\n";
		
		// Area de mensagens
		if (isset($this->mensagem) && $this->mensagem <> '') {
			if ($this->cabec) {
				$sc = 'style="border-width:1px 1px 0px 1px;"';
			} else {
				$sc = '';
			}
			echo "<td colspan=\"$max\" class=\"cablin\" $sc>\n";
			echo $this->mensagem;
			echo "</td></tr><tr>\n";
		}
		
		// Area de cabecalho
		if (isset($this->cabec) && $this->cabec <> '') {
			echo "<td colspan=\"$max\" class=\"form-cabec\">";
			echo $this->cabec;
			echo "</td></tr><tr>\n";
		}
		
		// Area de mensagens de erro
		if (is_array($this->erros) and count($this->erros) > 0) {
			echo "<td colspan=\"$max\" class=\"form-erros\">";
			echo _("Erros encontrados");
			echo "<ul class=\"form-erros\">\n";
			foreach ($this->erros as $erro)
				echo "<li class=\"form-erros\">$erro</li>";
			echo "</ul>";
			echo "</td></tr><tr>\n";
		}

		// Monta o formulario, percorrendo os campos
		$n = 0;
		$arw = !$this->foco;
		$jscript = '';
		foreach ($lin as $cols) {
			for ($i = 1; $i <= $cols; ++$i) {
				if ($i < $cols or $cols == $max)
					$s = '';
				else
					$s = "colspan=\"".($max - $i + 1)."\"";
				echo "<td $s class=\"form-cel\">\n";
				// Se for uma matriz: campos agrupados
				if (is_array($this->campos[$n])) {
					$campos = $this->campos[$n];
					$z = 0;
					foreach($campos as $c) {
						if ($z > 0)
							$campos[$z]->mostra_label = false;
						++$z;
					}
				} else {
					$campos = array($this->campos[$n]);
				}
				// Para cada campo da celula
				foreach ($campos as $c) {
					//$this->campos[$n]->mostra($this->read_only, $this->novo);
					$c->mostra($this->read_only, $this->novo);
					if (!$arw && !$c->upload && $c->tam && (!$c->read_only || (!$c->automatico && empty($c->valor)) )) {
						$f = $c->nome;
						$jscript .= "\n<script language=\"JavaScript\">\n";
						$jscript .= "<!-- //\n";
						$jscript .= "document.forms['$this->nome'].elements['$f'].focus();\n";
						$jscript .= "//-->\n";
						$jscript .= "</script>\n";
						$arw = true;
					}
					$jscript .= $c->jscript;
				}
				echo "</td>\n";
				if ($i == $cols)
					echo "</tr>\n";
				++$n;
			}
		}

		// Se tiver paginas TAB
		if (is_array($this->tabs) && count($this->tabs) > 0) {

			echo "<tr><td colspan=\"$max\" class=\"form-cel-menu\">";
			$pg = 0;
			echo "<ul class=\"mnulista\">";
			foreach ($this->tabs as $t => $a) {
				$s = '';
				++$pg;
				$lb = $a[0];
				$k = "<a href=\"javascript:pag_$_id($pg);\">$lb</a>";
				$j =  "onmouseover=\"nwliover(this);\" onmouseout=\"nwliout(this);\"";
				echo "<li id=\"t$_id$pg\" class=\"mnu\" $j>$k</li>\n";
			}
			echo "</ul>";
			echo "</td></tr><tr><td colspan=\"$max\" class=\"form-cel\">\n";

			$fck = array(); // Array para hack do FCKEditor (bug no gecko)
			$pg = 0;
			foreach ($this->tabs as $t => $a) {
				++$pg;
				$n2 = 0;
				$lin2 = array();
				$lin2[0] = 0;
				$max2 = 0;
				foreach ($a[1] as $campo2) {
					++$lin2[$n2];
					if ($lin2[$n2] > $max2)
						$max2 = $lin2[$n2];
					if (is_array($campo2))
						$c2 = $campo2[0];
					else
						$c2 = $campo2;
					if ($c2->br) {
						++$n2;
						$lin2[$n2] = 0;
					}
				}

				echo "<div name=\"p$_id$pg\" id=\"p$_id$pg\" style=\"position:relative;left:0px;top:0px;display:none\">\n";
				echo "<table class=\"form\" cellspacing=\"0\" class=\"layout\">\n";

				$n2 = 0;
				foreach ($lin2 as $cols2) {
					echo "<tr>";
					for ($i = 1; $i <= $cols2; ++$i) {
						if ($i < $cols2 or $cols2 == $max2)
							$s = '';
						else
							$s = "colspan=\"".($max2 - $i + 1)."\"";
						echo "<td $s class=\"form-cel\">\n";
						// Se for uma matriz: campos agrupados na celula
						if (is_array($a[1][$n2])) {
							$campos = $a[1][$n2];
							$n = 0;
							foreach($campos as $c) {
								if ($n > 0)
									$campos[$n]->mostra_label = false;
								++$n;
							}
						} else {
							$campos = array($a[1][$n2]);
						}
						// Para cada campo da celula
						foreach ($campos as $c) { 
							//$a[1][$n2]->mostra($this->read_only, $this->novo);
							$c->mostra($this->read_only, $this->novo);
							// Se for objetos FCKeditor guarda no array para corrigir bug com gecko
							if ($c instanceof nwx_form_texteditor) {
								$fck[$pg] = $c->nome;
							}
							if (!$arw && !$c->upload && (!$c->read_only || (!$c->automatico && empty($c->valor)) )) {
								$f = $c->nome;
								$jscript .= "\n<script language=\"JavaScript\">\n";
								$jscript .= "<!-- //\n";
								$jscript .= "document.forms['$this->nome'].elements['$f'].focus();\n";
								$jscript .= "//-->\n";
								$jscript .= "</script>\n";
								$arw = true;
							}
							$jscript .= $c->jscript;
						}
						echo "</td>\n";
						if ($i == $cols2) {
							echo "</tr>\n";
						}
						++$n2;
					}
				}

				echo "</table>\n";

				echo "</div>\n";
			}
			if (isset($_SESSION['nwx_etc']['t']) && $_SESSION['nwx_etc']['t']) {
			  $_pi = $_SESSION['nwx_etc']['t'];
			} else {
        $_pi = 1;
			}
			echo "<script language=\"JavaScript\">\n";
			echo "function pag_$_id(p)\n";
			echo "{\n";
			echo "  for(var i = 1; i <= $pg; i++) {\n";
			echo "    var divObj = document.getElementById('p$_id' + i);\n";
			echo "    var t = document.getElementById('t$_id' + i);\n";
			echo "    if (i == p) {\n";
			echo "      divObj.style.display = '';\n";
			echo "      t.className = 'mnusel';\n";
      echo "      nwx_store(i,'t');\n";
			// Hack para corrigir bug com Gecko no FCKEditor
			if (count($fck) > 0) {
				echo "      if (!document.all) {\n";
				foreach ($fck as $p => $f) {
					echo "        if (i == $p) {\n";
					echo "          try {\n";
					echo "            var oEditor = FCKeditorAPI.GetInstance('$f');\n";
					echo "            if (oEditor.EditMode == FCK_EDITMODE_WYSIWYG) {\n";
					echo "              oEditor.EditorDocument.designMode = \"off\" ;\n"; 
					echo "              oEditor.EditorDocument.designMode = \"on\" ;\n"; 
					echo "              oEditor.Focus() ;\n"; 
					echo "              oEditor.ToolbarSet.RefreshItemsState() ;\n"; 
					echo "            }\n";
					echo "          } catch (e) {}\n";
					echo "        } \n";//catch(e) {}\n";
				}
				echo "      }\n";
			}
			echo "    } else {\n";
			echo "      divObj.style.display = 'none';\n";
			echo "      t.className = 'mnu';\n";
			echo "    }\n";
			echo "  }\n";
			echo "}\n";
			echo "pag_$_id({$_pi});\n";
			echo "</script>\n";
			echo "</td></tr>\n";
		}

		echo "<tr><td colspan=\"$max\" class=\"form-rod\">";
	 
		$dom = textdomain(null);
		textdomain('nwx');
		$m1 = _('Confirmar e sair');
		$m2 = _('Salvar');
		$m3 = _('Voltar campos');
		$m4 = _("Abrir");
		$m5 = _('Cancelar e fechar');
		textdomain($dom);
		$b = array();
		if ($this->submit)
			$b[] = "<a ".nwx_ttip($m1)." class=\"nav\" href=\"javascript:submit_oper_modal('$this->nome','oper_$this->nome','$this->submit');\">$this->submit</a>";
		if (!$this->read_only) {
			if (!$this->novo && $this->salvar)
				$b[] = "<a ".nwx_ttip($m2)." class=\"nav\" href=\"javascript:submit_oper_modal('$this->nome','oper_$this->nome','$this->salvar');\">$this->salvar</a>";
			if (!$this->novo && $this->reset)
				$b[] = "<a ".nwx_ttip($m3)." class=\"nav\" href=\"javascript:reset_oper('$this->nome');\">$this->reset</a>";
		}
		if ((!$this->read_only || $this->mostra_detalhes) && !$this->novo && is_array($this->detalhes) && count($this->detalhes) > 0 ) {
			foreach ($this->detalhes as $det) {
				$b[] = "<a ".nwx_ttip($m4 . " " . $det[0])." class=\"nav\" href=\"javascript:submit_oper_modal('$this->nome','oper_$this->nome','det_$det[0]');\">$det[0]</a>";
			}
		}
		if (!$this->read_only && !$this->novo && is_array($this->operacoes) && count($this->operacoes) > 0 ) {
			foreach ($this->operacoes as $det) {
				if ($det[2])
					$cff = "onClick=\"return confirm('" . $det[2] ."')\";"; 
				else
					$cff = ""; 
				if ($det[1])
					$tt = nwx_ttip($det[1]); 
				else
					$tt = ""; 
				$b[] = "<a $tt class=\"nav\" href=\"javascript:submit_oper_modal('$this->nome','oper_$this->nome','$det[0]');\" $cff>$det[0]</a>";
			}
		}

		if ($this->cancel)
			$b[] = "<a ".nwx_ttip($m5)." class=\"nav\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->cancel');\">$this->cancel</a>";

		foreach ($b as $lk)
			echo $lk;
		
		echo "<input type=\"hidden\" name=\"oper_$this->nome\" value=\"$this->oper\">";
		echo "</td></tr>";
		echo "</table>\n";
		
		echo "</form>\n";
		echo $jscript;
		$this->erros = array();

	}

} // class nwx_form
// vim:et:sw=2:ts=2:nowrap:
