<?php
/**
 * Classe para processamento de grids
 *
 * @file nwx_grid.php
 * @author Gonalo Franco
 * @version $Id: nwx_grid.php 924 2007-01-11 18:36:37Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_db.php");

/**
 * Classe representando um grid
 *
 * Permite a criaao de uma planilha com registros de uma tabela/view de um Banco de Dados.<br>
 * Tem facilidades automaticas para paginaao, filtragem e ordenaao de registros.<br>
 * Operaoes adicionais podem ser definidas para cada registro da tabela, com ligaoes opcionais a formularios.
 */
class nwx_grid {

	// Variaveis de instancia
	
	//! Identificaao interna do grid
	public $id;
	//! Nome do grid
	public $nome;
	//! Array de colunas para listbox de filtro. Linhas no formato array(campo,label,tipo)
	public $filtro;
	//! Array de operaoes validas. Formato "oper"=>array("botao",$form,read-only,novo[,mensagem[,confirma]])
	public $oper;
	//! Array de colunas do grid. Linhas no formato array(campo,label,largura,alinhamento,tipo[,formato[,sort]])
	public $colunas;
	//! Array dos campos da chave primaria
	public $pk;
	//! Mensagem opcional a mostrar no topo do grid
	public $mensagem;
	//! Indica se mostra intervalo de registros no rodape do grid
	public $intervalo;
	//! Indica se o grid faz parte de uma LOV
	public $lov;
	//! Indica se e' um subgrid
	public $detalhe = false;
  //! Mostra checkbox de filtragem
  public $check = '';
  public $check_id = '';
  //! Funcao de filtragem
  public $funcao = '';
  // Default form
  public $form = null;
  // Mostra totais
  public $mostra_totais = 1;
  // Mostra segundo controle de navegacao
  public $navega2 = 1;
  
	private $_query;
	private $_tabela;
	private $_where;
	private $_order;
	private $_compara;
	private $_bt_fim;
	private $_bt_con = 'con';
	private $_bt_prx = 'prx';
	private $_bt_ant = 'ant';
	private $_bt_rst = 'rst';
	private $_linhas = 10;
	private $_min_linhas = 10;
	private $_max_linhas = 10;
	private $_descend = '';
	
	/**
	 * Contrutor
	 *
	 * @param $quadro Objeto quadro onde o grid esta
	 * @param $query Consulta SQL para os dados
	 * @param $where Clausula Where da consulta
	 * @param $order Clausula Order by da consulta
	 */ 
	function __construct($quadro,$query,$where,$order) {

		$this->id = $quadro->id;
		$this->nome = $quadro->id . '_' . $quadro->tab . '_' .
									$quadro->col . '_' .  $quadro->seq;
		$this->_query = $query;
		$this->_where = $where;
		$this->_order = $order;
		$this->filtro = array();
		$this->oper = array();
		$this->colunas = array();
		$this->where = array();
		$this->order = array();
		$this->popup = false;
		$this->mensagem = '';
		$this->intervalo = true;
		$dom = textdomain(null);
		textdomain('nwx');
		$this->_bt_fim = _('Fechar');
		$this->_compara = array(_('igual a'),_('diferente de'),_('inicia com'),_('contm'),_('termina com'),
													 _('maior que'),_('menor que'),_('nulo'),_('no nulo'));
		textdomain($dom);
	}
	
	/**
	 * Estabelece numero de linhas do grid por pagina
	 *
	 * @param $ln Numero de linhas por pagina (normal)
	 * @param $lx Numero de linhas ao maximizar (default igual ao normal)
	 */
	function linhas($ln, $lx = 0) {

		$this->_min_linhas = $ln;
		$this->_max_linhas = ($lx == 0) ? $ln : $lx;
		
	}

	/**
	 * Torna o estado inicial da classificacao como descendente
	 *
	 * @param $d Indice se vai ligar ou desligar
	 */
	function descend($d = true) {
		
		if ($d) {
			$this->_descend = 'desc';
		} else {
			$this->_descend = '';
		}
		
	}

	/**
	 * Formata coluna
	 *
	 * @param $col Conteudo da coluna
	 * @param $tipo Tipo de dados
	 * @param $form Formato a mostrar
	 * @return Coluna formatada
	 */
	private function _formatar($col,$tipo,$form,$pkv = '') {

		// Sem formato : retorna a propria coluna
		if ($form === '')
			return (empty($col) && $col != '0' ? '&nbsp;' : strip_tags($col));

		// Se formato for um array : usa coluna como indice e retorna conteudo
		if (is_array($form)) {
			if (array_key_exists($col,$form))
				return (empty($form[$col]) ? '&nbsp;' : $form[$col]);
			elseif (count($form) % 2 == 0 && isset($form[0])) {
				$c = '';
				$n = 0;
				for($i = 0; $i < count($form); $i += 2) {
					$c .= substr($col,$n,$form[$i]) . $form[$i + 1];
					$n += $form[$i];
				}
				$c .= substr($col,$n);
				return $c;
			} else { 
				return $col;
			}
		}

		// Se coluna vazia
		if (empty($col))
			return '&nbsp;';

		// Se formato for string : usa-o para formatar a coluna, dependendo do tipo
		if (strtoupper($tipo) == 'F') {
			$col = number_format($col,$form,NWX_DEC,NWX_SEP);
			return (empty($col) ? '&nbsp;' : $col);
		}

		if (strtoupper($tipo) == 'D') {
			$db = nwx_db::conexao();
			$df = nwx_time::date_format();
			$idf = '%'.substr($df,0,2) . '%' . substr($df,2,2) . '%' . substr($df,4); 
			if (substr($form,-5) == '%H:%M') $idf .= ' %H:%M';
			$col = strftime($idf, $db->UnixTimeStamp($col));
			return (empty($col) ? '&nbsp;' : $col);
		}

		// Formatos especiais
		if (strtoupper($form) == 'CNPJ') {
			if (strlen($col) == 13)
				$col = "0$col"; 
			if (strlen($col) == 14)
				$col = substr($col,0,2) . '.' . substr($col,2,3) . '.' .
							 substr($col,5,3) . '/' . substr($col,8,4) . '-' . substr($col,12,2);
			return (empty($col) ? '&nbsp;' : $col);
		}

		if (strtoupper($form) == 'CPF') {
			if (strlen($col) == 10)
				$col = "0$col"; 
			if (strlen($col) == 11)
				$col = substr($col,0,3) . '.' . substr($col,3,3) . '.' .
							 substr($col,6,3) . '-' . substr($col,9,2);
			return (empty($col) ? '&nbsp;' : $col);
		}

		if (strtoupper($form) == 'CPF_CNPJ') {
			if (strlen($col) == 10 || strlen($col) == 13)
				$col = "0$col"; 
			if (strlen($col) == 11)
				$col = substr($col,0,3) . '.' . substr($col,3,3) . '.' .
							 substr($col,6,3) . '-' . substr($col,9,2);
			elseif (strlen($col) == 14)
				$col = substr($col,0,2) . '.' . substr($col,2,3) . '.' .
							 substr($col,5,3) . '/' . substr($col,8,4) . '-' . substr($col,12,2);
			return (empty($col) ? '&nbsp;' : $col);
		}

		if (strtoupper($form) == 'MIME') {
			$ico = mime_ico($col);
			$col = "<img src=\"/nwx/img/$ico\">";
			return (empty($col) ? '&nbsp;' : $col);
		}

		if (strtoupper($tipo) == 'FUNC') {
			$col = $form($col);
			return (empty($col) ? '&nbsp;' : $col);
		}

    if (substr(strtoupper($form),0,4) == 'LINK') {
      //$k = substr($form,5).'_'.$pkv;
      $k = $form.'_'.$pkv;
      $ico = mime_ico($col);
      $col = "<a href=\"javascript:submit_oper2('{$this->nome}','oper_{$this->nome}','$k');\"><img src=\"/nwx/img/$ico\" border=\"none\"></a>";
      return (empty($col) ? '&nbsp;' : $col);
    }
		
		$col = sprintf($form, $col);
		return (empty($col) ? '&nbsp;' : $col);

	}

	/**
	 * Mostra o grid ou seu formulario associado
	 *
	 * @param $quadro Quadro do formulario
	 */
	function mostra($quadro) {

		// Ajusta o array de filtros
		if (empty($this->filtro)) {
			$this->filtro = array();
		}

		// Ajusta o array de colunas, colocando a coluna 7 caso nao exista
		foreach($this->colunas as $k => $lin) {
			if (count($lin) == 6) {
				$this->colunas[$k][6] = $this->colunas[$k][0];
			}
		}

		$submit = isset($_POST["oper_{$this->nome}"]) ? $_POST["oper_{$this->nome}"] : '';

		// Se pressionou o botao de Fechar : fecha o grid e o bloco
		if ($submit == $this->_bt_fim) {
			//unset($this->_grid);
			if (isset($_SESSION['nwx_aud'])) unset($_SESSION['nwx_aud']);
			nwx_fecha_grid($this->nome);
			nwx_fecha_bloco($this->id);
			if (!$this->lov)
				nwx_repaginar();
			else
				echo "<script language=\"javascript\">close();</script>";
			return;
		}

		// Guarda o order by anterior para poder mudar a ordenacao
		if (isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gob']))
			$ord_ant = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gob'];
		else
			$ord_ant = '';

		// Valores no Post
		if (isset($_POST[$this->id."_coluna"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gcol'] = nwx_filtra($_POST[$this->id."_coluna"]);
		if (isset($_POST[$this->id."_filtro"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gfil'] = nwx_filtra($_POST[$this->id."_filtro"]);
		if (isset($_POST[$this->id."_consulta"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gqry'] = nwx_filtra($_POST[$this->id."_consulta"]);
		//if (isset($_POST[$this->id."_operacao"]))
			//$_SESSION[NWX_SIS . '_grid'][$this->nome]['gopr'] = nwx_filtra($_POST[$this->id."_operacao"]);
		if (isset($_POST["oper_$this->nome"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gopr'] = $submit;
		if (isset($_POST[$this->id."_inicial"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gini'] = nwx_filtra($_POST[$this->id."_inicial"]);
		if (isset($_POST[$this->id."_order"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gob'] = nwx_filtra($_POST[$this->id."_order"]);
		if (isset($_POST[$this->id."_desc"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gds'] = nwx_filtra($_POST[$this->id."_desc"]);
		if (isset($_POST[$this->id."_pk"]))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gpk'] = nwx_filtra($_POST[$this->id."_pk"]);

		// Valores guardados na sessao
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gcol']) && count($this->filtro) > 0)
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gcol'] = $this->filtro[0][0];
		elseif (count($this->filtro) == 0)
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gcol'] = '';
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gfil']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gfil'] = 'igual a';
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gqry']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gqry'] = '';
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gopr']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gopr'] = '';
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gini']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gini'] = 1;
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gob']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gob'] = $this->_order;
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gds']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gds'] = $this->_descend;
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gpk']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gpk'] = '';
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gid']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gid'] = $this->id;
		if (!isset($_SESSION[NWX_SIS . '_grid'][$this->nome]['gtb']))
			$_SESSION[NWX_SIS . '_grid'][$this->nome]['gtb'] = $_SESSION[NWX_SIS . '_tab'];
		
		// Se clicou no cabecalho, verifica se foi na mesma ordem atual
		// Se for o caso, muda de ascendente para descendente ou vice-versa
		if (!empty($_POST[$this->id."_altord"])) {
			if (!empty($ord_ant) and $ord_ant == $_POST[$this->id."_altord"])
				if (empty($_SESSION[NWX_SIS . '_grid'][$this->nome]['gds']))
					$_SESSION[NWX_SIS . '_grid'][$this->nome]['gds'] = "desc";
				else
					$_SESSION[NWX_SIS . '_grid'][$this->nome]['gds'] = "";
			if (!empty($ord_ant) and $ord_ant != $_POST[$this->id."_altord"])
				$_SESSION[NWX_SIS . '_grid'][$this->nome]['gds'] = "";
		}
		$topr = 0;
    $sopr = trim($_SESSION[NWX_SIS . '_grid'][$this->nome]['gopr']);
    // Verifica se pressionou outro botao
		foreach($this->oper as $key => $opr) {
			if (trim($_SESSION[NWX_SIS . '_grid'][$this->nome]['gopr']) == trim($key)) {
				++$topr;
        // Nao e um grid de LOV
				if (!$this->lov) {
					$form = $opr[1];
					if (!empty($form)) {
						$form->oper = $key;
						$form->read_only = $opr[2];
						$form->novo = $opr[3];
						$form->cabec = $opr[0];
						$form->id = unserialize(rawurldecode($_SESSION[NWX_SIS . '_grid'][$this->nome]['gpk']));
						//$ch = ''; 
						//if (!$form->novo) {
						//  foreach($form->id as $s) {
						//    $ch .= "[$s]";
						//  }
						//}
						//$_SESSION['nwx_aud'] = array($this->id,$form->oper,$ch);
					}
					break;
				// Grid de LOV
				} else if ($submit) {
					$js_pk = unserialize(rawurldecode($_SESSION[NWX_SIS . '_grid'][$this->nome]['gpk']));
					$_id = empty($_GET['id']) ? 0 : $_GET['id'];
					$_ds = empty($_GET['dsp']) ? '' : $_GET['dsp'];
					$_sq = empty($_GET['sq']) ? '' : $_GET['sq'];
					$_ls = empty($_GET['ls']) ? '' : $_GET['ls'];
					$_fld = empty($_GET['fld']) ? '' : $_GET['fld'];
					$_form = empty($_GET['form']) ? '' : $_GET['form'];
					$_desp = empty($_GET['dsp']) ? '' : $_GET['dsp'];
					$_sq = stripslashes($_sq);
					$_resul = '';
					if ($key != 'Nenhum' && !empty($_sq) && (!empty($_dsp) || !empty($_ls))) {
						$ldb = nwx_db::conexao();
						$lrs = $ldb->execute($_sq, $js_pk);
						if (!$lrs->EOF) {
							if ($_ds) $_resul = "obj_caller_d.value = '" . addslashes($lrs->fields[$_ds]) . "';\n";
							if ($_ls) $_lista = $lrs->fields[$_ls];
						}
					}
					echo "<script language=\"javascript\">\n";
					echo "var obj_caller = frames['parent'].document.forms['$_form'].elements['$_fld'];\n";
					echo "var obj_caller_d = frames['parent'].document.forms['$_form'].elements['$_desp'];\n";
					echo "var obj_div = frames['parent'].document.getElementById('overDiv');\n";
					if ($key != 'Nenhum') {
						if (!$_ls) {
							echo "obj_caller.value = '$js_pk[0]';\n";
							echo "obj_caller.focus();\n";
							if (!empty($_resul)) {
								echo $_resul;
							}
						} else {
							echo "var obj_hid = frames['parent'].document.forms['$_form'].elements['{$_fld}_lst'];\n";
							echo "addSelect(obj_caller, '$js_pk[0]', '$_lista', obj_hid);\n";
						}
					} else {
						if (!$_ls) {
							echo "obj_caller.value = '';\n";
							echo "obj_caller.focus();\n";
							if (!empty($_ds) && !empty($_sq))
								echo "obj_caller_d.value = '';\n";
						} else {
							echo "var obj_hid = frames['parent'].document.forms['$_form'].elements['{$_fld}_lst'];\n";
							echo "emptySelect(obj_caller, obj_hid);\n";
						}
					}
					echo "</script>\n";
				}
			}
		}
    
    // Clicou em um link no grid, usa o form default
    // Operacao tem a form LINK_Identificacao_chave
    if (!$topr && substr($sopr,0,4) == 'LINK') {
      $form = $this->form;
      $sopr = stripslashes($sopr);
      $a = explode('_',$sopr);
      if (count($a) == 3) {
        $form->oper = $a[1];
        $form->id = unserialize(rawurldecode($a[2]));
      }
    }
    
		if (isset($quadro))
			$this->_linhas = (@$quadro->estado == 2) ? $this->_max_linhas : $this->_min_linhas;
		else
			$this->_linhas = $this->_min_linhas;

		// Chama o grid ou o formulario
		if (isset($form) && !empty($form)) {
			$form->mostra();
		} else {
			$this->_lista();
		}
	}

	/**
	 * Mostra o conteudo do grid
	 */
	private function _lista() {

		// Conexao ao Banco de dados
		$db = nwx_db::conexao();
    
		unset($_SESSION['nwx_etc']['t']);
    
		$_p = "/nwx/estilos/" . $_SESSION['nwx_estilo'];
		
		// Monta a linha de consulta
		$_coluna = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gcol'];
		$_consulta = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gqry'];
		$_inicial = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gini'];
		$_filtro = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gfil'];
		$_order = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gob'];
		$_desc = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gds'];
		$_pk = $_SESSION[NWX_SIS . '_grid'][$this->nome]['gpk'];

		// Acho o indice da coluna de busca no array
		$pcol = 0;
		foreach($this->filtro as $f) {
			if ($f[0] == $_coluna)
				break;
			++$pcol;
		}
		$_pagina = $this->_linhas;

		$submit = isset($_POST["oper_$this->nome"]) ? $_POST["oper_$this->nome"] : '';

		$dom = textdomain(null);
		textdomain('nwx');
		//$submit = isset($_POST[$this->id."navega"]) ? $_POST[$this->id."navega"] : '';
		$_where = $this->_where;
		// Se preencheu campo de consulta : altera a clausula where
		if (($_consulta != '' || $_filtro == _('nulo') || $_filtro == _('no nulo')) && $submit <> $this->_bt_rst) {
			if (!empty($_where))
				$_where .= ' and';
			if ($_filtro == _('nulo'))
				$_where .= " ($_coluna is null)";
			elseif ($_filtro == _('no nulo'))
				$_where .= " ($_coluna is not null)";
			elseif ($this->filtro[$pcol][2] == 'D') {
				if (nwx_time::data_valida($_consulta)) {
					$_d = nwx_time::data_iso($_consulta, false);
					if ($_filtro == _('inicia com'))
						$_where .= " ($_coluna like '$_d%')";
					elseif ($_filtro == _('termina com'))
						$_where .= " ($_coluna like '%$_d')";
					elseif ($_filtro == _('contm'))
						$_where .= " ($_coluna like '%$_d%')";
					elseif ($_filtro == _('igual a'))
						$_where .= " ($_coluna like '$_d%')";
					elseif ($_filtro == _('diferente de'))
						$_where .= " ($_coluna <> '$_d')";
					elseif ($_filtro == _('maior que'))
						$_where .= " ($_coluna > '$_d')";
					elseif ($_filtro == _('menor que'))
						$_where .= " ($_coluna < '$_d')";
				} else
					$_consulta = '';
			} elseif ($this->filtro[$pcol][2] == 'N') {
				$_d = strtr($_consulta,',','.');
				$_d = is_numeric($_d) ? $_d : 0;
				if ($_filtro == _('inicia com'))
					$_where .= " ($_coluna like '$_d%')";
				elseif ($_filtro == _('termina com'))
					$_where .= " ($_coluna like '%$_d')";
				elseif ($_filtro == _('contm'))
					$_where .= " ($_coluna like '%$_d%')";
				elseif ($_filtro == _('igual a'))
					$_where .= " ($_coluna = $_d)";
				elseif ($_filtro == _('diferente de'))
					$_where .= " ($_coluna <> $_d)";
				elseif ($_filtro == _('maior que'))
					$_where .= " ($_coluna > $_d)";
				elseif ($_filtro == _('menor que'))
					$_where .= " ($_coluna < $_d)";
			} elseif ($this->filtro[$pcol][2] == 'C') {
				if ($_filtro == _('inicia com'))
					$_where .= " ($_coluna like '$_consulta%')";
				elseif ($_filtro == _('termina com'))
					$_where .= " ($_coluna like '%$_consulta')";
				elseif ($_filtro == _('contm'))
					$_where .= " ($_coluna like '%$_consulta%')";
				elseif ($_filtro == _('igual a'))
					$_where .= " ($_coluna = '$_consulta')";
				elseif ($_filtro == _('diferente de'))
					$_where .= " ($_coluna <> '$_consulta')";
				elseif ($_filtro == _('maior que'))
					$_where .= " ($_coluna > '$_consulta')";
				elseif ($_filtro == _('menor que'))
					$_where .= " ($_coluna < '$_consulta')";
			}
		}
		textdomain($dom);
		// Ajusta o comando SQL
		$_w = empty($_where) ? '' : ' where ';
		$_o = empty($_order) ? '' : ' order by ';
		$stmt = $this->_query . $_w . $_where . $_o . $_order . ' ' . $_desc;
		
		if (is_array($this->where) && count($this->where) > 0) {
			$arr_where = $this->where;
		} else {
			$arr_where = false;
		}
		
		$_ant = $_inicial;
		
		// Se for uma navegacao : acerta os limites p/ o grid
		if ($submit == $this->_bt_prx) {
			$_inicial = $_inicial + $_pagina;
			$_pk = '';
		} elseif ($submit == $this->_bt_ant && $_inicial > 1) {
			$_inicial = $_inicial - $_pagina;
			$_pk = '';
		} elseif ($submit == $this->_bt_rst) {
			$_inicial = 1;
			$_consulta = '';
			$_filtro = '=';
			if (count($this->filtro) > 0)
				$_coluna = $this->filtro[0][1];
			$_pk = '';
		} elseif ($submit == $this->_bt_con) {
			$_inicial = 1;
			$_pk = '';
		}
		
		// Se mostra totais
		if ($this->mostra_totais) {
		  $rt = $db->execute("select count(*) as ttr from ({$stmt}) as x");
		  $ttr = $rt->fields['ttr'];
		} else {
			$ttr = 0;
		}
		
		// Faz a consulta
		$rs = $db->selectlimit($stmt,$_pagina, $_inicial - 1, $arr_where);
		if ($rs && $rs->EOF) {
			$_inicial = $_ant;
			$rs = $db->selectlimit($stmt,$_pagina, $_inicial - 1, $arr_where);
		}
		
		// Mostra o painel
		echo "<form name = \"$this->nome\" method=\"post\" style=\"display:inline;margin:0;\">\n";

		// Monta o form de consulta
		echo "<table class=\"grid-form\" cellspacing=\"0\">\n";

		if (isset($this->mensagem) && $this->mensagem != '') {    
			echo "<tr><td colspan=\"2\" class=\"cablin\">\n";
			echo $this->mensagem;
			echo "</td></tr>\n";
		}
		
		echo "<tr>\n";

		echo "<td nowrap class=\"grid-cel\">\n";
		//echo "Consulta&nbsp;";

		if (count($this->filtro) > 0) {
			echo "<select class=\"form-lista\" name=\"$this->id"."_coluna\" size=\"1\">";
			foreach($this->filtro as $n) {
				$s = ($n[0] == $_coluna) ? 'selected' : '';
				echo "<option value=\"".$n[0]."\" $s>". $n[1] . "</option>";
			}
			echo "</select>";
			echo "<select class=\"form-lista\" name=\"$this->id"."_filtro\" size=\"1\">";
			foreach($this->_compara as $c) {
				$s = ($c == $_filtro) ? 'selected' : '';
				echo "<option value=\"$c\" $s>$c</option>";
			}
			echo "</select>";
			echo "<input class=\"form-input\" type=\"text\" name=\"$this->id"."_consulta\" value=\"$_consulta\" size=\"30\">";
			$dom = textdomain(null);
			textdomain('nwx');
			echo "<a ".nwx_ttip(_("Aplicar condio"))." class=\"navbt\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_con');\"><img class=\"navimg\" src=\"$_p/zoom_in.gif\"></a>";
			echo "<a ".nwx_ttip(_("Cancelar condio"))." class=\"navbt\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_rst');\"><img class=\"navimg\" src=\"$_p/zoom_out.gif\"></a>";
			
      if ($this->check && $this->check_id) {
        if (isset($_SESSION['nwx_etc'][$this->check_id]) && $_SESSION['nwx_etc'][$this->check_id]) {
          $c = 'checked="checked"';
        } else {
          $c = '';
        }
        echo "&nbsp;&nbsp;&nbsp;<input class=\"form-check\" type=\"checkbox\" $c name=\"{$this->check_id}\" value=\"1\" onclick=\"nwx_session_check('{$this->check_id}');submit();\">" . $this->check;
      }
      
      textdomain($dom);
		} else {
			echo "&nbsp;";
		}
		echo "</td>\n";

		echo "<td nowrap class=\"grid-cel\" style=\"text-align:right;\">\n";
		$dom = textdomain(null);
		textdomain('nwx');
		echo "<a ".nwx_ttip(_("Pgina anterior"))." class=\"navbt\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_ant');\"><img class=\"navimg\" src=\"$_p/btn_up.gif\"></a>";
		echo "<a ".nwx_ttip(_("Prxima pgina"))." class=\"navbt\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_prx');\"><img class=\"navimg\" src=\"$_p/btn_dwn.gif\"></a>";
		textdomain($dom);
		echo "<input type=\"hidden\" name=\"$this->id"."_order\" value=\"$_order\">";
		echo "<input type=\"hidden\" name=\"$this->id"."_desc\" value=\"$_desc\">";
		echo "<input type=\"hidden\" name=\"$this->id"."_altord\" value=\"\">";
		echo "</td>\n";
		echo "</tr>\n";
		echo "</table>\n";

		// Cabecalho do grid
		echo "<table id=\"tab_$this->id\" class=\"grid\" cellspacing=\"1\">\n";
		echo "<tr>\n";
		echo "<td class=\"grid-cabec\">&nbsp;</td>";

		// Para cada coluna incluida
		foreach($this->colunas as $col) {
			// Se coluna ordenada, mostra o icone ascendente ou descendente
			if (!empty($_order) and $_order == $col[6])
				if (empty($_desc))
					$im = "&nbsp;<img src=\"/nwx/img/up.gif\" />";
				else
					$im = "&nbsp;<img src=\"/nwx/img/down.gif\" />";
			else
				$im = '';
			// Desenha o cabecalho, com links para ordenacao em cada coluna
			if (!empty($_order) && strpos($_order,',') === false && $col[4] != 'T')
				if (empty($col[2]))
					echo "<td nowrap class=\"grid-cabec\"><a href=\"javascript:submit_order('" . $this->nome . "','" . $this->id  . "','" . $col[6] . "');\">" . $col[1] . "</a>$im</td>";
				else
					echo "<td nowrap class=\"grid-cabec\" width=\"" . $col[2]. "\"><a href=\"javascript:submit_order('" . $this->nome . "','" . $this->id  . "','" . $col[6] . "');\">" . $col[1] . "</a>$im</td>";
			else
				if (empty($col[2]))
					echo "<td nowrap class=\"grid-cabec\">".$col[1]."</td>";
				else
					echo "<td nowrap class=\"grid-cabec\" width=\"" . $col[2]. "\">".$col[1]."</td>";

		}
		echo "</tr>\n";

    // Corpo do grid
    $atual = 0;
    
    while ($rs && !$rs->EOF) {

			// Funcao de comparacao
      if ($this->funcao) {
        $func = $this->funcao;
        $r = $func($rs->fields);
        if (!$r) {
          $rs->MoveNext();
          continue;
        }
      }
      
      ++$atual;
			$l = ($atual % 2) + 1;
			$chk = ($atual == 1) ? "checked" : "";

			$pka = array();
			foreach ($this->pk as $p) {
				$pka[] = $rs->fields[$p];
			}
			$pkv = rawurlencode(serialize($pka));
			
			echo "<tr>\n";
			echo "<td class=\"grid-cabec\">";
			//echo "<input type=\"radio\" class=\"grid-radio\" $chk name=\"$this->id"."_pk\" value=\"".$rs->fields[$this->pk]."\">";
			echo "<input type=\"radio\" class=\"grid-radio\" $chk name=\"" . $this->id . "_pk\" value=\"" . $pkv . "\">";
			echo "</td>";
			foreach($this->colunas as $col) {
				$a = empty($col[3]) ? 'E' : strtoupper($col[3]);
				if ($a == 'D')
					$a = "style=\"text-align:right;\"";
				elseif ($a == 'C')
					$a = "style=\"text-align:center;\"";
				else
					$a = "style=\"text-align:left;\"";
				echo "<td class=\"grid-lin$l\" $a>" . $this->_formatar($rs->fields[$col[0]],$col[4],$col[5],$pkv) . "</td>";
			}
			echo "</tr>\n";

			$rs->MoveNext();
		}

		if ($atual == 0) {
			echo "<tr>\n";
			$dom = textdomain(null);
			textdomain('nwx');
			echo "<td class=\"grid-lin1\" colspan=\"" . (sizeof($this->colunas) + 1) . "\">"._('Nenhum registro encontrado')."</td>\n";
			textdomain($dom);
			echo "</tr>\n";
			$intervalo = "&nbsp;";
		} else {
			$final = $_inicial + $atual - 1;
			$dom = textdomain(null);
			textdomain('nwx');
			$intervalo = _("Linhas")." $_inicial - $final";
			if ($this->mostra_totais && $ttr) {
				$intervalo .= " / {$ttr}";
			}
			textdomain($dom);
			if ($this->intervalo) {
				echo "<tr>\n";
				echo "<td class=\"grid-fim\" colspan=\"" . (sizeof($this->colunas) + 1) . "\">\n";
				echo $intervalo;
        if ($this->navega2) {
        	$dom = textdomain(null);
        	textdomain('nwx');
        	echo "&nbsp;";
          if ($ttr) {
            if ($_inicial > 1) echo "<a ".nwx_ttip(_("Pgina anterior"))." class=\"navbt\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_ant');\"><img class=\"navimg\" src=\"$_p/btn_up.gif\"></a>";
            if ($final < $ttr) echo "<a ".nwx_ttip(_("Prxima pgina"))." class=\"navbt\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_prx');\"><img class=\"navimg\" src=\"$_p/btn_dwn.gif\"></a>";
          }
        	textdomain($dom);
        }
				echo "</td>";
				echo "</tr>\n";
			}
		}

		echo "</table>";

		// Rodape do grid
		echo "<table class=\"grid-rodape\" cellspacing=\"0\">\n";
		echo "<tr>";
		echo "<td class=\"grid-rodape\">";
		echo "&nbsp;</td>";
		echo "<td class=\"grid-rodape\">";
		foreach($this->oper as $k => $opr) {
			//if ($atual > 0 || $k == 'Incluir')
			if (count($opr) > 4 && !empty($opr[4])) 
				$ttip = nwx_ttip($opr[4]); 
			else
				$ttip = "onmouseover=\"return true;\""; 
			if (count($opr) > 5 && !empty($opr[5])) 
				$cff = "onClick=\"return confirm('" . $opr[5] ."')\";"; 
			else
				$cff = ""; 
			if ($atual > 0 || $opr[3]) {
				if (count($opr) > 6 && !empty($opr[6])) {
					echo "<a $ttip class=\"nav\" href=\"$opr[6]\" target=\"_blank\" $cff>$opr[0]</a>";
				} else {
					if ($cff) {
            echo "<a $ttip class=\"nav\" href=\"javascript:submit_oper_modal('$this->nome','oper_$this->nome','$k');\" $cff>$opr[0]</a>";
          } else {
            echo "<a $ttip class=\"nav\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$k');\" $cff>$opr[0]</a>";
          }
				}
			}
		}
		
		if (!$this->detalhe && !$this->lov) { 
			$dom = textdomain(null);
			textdomain('nwx');
			$ttip = nwx_ttip(_("Cancelar e fechar")); 
			echo "<a $ttip class=\"nav\" href=\"javascript:submit_oper('$this->nome','oper_$this->nome','$this->_bt_fim');\">$this->_bt_fim</a>";
			textdomain($dom);
		}

		echo "</td>";
		echo "</tr>";
		echo "</table>";
		
		echo "<input type=\"hidden\" name=\"$this->id"."_inicial\" value=\"$_inicial\">";
		echo "<input type=\"hidden\" name=\"oper_$this->nome\" value=\"$this->oper\">";
		echo "</form>";

		$_SESSION[NWX_SIS . '_grid'][$this->nome]['gini'] = $_inicial;

	}

} //class nwx_grid 
// vim:et:sw=2:ts=2:nowrap:
