<?php
/**
 * Log de mensagens
 *
 * Implementa a gravaao de mensagens em arquivos de log
 * 
 * @file nwx_log.php
 * @author Gonalo Franco
 * @version $Id: nwx_log.php 924 2007-01-11 18:36:37Z goncalo $
 */

//require_once("nwx_inc.php");

if (!defined('NWX_LOG_PATH')) define ('NWX_LOG_PATH', NWX_HTD);

/**
 * Classe para gerenciamento de conexoes com Bancos de Dados
 * 
 * Implementa o padrao singleton para retonar sempre a mesma conexao
 */
class nwx_log {

  private $hlog;
  private $nivel;
    
  /**
   * Construtor
   * 
   * Usando construtor privado para implementar padro singleton
   */
  private function __construct($log, $nivel_log) {

    $this->nivel = $nivel_log;
    if ($nivel_log) {
      $logfile = NWX_LOG_PATH . "/" . NWX_APL . "_{$log}.log";
      $this->hlog = @fopen($logfile, 'a+');    
      if (!is_resource($this->hlog)) {
        throw new Exception("Arquivo de log $logfile no pode ser criado ou aberto");
      }
    }
    
  }

  /**
   * Retorna conexao ao Banco de Dados
   */
  static function obter_log($log, $nivel_log = NWX_LOG_AVISO) {

    static $logs;

    if (!isset($logs)) {
      $logs = array();
    }
    if (!isset($logs[$log])) {
      $logs[$log] = new nwx_log($log, $nivel_log);
    }

    return $logs[$log];
    
  }

  /**
   * Grava mensagem de log
   */
  private function registra($msg, $nvl, $modulo = '') {

    $time = strftime('%x %X', time());
    $msg = str_replace("\t", '    ', $msg);
    $msg = str_replace("\n", ' ', $msg);
    $msg = str_replace("\r", '', $msg);

    $str_nivel = $this->nivel_string($nvl);

    if(!empty($modulo)) {
      $modulo = str_replace("\t", '    ', $modulo);
      $modulo = str_replace("\n", ' ', $modulo);
      $modulo = str_replace("\r", '', $modulo);
    }  

    $linha = "$time\t$str_nivel\t$msg\t$modulo\n";
    fwrite($this->hlog, $linha);

  }

  /**
   * Mensagem nivel de DEBUG
   */
  function debug($msg, $modulo = '') {
    if (!$this->nivel) return;
    if ($this->nivel <= NWX_LOG_DEBUG) {
      $this->registra($msg, NWX_LOG_DEBUG, $modulo);
    }
  }

  /**
   * Mensagem nivel de INFO
   */
  function info($msg, $modulo = '') {
    if (!$this->nivel) return;
    if ($this->nivel <= NWX_LOG_INFO) {
      $this->registra($msg, NWX_LOG_INFO, $modulo);
    }
  }

  /**
   * Mensagem nivel de AVISO
   */
  function aviso($msg, $modulo = '') {
    if (!$this->nivel) return;
    if ($this->nivel <= NWX_LOG_AVISO) {
      $this->registra($msg, NWX_LOG_AVISO, $modulo);
    }
  }

  /**
   * Mensagem nivel de ERRO
   */
  function erro($msg, $modulo = '') {
    if (!$this->nivel) return;
    if ($this->nivel <= NWX_LOG_ERRO) {
      $this->registra($msg, NWX_LOG_ERRO, $modulo);
    }
  }

  /**
   * Mensagem nivel CRITICO
   */
  function critico($msg, $modulo = '') {
    if (!$this->nivel) return;
    if ($this->nivel <= NWX_LOG_CRITICO) {
      $this->registra($msg, NWX_LOG_CRITICO, $modulo);
    }
  }
  
  /**
   * Retorna string do nivel
   */
  public static function nivel_string($nivel) {

    switch ($nivel) {
      case NWX_LOG_DEBUG:
        return 'NWX_LOG_DEBUG';
        break;
      case NWX_LOG_INFO:
        return 'NWX_LOG_INFO';
        break;
      case NWX_LOG_AVISO:
        return 'NWX_LOG_AVISO';
        break;
      case NWX_LOG_ERRO:
        return 'NWX_LOG_ERRO';
        break;
      case NWX_LOG_CRITICO:
        return 'NWX_LOG_CRITICO';
      default:
        return "NWX_LOG_???($nivel)";
    }

  }

  
} //class nwx_log
// vim:et:sw=2:ts=2:nowrap:
