<?php
/**
 * Montagem das paginas HTML de um aplicativo
 *
 * Implementa montagem de paginas usando definiao em Banco de Dados
 * e usando a estrutura da biblioteca nw
 *
 * @author Gonalo Franco
 * @version $Id: nwx_nwpag.php 925 2007-01-12 22:16:24Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_pag.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_db.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_acesso.php");

/**
 * Paginas via Banco de Dados com estrutura nw_  
 */
class nwx_nwpag extends nwx_pag {

	/**
	 * Construtor - Cria a pagina
	 *
	 * @param $titulo Titulo da pagina
	 */
	function __construct($titulo = '') {

		parent::__construct($titulo);
		$this->conexao = nwx_db::tipo() . ' - ' . phpversion();
		$this->descricao = NWX_DESCRICAO;
		$this->estilo = NWX_ESTILO;
		// Licenciamento
		$this->licenciado = NWX_LICENCEE;
		$this->copyright = NWX_OWNER;
		$this->serie = NWX_SERIAL;
		
	}

	/**
	 * Cria a lista de paginas
	 */
	function paginas() {
		
		$w = '';
		// Usar cache para nao acessar banco de dados
		if (isset($_SESSION['nwx_usr']) && $_SESSION['nwx_usr']) {
			$w = 'and ordem > 0'; 
			if (isset($_SESSION['nwx_etc']['pgs'][NWX_SIS]) && $_SESSION['nwx_etc']['pgs'][NWX_SIS]) {
				$this->tabs = $_SESSION['nwx_etc']['pgs'][NWX_SIS];
				return;
			}
			$_SESSION['nwx_etc']['pgs'] = array();
		}
		
		$this->tabs = array();
		
		$db = nwx_db::conexao();
		$aplic = NWX_SIS;
		
		if (!$db || !isset($_SESSION['nwx_usr']) || !$_SESSION['nwx_usr']) {
			$this->tabs[1] = array('Conexo', 'Conexo ao Sistema', array('0%','100%','','',''));
			return; 
		}
		
		$st = "select * from nw_mnu where aplic = '$aplic' and pai is null $w order by ordem,id";
		$rs = $db->execute($st);
		while (!$rs->EOF) {
      if ($rs->fields['modulo'] == '1') {
        $rs->MoveNext();
        continue;
      }
			$id = $rs->fields['id'];
			// Se definiu funcao de acesso adicional
			if (defined('NWX_MNU_ACESSO')) {
				$acesso = NWX_MNU_ACESSO;
				include_once(NWX_BAS . DIRECTORY_SEPARATOR . $acesso . ".php");
				if (!$acesso($id)) {
					$rs->MoveNext();
					continue;
				}
			}
			$txt = $rs->fields['texto'];
			$des = $rs->fields['descricao'];
			$cols = array();
			$cols[] = $rs->fields['col0'];
			$cols[] = $rs->fields['col1'];
			$cols[] = $rs->fields['col2'];
			$cols[] = $rs->fields['col3'];
			$cols[] = $rs->fields['col4'];
			$this->tabs[$id] = array($txt, $des, $cols); 
			if (isset($_SESSION['nwx_usr']) && $_SESSION['nwx_usr']) {
				$_SESSION['nwx_etc']['pgs'][NWX_SIS][$id] = array($txt, $des, $cols); 
			}
			$rs->MoveNext();
		}

	}

	/**
	 * Cria a lista de blocos fixos  
	 */
	function fixos() {
		
		// Se usuario logado, usar cache para nao acessar banco de dados
		if (isset($_SESSION['nwx_usr'])) {
			if (isset($_SESSION['nwx_etc']['fix'][NWX_SIS]) && $_SESSION['nwx_etc']['fix'][NWX_SIS]) {
				$this->fixos = $_SESSION['nwx_etc']['fix'][NWX_SIS];
				return;
			}
			$_SESSION['nwx_etc']['fix'] = array();
		}
		
		$db = nwx_db::conexao();
		$aplic = NWX_SIS;

		if (!$db || !isset($_SESSION['nwx_usr']) || !$_SESSION['nwx_usr']) {
			if (!defined('NWX_LOGIN_BLOCK')) define('NWX_LOGIN_BLOCK', 'nw_login');
      $this->fixos[1][1][0] = NWX_LOGIN_BLOCK; 
			return;
		}		
		
		// Le os registros ativados para todas as paginas (aba = 0)
		$st = "select * from nw_fix where aplic = '$aplic' and aba = 0"; //order by cln, seq, aba desc
		$rs = $db->execute($st);
		while (!$rs->EOF) {
			foreach ($this->tabs as $t => $c) {
				$tab = $t;
				$col = $rs->fields['cln'];
				$seq = $rs->fields['seq'];
				$blo = $rs->fields['bloco'];
				if (nwx_acesso::bloco($blo)) {
					$this->fixos[$tab][$col][$seq] = $blo;
					if (isset($_SESSION['nwx_usr'])) $_SESSION['nwx_etc']['fix'][NWX_SIS][$tab][$col][$seq] = $blo;
				}
			}
			$rs->MoveNext();
		}
				 
		// Le os registros com valores explicitos para a aba (pagina)
		$st = "select * from nw_fix where aplic = '$aplic' and aba <> 0"; //order by cln, seq, aba desc
		$rs = $db->execute($st);
		while (!$rs->EOF) {
			$tab = $rs->fields['aba'];
			$col = $rs->fields['cln'];
			$seq = $rs->fields['seq'];
			$blo = $rs->fields['bloco'];
			if (nwx_acesso::bloco($blo)) {
				$this->fixos[$tab][$col][$seq] = $blo; 
				if (isset($_SESSION['nwx_usr'])) $_SESSION['nwx_etc']['fix'][NWX_SIS][$tab][$col][$seq] = $blo;
			}
			$rs->MoveNext();
		}
		
	}

	/**
	 * Monta a linha de mensagem inferior 
	 */
	function mensagem() {
		
		return "Sistema de Teste";
	
	}

	/**
	 * Monta o rodape 
	 */
	function rodape() {
		
		return "Copyright&copy; 2005 - Gonalo Franco";
	
	}

	
	/**
	 * Retorna cabecalho
	 */
	function cabec() {
		
		return '&nbsp;';
	
	}

	/**
	 * Retorna pagina de fundo
	 */
	function home() {
		
		return '&nbsp;';
	
	}

	/**
	 * Retorna os estilos aceitos
	 */
	function estilos() {
		
		return array('bns' => _('Bsico')
								,'nwx' => _('Padro Azul')
								,'nwxg' => _('Padro Verde')
								);
	
	}

	/**
	 * Retorna as linguas aceitas
	 */
	function locales() {
		
		return array('pt_BR' => 'Portugus');
	
	}
	
} //class nwx_nwpag 
// vim:et:sw=2:ts=2:nowrap:
