<?php
/**
 * Montagem das paginas HTML de um aplicativo
 *
 * @author Gonalo Franco
 * @version $Id: nwx_pag.php 925 2007-01-12 22:16:24Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx.php");
if (!defined('NWX_EMPRESAS')) {
	define('NWX_EMPRESAS', false);
	$_SESSION['nwx_adm2'] = 0;
	$_SESSION['nwx_sec2'] = 0;
}
if (!isset($_SESSION['nwx_adm2'])) {
	$_SESSION['nwx_adm2'] = 0;
	$_SESSION['nwx_sec2'] = 0;
}

/**
 * Classe abstrata para criaao e controle de paginas
 */
abstract class nwx_pag {

	public $copyright;
	public $descricao;
	public $conexao;
	public $licenciado;
	public $serie;

	public $tabs;
	public $colunas;
	public $fixos;
	public $blocos;
	public $obj_blocos;
	public $estilo;
	public $titulo;
	
	/**
	 * Construtor - Cria a pagina
	 *
	 * @param $titulo Titulo da pagina
	 */
	function __construct($titulo = '') {

		if (isset($_GET['logout']) || 
		(isset($_SESSION['nwx_rdx']) && NWX_RDX != $_SESSION['nwx_rdx'])) {
			$this->logout();
			nwx_repaginar();
		}

		$tabs = array();
		$colunas = array();
		$fixos = array();
		$blocos = array();
		$this->titulo = $titulo;
		$this->copyright = '';
		$this->descricao = '';
		$this->licenciado = '';
		$this->serie = '';
		$this->conexao = phpversion();

	}

	/**
	 * Construtor - Cria a pagina
	 *
	 * @param $titulo Titulo da pagina
	 */
	function logout() {

		nwx_db::audita('Desconexo');
		$chaves = array();
		foreach ($_SESSION as $key => $valor) {
			if (substr($key,0, 4) == 'nwx_' || strpos($key, NWX_SIS) == 0) {
				$chaves[] = $key;
			}
		}
		foreach ($chaves as $key) {
			unset($_SESSION[$key]);
		}
		$_SESSION['nwx_logout'] = 1;
		$_SESSION['nwx_uex'] = 1;
		
	}

	/**
	 * Processa a montagem da pagina 
	 */
	function monta() {

		if (isset($_GET['err'])) {
			nwx_alerta($_GET['err']);
		}
		// Verifica se ativou algum controle de quadro :
		// Fechamento de quadro
		if (isset($_GET['blc']) and isset($_GET['x'])) {
			// Se for um grid, procura e limpa na sessao
			if (isset($_SESSION[NWX_SIS . '_grid']) && is_array($_SESSION[NWX_SIS . '_grid'])) {
				foreach ($_SESSION[NWX_SIS . '_grid'] as $k => $a) {
					if ($a['gid'] == $_GET['blc'] && $a['gtb'] == $_SESSION[NWX_SIS . '_tab']) {
						nwx_fecha_grid($k);
					}
				}
			}
			// Procura por sub-blocos
			if (isset($_SESSION[NWX_SIS . '_tab']) && isset($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']]) && is_array($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']])) {
				foreach ($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']] as $k => $b) {
					if ($b == $_GET['blc']) {
						foreach ($_SESSION[NWX_SIS . '_grid'] as $g => $a) {
							if ($a['gid'] == $k && $a['gtb'] == $_SESSION[NWX_SIS . '_tab']) {
								nwx_fecha_grid($g);
							}
						}
					nwx_fecha_bloco($k);
					}
				}
			}
			if (!isset($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']]))
				unset($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']]);
			if (isset($_SESSION[NWX_SIS . '_det']) && count($_SESSION[NWX_SIS . '_det']) == 0)
				unset($_SESSION[NWX_SIS . '_det']);
			// Fecha o quadro
			nwx_fecha_bloco($_GET['blc']);
			nwx_repaginar();
			exit;
		// Minimizacao
		} elseif (isset($_GET['blc']) and isset($_GET['m'])) {
			$_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']][$_GET['blc']][2] =  1;
			nwx_repaginar();
			exit;
		// Maximizacao ou restauracao
		} elseif (isset($_GET['blc']) and isset($_GET['s'])) {
			$k = $_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']][$_GET['blc']][2];
			if ($k > 0)
				$_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']][$_GET['blc']][2] = 0;
			else
				$_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']][$_GET['blc']][2] = 2;
			nwx_repaginar();
			exit;
		}

		// Le o estilo corrente
		if (!isset($_SESSION['nwx_estilo'])) {
			if (isset($_COOKIE['nwx_estilo']))
				$_SESSION['nwx_estilo'] = $_COOKIE['nwx_estilo'];
			else {
				$_SESSION['nwx_estilo'] = $this->estilo;
				setcookie('nwx_estilo',$this->estilo,time()+NWX_COOKIE);
			}
		}
		$css = $_SESSION['nwx_estilo'];
		$this->estilo = '/nwx/estilos/' . rtrim($css) . '/' . rtrim($css) . ".css";

		// Monta tabs
		$this->paginas();

		// Blocos Fixos
		$this->fixos();
		
		// Coloca fixos no array de blocos
		foreach ($this->fixos as $t => $ac) {
			// Apenas se tiver menu e com alguma opcao liberada
			if (nwx_acesso::menu($t)) {
				foreach ($ac as $c => $as) { 
					foreach ($as as $s => $b) {
						$this->blocos[$t][$c][$s] = array($b, 0, array()); 
					}
				}
			}
		} 
		
		// Se nao tem nenhum bloco: usuario sem acesso
		if (!is_array($this->blocos)) {
			$this->logout();
			nwx_repaginar("?err=Usurio sem acesso s pginas");
			return;
		}

		// Verifica paginas sem blocos
		$sb = array();
		foreach ($this->tabs as $t => $p) {
			if (!array_key_exists($t, $this->blocos)) {
				$sb[] = $t;
			}
		}
		
		// Exclui paginas sem blocos
		foreach ($sb as $t) {
			if (isset($this->tabs[$t])) unset($this->tabs[$t]);
		}
		
		// Se nao tem nenhum bloco: usuario sem acesso
		if (!isset($this->tabs)) {
			$this->logout();
			nwx_repaginar("?err=Usurio sem acesso s pginas");
			return;
		}
		
		// Encontra a primeira tab (pagina)
		foreach($this->tabs as $k => $v){
			$pritab = $k;
			break;
		}
		// Se nao tem na sessao, assume a primeira
		if (!isset($_SESSION[NWX_SIS . '_tab'])) {
			$_SESSION[NWX_SIS . '_tab'] = $pritab;
		}
		// Se especificou pagina, assume
		$a = isset($_GET['tab']) && is_numeric($_GET['tab']) ? $_GET['tab'] : 0; 
		if ($a) $_SESSION[NWX_SIS . '_tab'] = $a;
		// Verifica se valor especificado e' valido
		$ok = false;
		foreach($this->tabs as $k => $v){
			if ($_SESSION[NWX_SIS . '_tab'] == $k) {
				$ok = true;
				break;
			}
		}
		// Se valor invalido, assume a primeira
		if (!$ok) {    
			$_SESSION[NWX_SIS . '_tab'] = $pritab;
		}
		
		$tab = $_SESSION[NWX_SIS . '_tab'];

		// Verifica se as opcoes GET (blc,col,seq) sao consistentes
		if (isset($_SESSION[NWX_SIS . '_tab']) and !isset($this->blocos[$_SESSION[NWX_SIS . '_tab']]))
			unset($_GET['col']);
		if (isset($_GET['col']))
			if (!is_numeric($_GET['col']))
				unset($_GET['col']);
		if (isset($_GET['seq']) and !is_numeric($_GET['seq']))
			unset($_GET['seq']);
		if (isset($_GET['sta']) and !is_numeric($_GET['sta']))
			unset($_GET['sta']);
		if (isset($_GET['sta']) and ($_GET['sta'] < 0 or $_GET['sta'] > 2))
			unset($_GET['sta']);

		// Se link inclui bloco que ja esta incluido na sessao, excluir para ele ir para o topo  
		if (isset($_GET['blc']) && isset($_GET['col']) && isset($_SESSION[NWX_SIS . '_abre'][$tab])) {
			$_blc = $_GET['blc'];
			foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $pos) {
				if ($blo == $_blc) {
					unset($_SESSION[NWX_SIS . '_abre'][$tab][$blo]);
				}
			}
		}
				
		// Se link especificou bloco e posicao, inclui o bloco nomeado
		if (isset($_GET['blc']) && nwx_acesso::bloco($_GET['blc'])) {
			$opc = array();
			$_s = 0;
			$_c = 1;
			$_n = 10;
			foreach ($_GET as $key => $val) {
				if ($key == 'blc') {
					$_b = $val;
				} elseif ($key == 'sta') {
					$_s = $val;
				} elseif ($key == 'col') {
					$_c = $val;
				} elseif ($key == 'seq') {
					$_n = $val;
				} else {
					$opc[$key] = $val; 
				}
			}
			$this->blocos[$tab][$_c][$_n] = array($_b,$_s,$opc);
			$_SESSION[NWX_SIS . '_abre'][$tab][$_b] = array($_c,$_n,$_s,$opc);
		}

		// Se sessao guardou algum bloco, inclui-lo
		if (isset($_SESSION[NWX_SIS . '_abre'][$tab])) {
			foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $pos) {
				// Variavel tmp : janela temporaria
				if (!array_key_exists('tmp',$pos[3]))
					$this->blocos[$tab][$pos[0]][$pos[1]] = array($blo,$pos[2],$pos[3]);
			}
		}
		
		// Lay-out de colunas
		foreach ($this->blocos[$tab] as $cl => $val) {
			$this->colunas[$tab][$cl] = '';
		}
		$cl = 0;
		foreach ($this->tabs[$tab][2] as $val) {
			if (isset($this->colunas[$tab][$cl])) $this->colunas[$tab][$cl] = $val;
			++$cl;
		}
		
		// Percorre todos os blocos na pagina, procurando por algum maximizado
		// Se encontrar, tira os demais e troca por este em coluna unica
		foreach ($this->blocos[$tab] as $k => $c) {
			foreach ($c as $s => $b) {
				if ($b[1] == 2) {
					// Limpar colunas e blocos e refazer o bloco com a mesma posicao
					unset($this->colunas);
					unset($this->blocos);
					$this->colunas[$tab][$k] = '';
					$this->blocos[$tab][$k][$s] = array($b[0],$b[1],$b[2]);
					break 2;
				} elseif ($b[1] == 1) {
					$this->blocos[$tab][$k][$s][1] = 1;
					break 2;
				}
			}
		}

		// Carrega os blocos de seus arquivos php
		foreach ($this->blocos[$tab] as $k => $cl) {
			foreach ($cl as $s => $blo) {
				$classe = $blo[0];
				// Verifica se pode encontrar o arquivo da classe
				if (file_exists(NWX_BAS . '/'  . "$classe.php")) {
					$pclass = NWX_BAS;
				} elseif (file_exists(NWX_DIR . '/'  . "$classe.php")) {
					$pclass = NWX_DIR;
				} else {
					$pclass = '';
				}
				// Encontrou definicao no disco: cria bloco
				if ($pclass) {
					require_once("$pclass/$classe.php");
					$this->obj_blocos[$tab][$k][$s] = new $classe($classe);
					$this->obj_blocos[$tab][$k][$s]->estado = $this->blocos[$tab][$k][$s][1];
					$this->obj_blocos[$tab][$k][$s]->tab = $tab;
					$this->obj_blocos[$tab][$k][$s]->col = $k;
					$this->obj_blocos[$tab][$k][$s]->seq = $s;
					$this->obj_blocos[$tab][$k][$s]->pag = $this;
				// Nao encontrou: usao bloco nwx_nob
				} else {
					require_once("nwx_nob.php");
					$this->obj_blocos[$tab][$k][$s] = new nwx_nob($classe);
					$this->obj_blocos[$tab][$k][$s]->estado = $this->blocos[$tab][$k][$s][1];
					$this->obj_blocos[$tab][$k][$s]->tab = $tab;
					$this->obj_blocos[$tab][$k][$s]->col = $k;
					$this->obj_blocos[$tab][$k][$s]->seq = $s;
					$this->obj_blocos[$tab][$k][$s]->pag = $this;
				}
					
			}
		}
		
	}

	/**
	 * Prepara janela sobre sistema
	 *
	 * @return String com link para janela 'Sobre'
	 */
	function sobre() {

		$dom = textdomain(null);
		textdomain('nwx');
		$dat = $this->conexao;
		$copyr = $this->copyright;
		$descricao = $this->descricao;
		$nomes = explode(" ",$copyr);
		$nome = $nomes[0];
		$lic = $this->licenciado;
		$ser = $this->serie;
		$sess = nwx::$_session;
		if ($sess == 'Cache') {
			$sta = nwx_session_mc::status();
		} else {
			$sta = '';
		}
		$sis = strtoupper(NWX_SIS);
		
		if (defined('NWX_VER') && NWX_VER) {
			$cpl = NWX_VER;
		} else {
			$cpl = 'N/A';
		}
		
		$t = "<table width=\"100%\" height=\"260\" cellpadding=\"10\" cellspacing=\"0\">" .
				 "  <tr>" .
				 "    <td bgcolor=\"#eeeeee\" height=\"80\">" .
				 "      <table cellpadding=\"0\" cellspacing=\"0\" width=\"95%\" align=\"center\">" .
				 "        <tr>" .
				 "          <td><font face=\"Times New Roman, Garamond, Times\" size=\"8\" color=\"#9999cc\">{$nome}&nbsp;<font color=\"#dd6666\">$sis</font></font></td>" .
				 "          <td align=\"right\"><font size=\"4\" face=\"Verdana, Arial\" color=\"#999999\">&nbsp;</font></td>" .
				 "        </tr>" .
				 "        <tr>" .
				 "          <td align=\"right\" colspan=\"2\"><font face=\"Verdana, Arial\" size=\"1\" color=\"#333333\">$descricao</font></td>    " .
				 "        </tr>" .
				 "      </table>" .
				 "    </td>" .
				 "  </tr>" .
				 "  <tr>" .
				 "    <td style=\"font-family:arial;font-size:10px;vertical-align:top;\">" .
				 "      Copyright &copy; $copyr<BR>"._("Todos os direitos reservados").".<br><br>" .
				 "      "._("Licenciado para")." <b>$lic</b><br>" .
				 "      "._("Nr.Srie")." <b>$ser</b><br>" .
				 "      "._("Verso")." <b>$cpl</b><br>" .
				 "    </td>" .
				 "  </tr>" .
				 "  <tr>" .
				 "    <td bgcolor=\"#eeeeee\" height=\"20\">" .
				 "      <table cellpadding=\"0\" cellspacing=\"0\" width=\"100%\">" .
				 "        <tr>" .
				 "          <td style=\"font-family:verdana;font-size:10px;vertical-align:top;text-align:left;\">"._("Conexo:")." $dat</td>" .
				 "        </tr>" .
				 "        <tr>" .
				 "          <td style=\"font-family:verdana;font-size:10px;vertical-align:top;text-align:left;\">"._("Sesses:")." $sess $sta</td>" .
				 "        </tr>" .
				 "      </table>" .
				 "    </td>" .
				 "  </tr>" .
				 "</table>";
		 
		$t = htmlentities($t);
		$a = "<a href=\"javascript:void(0);\" onmouseover=\"" .
				 "overlib('$t'," .
				 "TEXTFONT,'Arial'," .
				 "TEXTSIZE,'12px'," .
				 "WIDTH,'420'," .
				 "DELAY,250," .
				 "HAUTO,VAUTO" .
				 ");return true;\" " .
				 "onmouseout=\"nd();\">";

		textdomain($dom);
		return $a;

	}

	/**
	 * Monta cabecalho da pagina
	 */
	function monta_cabec($tab) {
		$dom = textdomain(null);
		textdomain(NWX_SIS);
		$cabec = $this->cabec();
		//@include_once(NWX_BAS . "/" . NWX_SIS . "_cabec.php");
		$cab = "<!-- Cabecalho -->\n"   
					. "<tr><td class=\"cabec\" colspan=\"2\">$cabec</td></tr>"  
					. "<tr><td class=\"menu\" colspan=\"2\">"  
				 . "<!-- Menu principal -->"
				 . "<ul class=\"tablista\">";
		$pag = NWX_RDX.NWX_APL.'/'.NWX_IDX;
		foreach ($this->tabs as $t => $item) {
			$k = "<a href=$pag?tab=$t>"._($item[0])."</a>";
			if ($t != $tab) {
				$c = "tab";
				$j =  "onmouseover=\"nwliover(this);status='$item[1]';return true;\" onmouseout=\"nwliout(this);status='';\"";
			} else {
				$c = "tabsel";
				$j =  "onmouseover=\"status='$item[1]';return true;\"";
			}
			$cab .= "<li class=\"$c\" $j>$k</li>\n";
		}
		$cab .= "</ul></td></tr>\n";
		textdomain($dom);
		return $cab;
	}
	
	/**
	 * Monta linha de mensagem superior da pagina
	 */
	function msg1($tab) {
		
		$dom = textdomain(null);
		textdomain('nwx');
		// Prepara janela de informaoes do usuario
		if (isset($_SESSION['nwx_usr'])) {
			$h = "<span class=\"etiq\">"._("Usurio").": </span><span class=\"texto\">" . $_SESSION['nwx_nom'] . "</span><br>" .
					 "<span class=\"etiq\">"._("Data/Hora").": </span><span class=\"texto\">" . $_SESSION['nwx_ini'] . "</span>";
			if (isset($_SESSION['nwx_emp']) && NWX_EMPRESAS) {
				$emps = explode(':', NWX_EMPRESAS);
				$h .= "<br><span class=\"etiq\">"._("Empresa").": </span><span class=\"texto\">" . trim($emps[$_SESSION['nwx_emp']]) . "</span>";
			}
			if ($_SESSION['nwx_adm']) {
				$h .= "<br><span class=\"texto\"><img align=\"absmiddle\" src=\"/nwx/img/tchk.png\"> "._("Administrador do Sistema")."</span>";
			} else if ($_SESSION['nwx_adm2']) {
				$h .= "<br><span class=\"texto\"><img align=\"absmiddle\" src=\"/nwx/img/tchk.png\"> "._("Administrador do Sistema (Empresa)")."</span>";
			}
			if ($_SESSION['nwx_sec']) {
				$h .= "<br><span class=\"texto\"><img align=\"absmiddle\" src=\"/nwx/img/tchk.png\"> "._("Administrador de Segurana")."</span>";
			} else if ($_SESSION['nwx_sec2']) {
				$h .= "<br><span class=\"texto\"><img align=\"absmiddle\" src=\"/nwx/img/tchk.png\"> "._("Administrador de Segurana (Empresa)")."</span>";
			}
			if (@$_SESSION['nwx_uex']) {
				$h .= "<br><span class=\"texto\"><img align=\"absmiddle\" src=\"/nwx/img/tchk.png\"> "._("Autenticao interna")."</span>";
			} else {
				$h .= "<br><span class=\"texto\"><img align=\"absmiddle\" src=\"/nwx/img/tchk.png\"> "._("Pr-autenticado")."</span>";
			}
			$h = htmlentities($h);
			$a = "<a href=\"javascript:void(0);\" onmouseover=\"return " .
				 "overlib('$h'," .
				 "TEXTFONT,'Arial'," .
				 "TEXTSIZE,'12px'," .
				 "WIDTH,'240'," .
				 "DELAY,250," .
				 "CAPTION,'"._('Detalhes da Conexo')."'," .
				 "HAUTO,VAUTO" .
				 ");\"" .
				 "onmouseout=\"nd();\">";
		}
		// Se conectado, mostra icones de usuario, senha, preferencias, lista de usuarios e saida
		if (isset($_SESSION['nwx_usr'])) {
			// Se for usuario interno: permite alterar senha
			if (@$_SESSION['nwx_uex']) {
				$sen = "<a ".nwx_ttip(_("Alterar sua senha"))."href=\"".NWX_RDX.NWX_APL."/".NWX_IDX."?blc=nwx_senha&col=0&seq=1&ico=lock_icon.gif&tmp\"><img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/lock_icon.gif\"></a>&nbsp;"; 
			} else {
				$sen = "";
			}
			// Opcao de alterar preferencias
			if (NWX_PREFS) {
				$prf = "<a ".nwx_ttip(_("Estilos/Preferncias"))."href=\"".NWX_RDX.NWX_APL."/".NWX_IDX."?blc=nwx_prefs&col=0&seq=1&ico=accept.gif&tmp\"><img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/accept.gif\"></a>&nbsp;"; 
			} else {
				$prf = "";
			}  
			// Opcao de desconectar
			if (NWX_LOGOUT) {
				$dcn = "<a ".nwx_ttip(_("Desconectar"))."href=\"".NWX_RDX.NWX_APL."/".NWX_IDX."?logout\"><img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/close1.gif\"></a>&nbsp;"; 
			} else {
				$dcn = "";
			}  
			
			$ic = "<span class=\"texto\" style=\"float:right;\">"
					. $a . "<img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/user.gif\"></a>&nbsp;" 
					. $sen 
					. $prf 
					//. "<a ".nwx_ttip("Usurios conectados")."href=\"/".NWX_APL."/".NWX_IDX."?blc=nwx_usrls&col=1&seq=1&ico=group.gif&tmp\"><img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/group.gif\"></a>&nbsp;" 
					. $dcn
					. $this->sobre() . "<img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/sobre.gif\"></a>&nbsp;" 
					. "&nbsp;</span>";
		// Se nao esta conectado, nao mostra nada
		} else {
			$ic = "<span class=\"texto\" style=\"float:right;\">" 
					. $this->sobre() . "<img border=\"none\" align=\"absmiddle\" src=\"/nwx/img/sobre.gif\"></a>&nbsp;" 
					. "&nbsp;&nbsp;</span>";
		}

		textdomain(NWX_SIS);
		// Monta a linha, com texto sobre a pagina e icones de informacoes
		$usr = '';
		$val = "<!-- Linha de mensagem superior -->\n"  
				 . "<tr><td class=\"msg\" nowrap>\n"  
				 . _($this->tabs[$tab][1])
				 . "</td><td class=\"msg\" nowrap>" 
				 . $ic
				 . "</td></tr>";
		//if (nwx_mensagens()) {
		//  textdomain('nwx');
		//  $val .= "<tr>"
		//       . "<td colspan=\"2\" style=\"padding:4px;background-color:#ccc;width:100%;font-family:arial;font-size:12px;;font-weight:bold\">"
		//       . _("Voc tem novas mensagens em sua caixa de entrada")
		//       . "</td>"
		//       . "</tr>";
		//}
		textdomain($dom);
		return $val;

	}

	/**
	 * Monta corpo principal da pagina
	 */
	function corpo($tab) {

		echo "<!-- Corpo da pagina -->\n"
				 . "<tr><td class=\"corpo\" colspan=\"2\">\n"
				 . "<table cellspacing=\"0\" class=\"layout\"><tr>\n";

		// Corpo da pagina
		if (is_array($this->colunas)) {
			if (in_array($tab,array_keys($this->colunas))) {
				ksort($this->colunas[$tab]);
				foreach ($this->colunas[$tab] as $n => $val) {
					if ($val) {
						$ccl = "style=\"$val\"";
					} else {
						$ccl = '';
					}
					echo "<td class=\"coluna$n\" $ccl>\n";
					// echo "<td width=\"$val\" class=\"coluna$n\">\n";
					// Conteudo da coluna
					if (in_array($tab,array_keys($this->obj_blocos)) && is_array($this->obj_blocos[$tab])) {
						if (isset($this->obj_blocos[$tab][$n]) && is_array($this->obj_blocos[$tab][$n])) {
							ksort($this->obj_blocos[$tab][$n]);
							foreach ($this->obj_blocos[$tab][$n] as $blc)
								$blc->mostra();
						}
					}
					echo "</td>\n";
				}
			}
		} else {
			echo '<td>&nbsp;</td>';
		}

		echo "</tr></table>\n";
		echo "</td></tr>";  
		return true;

	}

	/**
	 * Monta linha de mensagem inferior da pagina
	 */
	function msg2($tab) {

		if (isset($_SESSION['nwx_emp']) && NWX_EMPRESAS) {
			$emps = explode(':',NWX_EMPRESAS);
			$emp = ' - '. $emps[$_SESSION['nwx_emp']];
		} else {
			$emp = '';
		}
		$val = "<!-- Linhe de mensagem inferior -->\n"  
				 . "<tr><td class=\"fim\" colspan=\"2\">\n"   
				 . $this->mensagem() . $emp
				 . "</td></tr>";
		return $val;  

	}

	/**
	 * Monta rodape da pagina
	 */
	function rdp($tab) {

		$val = "<!-- Rodape -->\n"  
				 . "<tr><td class=\"rodape\" colspan=\"2\">\n"  
				 . $this->rodape()
				 . "</td></tr>";
		return $val;  
		
	}
	
	/**
	 * Mostra a pagina montada
	 */
	function mostra() {

		// Monta os blocos da pagina
		$this->monta();
		
		$_SESSION['nwx_apl'] = NWX_APL;

		$tab =  $_SESSION[NWX_SIS . '_tab'];

		$css2 = "";
		$css1 = NWX_RDX.NWX_APL."/".NWX_SIS.".css";
		$css2 = "<link rel=\"stylesheet\" href=\"$css1\">";
		$css3 = "";
		if (defined('NWX_REF')) { 
			$css1 = NWX_RDX.NWX_REF."/".NWX_REF.".css";
			$css3 = "<link rel=\"stylesheet\" href=\"$css1\">";
		}
			
		$cabec = $this->monta_cabec($tab);
		$msg1 = $this->msg1($tab);
		$msg2 = $this->msg2($tab);
		$rdp = $this->rdp($tab);

		$alr = "";
		if (isset($_SESSION['nwx_alr']) && !empty($_SESSION['nwx_alr'])) {
			$alr = "<script language=\"javascript\">alert('".$_SESSION['nwx_alr']."');</script>";
			unset($_SESSION['nwx_alr']);
		}
		$alr .= "<script language=\"javascript\">nwx_wmsg(false, false);</script>";

		$est2 = $this->estilo ? "<link rel=\"stylesheet\" href=\"$this->estilo\">" : "";
		$_cc = strtolower(substr($_SESSION['nwx_locale'], 0, 2));
		if ($_cc == 'pt') $_cc = 'br';
		
		// Mostra a pagina
		//<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">
		//<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">
		//<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">
		<html>
			<head>
				<meta http-equiv=\"content-type\" content=\"text/html;charset=ISO-8859-1\" />
				<title>$this->titulo</title>
				<link rel=\"stylesheet\" href=\"/nwx/jscript/jscalendar-1.0/calendar-blue.css\">
				<link rel=\"stylesheet\" href=\"/nwx/jscript/dhtmlxtree/dhtmlxtree.css\">
				<link rel=\"stylesheet\" type=\"text/css\" href=\"/nwx/jscript/yui/build/fonts/fonts-min.css\" />
				<link rel=\"stylesheet\" type=\"text/css\" href=\"/nwx/jscript/yui/build/container/assets/skins/sam/container.css\" />
				$est2
				$css2
				$css3
				<script type=\"text/javascript\" src=\"/nwx/jscript/yui/build/utilities/utilities.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/yui/build/container/container-min.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/TreeMenu.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/nwx_util.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/nwx_lov.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/tigra_tables.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/overlib.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/overlib_hideform.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/flexgrid.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/nwx_ajax.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/jscalendar-1.0/calendar.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/jscalendar-1.0/lang/calendar-$_cc.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/jscalendar-1.0/calendar-setup.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/prototype.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/dhtmlxtree/dhtmlxcommon.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/dhtmlxtree/dhtmlxtree.js\"></script>
				<script type=\"text/javascript\" src=\"/nwx/jscript/dhtmlxtree/ext/dhtmlxtree_xw.js\"></script>
		</head>
			<body topmargin=\"0\" bottommargin=\"0\" leftmargin=\"0\" tightmargin=\"0\" class=\"yui-skin-sam\">
			<div id=\"overDiv\" style=\"position:absolute;visibility:hidden;z-index:1000;\"></div>
			<div id=\"wmsg\" style=\"position:absolute;width:180px;height:140px;font-size:11px;font-weight:bold;font-family:verdana;text-align:center;vertical-align:middle;visibility:hidden;z-index:1000;background-color:#fff;color:#000;\"><br><br>Processando<br><br>Aguarde...<br><br><img src=\"/nwx/img/progress.gif\"></div>
			<table class=\"corpo\" width=\"100%\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\">
			$cabec \n
			$msg1  \n
			";
			 
		$this->corpo($tab);

		echo "
			$msg2 \n
			$rdp \n   
			</table>\n  
			$alr \n
			</body>
			</html>
		";  
		
	}

	/**
	 * Retorna as paginas tab  
	 */
	abstract function paginas();
	/**
	 * Retorna os blocos fixos
	 */
	abstract function fixos();
	/**
	 * Retorna cabecalho
	 */
	abstract function cabec();
	/**
	 * Retorna pagina de fundo
	 */
	abstract function home();
	/**
	 * Retorna linha de mensagem inferior
	 */
	abstract function mensagem();
	/**
	 * Retorna rodape
	 */
	abstract function rodape();
	/**
	 * Retorna estilos
	 */
	abstract function estilos();
	/**
	 * Retorna locales
	 */
	abstract function locales();

	
} //class nwx_pag
// vim:et:sw=2:ts=2:nowrap:
