<?php
/**
 * Alteracao da senha do usuario no login
 *
 * @file nwx_senha_login.php
 * @author Gonalo Franco
 * @version $Id$
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");

/**
 * Define formulario para alterar senha
 */
class nwx_senha_login_form extends nwx_form {

	/**
	 * Carrega valores iniciais
	 */
	function carrega() {
		$this->valor('usuario','');
		$this->valor('senha_ant','');
		$this->valor('senha_1','');
		$this->valor('senha_2','');
	}

	/**
	 * Verifica se entradas corretas
	 */
	function verifica() {

		$usr = strtoupper($this->post('usuario'));
		$min = nwx_param('PASS_MIN');
		$cpx = nwx_param('PASS_CPLX');
		$mc = $cpx == '2' ? ' '._('(maisculas e minsculas)') : '';
		
		$senha_ant = $this->post('senha_ant');
		$senha_1 = $this->post('senha_1');
		$senha_2 = $this->post('senha_2');

		// Senha 1 nao bate com senha 2
		if ($senha_1 != $senha_2) {
			$this->erro(_('Senha 1 e 2 diferentes'));
		}
		// Se tem funcao de login/senha customizados
		if (defined('NWX_EXT_LOGIN') && NWX_EXT_LOGIN) {
			if (file_exists(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_LOGIN . ".php")) {
				return;
			}
		}
		
		$db = nwx_db::conexao();
		$stmt = "select senha, bloq from nw_usr where usr = ?";
		
		$rs = $db->execute($stmt, array($usr));
		if (!$rs->EOF && $rs->fields['bloq']) {
			$this->erro(_('Usurio bloqueado'));
		} else if ($rs->EOF || trim($rs->fields['senha']) != trim(md5($senha_ant))) {
			$this->erro(_('Senha anterior ou cdigo do usurio incorretos'));
		}

		// Senha muito simples
		if (nwx_ssen($usr, $senha_1)) {
			$this->erro(_("Senha deve no mnimo {$min} caracteres e conter letras{$mc}, digitos e pontuao"));
		}
			
		// Senha repetida  
		if (nwx_rsen($usr, $senha_1)) {
			$this->erro(_("Senha j foi usada recentemente"));
		}
		
	}

	/**
	 * Processa alteracao
	 */
	function processa($_sair) {

		$usr = strtoupper($this->post('usuario'));
		$senha_ant = $this->post('senha_ant');
		$senha = $this->post('senha_1');
		// Se tiver funcao extendida de login e senhas: usa-la para fazer a conexao
		if (defined('NWX_EXT_LOGIN') && NWX_EXT_LOGIN) {
			if (file_exists(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_LOGIN . ".php")) {
				include_once(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_LOGIN . ".php");
				if (function_exists('nwx_ext_senha')) {
					$mensagem = '';
					$erro = nwx_ext_senha($usr, $senha_ant, $senha, $mensagem);
					if ($erro) {
						$this->erro($mensagem);
					} else { 
						if ($mensagem) $_SESSION['nwx_alr2'] = $mensagem;
						$this->sair = true;
						nwx_repaginar();
					}
				}
				return;
			}
		}

		// Le parametros de seguranca
		$dias = nwx_param('PASS_EXP');
		if ($dias) {
			$nxsen = nwx_time::data_iso(nwx_time::soma_dias(date(nwx_time::date_format()), $dias));
		} else {
			$nxsen = null;
		}

		$db = nwx_db::conexao();
		if ($this->oper == 'ALT') {
			$stm = "update nw_usr set senha = ?, xsen = ? where usr = ?";
			$p = array(md5($senha)
								,$nxsen 
								,$usr
								);
			$this->sair = true;
		}

		if (isset($stm) && !$db->execute($stm,$p))
			$this->erro(nwx_db::erro());
		else {
			unset($_SESSION['nwx_xsen']);		
			$_SESSION['nwx_alr2'] = 'Sua senha foi alterada com sucesso';
			nwx_repaginar();
		}

	}

} //class nwx_senha_form

/**
 * Define quadro contendo formulario de senha
 */
class nwx_senha_login extends nwx_quadro {

	/**
	 * Construtor: ajusta o titulo e tipo
	 */
	function __construct($id) {
		
		textdomain('nwx');
		parent::__construct($id);
		$this->titulo = _("Alterar senha");
		$this->fixo = 1;

	}

	/**
	 * Monta o conteudo do quadro
	 */
	function monta() {
		
		$f0 = new nwx_form_text('usuario','C',20,0,false,false);
		$f1 = new nwx_form_pass('senha_ant','C',100,0,false,false);
		$f2 = new nwx_form_pass('senha_1','C',100,0,false,false);
		$f3 = new nwx_form_pass('senha_2','C',100,0,false,false);
		
		$f0->ajuda = _("Codigo do Usuario");
		$f1->ajuda = _("Senha anterior a alterar");
		$f2->ajuda = _("Nova Senha");
		$f3->ajuda = _("Repetir Senha para confirmao");
		
		$form = new nwx_senha_login_form("nwx_senha_login_form","nwx_senha_login");
		$form->oper = 'ALT';
		$form->reset = '';
		$form->salvar = '';
		$form->input($f0,_('Usurio'),'','size="20"',true);
		$form->input($f1,_('Anterior'),'','size="20"',true);
		$form->input($f2,_('Nova Senha'),'','size="20"',true);
		$form->input($f3,_('Repetir'),'','size="20"',false);
		$form->mostra();
	
	}

} //class nwx_senha_login
// vim:et:sw=2:ts=2:nowrap:
