<?php
/**
 * Controle de Sessoes no Banco de Dados
 *
 * Implementa o gerenciamento de sessoes em Banco de Dados<br>
 * Usa a biblioteca ADODB
 * 
 * @author Gonalo Franco
 * @version $Id$
 */

require_once("adodb/adodb.inc.php");

if (!defined('NWX_SESSIONS_LIFE')) define('NWX_SESSIONS_LIFE',3600);
if (!defined('NWX_SESSIONS_TAB')) define('NWX_SESSIONS_TAB','nw_sess');
if (!defined('NWX_SESSIONS_CPO')) define('NWX_SESSIONS_CPO','sessdata');
if (!defined('NWX_SESSIONS_KEY')) define('NWX_SESSIONS_KEY','sesskey');
if (!defined('NWX_SESSIONS_LIFE')) define('NWX_SESSIONS_LIFE',8000);

/**
 * Gerenciamento de sessoes
 * 
 * Implementa o gerenciamento de sessoes
 */
class nwx_session_db {

  static $dsn;
   
  /**
   * Conexao ao banco de dados
   */
  private function conexao() {

    static $db;

    if (isset($db)) {
      return $db;
    }
    if (!defined('ADODB_ASSOC_CASE')) define('ADODB_ASSOC_CASE',0);
    $db =& ADONewConnection(self::$dsn);
    $db->SetFetchMode(ADODB_FETCH_ASSOC);
    //$db->debug = true;
    $ADODB_COUNTRECS = false;
    return $db;

  }
  
  /**
   * Inicio do controle de sessao
   */
  function start($dsn) {

    static $roda = 0;
    
    self::$dsn = $dsn . '?persist';
    
    if (!self::conexao()) {
      return false;
    }
    
    // Preparar os gerenciadores
    session_set_save_handler(
        array('nwx_session_db', 'open_method'), 
        array('nwx_session_db', 'close_method'), 
        array('nwx_session_db', 'read_method'), 
        array('nwx_session_db', 'write_method'), 
        array('nwx_session_db', 'destroy_method'), 
        array('nwx_session_db', 'gc_method')
        );

    return true;
        
  }

  /**
   * Abre sessao 
   */
  function open_method($save_path, $session_name) {

    // Verifica conexao ao banco de dados
    if (!self::conexao()) {
      return false;
    }
    return true;
    
  }
    
  /**
   * Fecha sessao
   */
  function close_method() {

    $db = self::conexao();
    $db->close();
    return true;
    
  }
    
  /**
   * Leitura de variavel 
   */
  function read_method($id) {

    $db = self::conexao();
    $tab = NWX_SESSIONS_TAB;
    $cpo = NWX_SESSIONS_CPO;
    $chave = NWX_SESSIONS_KEY;

    $sql = "SELECT $cpo FROM $tab WHERE $chave = ? AND expiry >= ?";
    $rs = $db->execute($sql, array($id,time()));
    if ($rs) {
      if ($rs->EOF) {
        $v = '';
      } else {
        $v = reset($rs->fields);
        $v = rawurldecode($v);
      }
      $rs->Close();
      return $v;
    }

    return '';

  }
    
  /**
   * Gravacao de variavel
   */
  function write_method($id, $val) {

    // Conexao no BD
    $db = self::conexao();
    $tab = NWX_SESSIONS_TAB;
    $cpo = NWX_SESSIONS_CPO;
    $chave = NWX_SESSIONS_KEY;
    $life = NWX_SESSIONS_LIFE;
    
    // Parametros
    $expiry = time() + $life;
    $key = $db->quote($id);
    $val = rawurlencode($val);
    
    // Atualiza BD
    $rs = $db->Execute("select count(*) AS cnt from $tab where $chave = ?", array($id));
    if ($rs && reset($rs->fields) > 0) {
      $sql = "update $tab set expiry = ? where $chave = ?";
      $db->Execute($sql, array($expiry,$id));
    } else {
      $sql = "insert into $tab (expiry, $chave) VALUES (?, ?)";
      $db->Execute($sql, array($expiry,$id));
    }
    $db->UpdateBlob($tab, $cpo, $val, " $chave=$key", 'CLOB');
    return(true);

  }
    
  /**
   * Destruir sessao
   */
  function destroy_method($id) {

    $db = self::conexao();
    $tab = NWX_SESSIONS_TAB;
    $cpo = NWX_SESSIONS_CPO;
    $chave = NWX_SESSIONS_KEY;
    $life = NWX_SESSIONS_LIFE;
    $sql = "delete from $tab where $chave = ?";
    $rs = $db->execute($sql, array($id));
    if ($rs) $rs->Close();

    return $rs ? true : false;

  }
    
  /**
   * Coleta de lixo
   */
  function gc_method($maxlife = 0) {

    $db = self::conexao();
    $tab = NWX_SESSIONS_TAB;
    $sql = "delete from $tab where expiry < ?";
    $db->execute($sql, array(time()));

    return true;

  }
   
} //class nwx_session_db
// vim:et:sw=2:ts=2:nowrap:
