<?php
/**
 * Controle de Sessoes via memcache
 *
 * Implementaao do controle de sessoes em memcache
 * 
 * @author     Gonalo Franco
 * @version    $Id$
 */                                                        

if (!defined('NWX_SESSIONS_LIFE')) define('NWX_SESSIONS_LIFE',3600);
if (!defined('NWX_SESSIONS_HOST')) define('NWX_SESSIONS_HOST','localhost');
if (!defined('NWX_SESSIONS_PORT')) define('NWX_SESSIONS_PORT',11211);

/**
 * Gerenciamento de sessoes
 * 
 * Implementa o gerenciamento de sessoes
 */
class nwx_session_mc {

  static $memcache;
  static $sess;
     
  /**
   * Construtor
   * 
   * Construtor privado para implementar padrao singleton
   */
  static function start() { 

    // Verifica conexao ao servidor
    self::$memcache = new Memcache;
    if (!self::$memcache->connect(NWX_SESSIONS_HOST, NWX_SESSIONS_PORT)) {
      return false;
    }
    
    // Preparar os gerenciadores
    session_set_save_handler(
        array('nwx_session_mc', 'open'), 
        array('nwx_session_mc', 'close'), 
        array('nwx_session_mc', 'read'), 
        array('nwx_session_mc', 'write'), 
        array('nwx_session_mc', 'destroy'), 
        array('nwx_session_mc', 'gc')
        );
    
    return true;

  }

  /**
   * Abre sessao 
   * 
   * @param string $save_path Caminho
   * @param string $session_name Nome da sessao
   * @return boolean Se deu certo
   */
  static function open($save_path, $session_name) {

    if (!self::$memcache) {
      return false;
    }
    self::$sess = $session_name;
    return true;
    
  }
    
  /**
   * Fecha sessao
   * 
   * @return boolean
   */
  static function close() {

    self::$memcache->close();
    return true;
    
  }
    
  /**
   * Leitura de variavel
   * 
   * @param string $id Nome da variavel
   * @return mixed Conteudo da variavel 
   */
  static function read($id) {

    $var = self::$memcache->get(self::$sess.$id);

    if ($var !== false) {
      return $var;
    }
    return '';

  }
    
  /**
   * Gravacao de variavel
   * 
   * @param string $id Nome da variavel
   * @param mixed $val Conteudo
   * @return boolean
   */
  static function write($id, $val) {
    
    // Atualiza entrada no cache
    self::$memcache->delete(self::$sess.$id);
    if (self::$memcache->set(self::$sess.$id, $val, false, NWX_SESSIONS_LIFE)) {
      return true;
    }

    return false;

  }
    
  /**
   * Destruir sessao
   * 
   * @param string $id Id da sessao
   * @return boolean
   */
  static function destroy($id) {

    // Exclui entrada
    if (self::$memcache->delete(self::$sess.$id)) {
      return true;
    }

    return false;

  }
    
  /**
   * Coleta de lixo
   * 
   * @param int $maxlife Vida maxima da sessao
   */
  static function gc($maxlife = 0) {

    return true;

  }

  /**
   * Retorna status do Cache
   * 
   * @param string $id Nome da variavel
   * @return mixed Conteudo da variavel 
   */
  static function status() {

    $sta = self::$memcache->getExtendedStats();
    $ret = '[ ';
    foreach ($sta as $s => $item) {
      $ret .= "$s ";
      foreach ($item as $k => $v) {
        if ($k == 'bytes') {
          $ret .= "Bytes:$v ";
        }
        if ($k == 'version') {
          $ret .= "Ver:$v ";
        }
        if ($k == 'curr_connections') {
          $ret .= "Con:$v ";
        }
        
      }
      break;
    }
    $ret .= ']';
    return $ret;

  }
  
  
} // class nwx_session_mc
// vim:et:sw=2:ts=2:nowrap:
