<?php
/**
 * Funcoes para manutencao de datas/horas
 *
 * @file nwx_time.php
 * @author Gonalo Franco
 * @version $Id: nwx_time.php 924 2007-01-11 18:36:37Z goncalo $
 */

include_once('adodb/adodb-time.inc.php');

/**
 * Verificaao e manipulaao de datas/horas 
 */
class nwx_time {

  /**
   * Verifica se data valida
   *
   * @param $data String com data
   * @param $br Estilo d/m/a
   * @return Se data valida
   */
  static function data_valida($data, $br = false) {

    $p = explode(" ",$data);

    // Le o separador
    $s = !$br ? self::date_format('/') : '/';
     
    // Parte da data
    $d = explode($s,$p[0]);
    if (sizeof($d) != 3)
      return false;
    if (strlen($d[2]) != 4)
      return false;

    // Parte da hora (se houver)
    if (sizeof($p) > 1) {
      $h = explode(":",$p[1]);
      if (sizeof($h) > 3)
        return false;
      if (sizeof($h) == 2)
        $h[2] = 0;
      if (sizeof($h) == 1) {
        $h[1] = 0;
        $h[2] = 0;
      }
      if (!is_numeric($h[0]) || !is_numeric($h[1]) || !is_numeric($h[2]))
        return false;
      if ($h[0] < 0 || $h[0] > 23)
        return false;
      if ($h[1] < 0 || $h[1] > 59)
        return false;
      if ($h[2] < 0 || $h[2] > 59)
        return false;
    }
    $dia = !$br ? self::date_format('d') : 0;
    $mes = !$br ? self::date_format('m') : 1;
    $ano = !$br ? self::date_format('a') : 2;
    return checkdate($d[$mes],$d[$dia],$d[$ano]);

  }

  /**
   * Retorna data no formato ISO
   *
   * @param $data String ou numero com data
   * @param $ph boolean Mostra o componente hora:min
   * @return String com data no formato ISO
   */
  static function data_iso($data = '', $ph = true) {

    if ($ph) {
      $hora = ' H:i:s';
    } else {
      $hora = '';
    }
    
    // Se $data vazio
    if ($data == '')
      return adodb_date("Y-m-d$hora");

    // Se for inteiro ou float
    if (is_int($data) || is_float($data))
      return adodb_date("Y-m-d$hora", $data);
    
    if (!nwx_time::data_valida($data))
      return false;

    $df = self::date_format();
    $s = self::date_format('/');
    $dia = self::date_format('d');
    $mes = self::date_format('m');
    $ano = self::date_format('a');
    
    // Divide entre data e hora
    $p = explode(" ",$data);

    // Parte da data
    $d = explode($s,$p[0]);

    // Parte da hora (se houver)
    if (sizeof($p) > 1) {
      $h = explode(":",$p[1]);
      if (sizeof($h) == 2)
        $h[2] = 0;
      if (sizeof($h) == 1) {
        $h[1] = 0;
        $h[2] = 0;
      }
    } else {
      $h = array(0,0,0); 
    }
    if ($ph) {
      return $d[$ano] . '-' . $d[$mes] . '-' . $d[$dia] . ' ' .
             substr("00$h[0]",-2) . ':' .
             substr("00$h[1]",-2) . ':' .
             substr("00$h[2]",-2);
    } else {
      return $d[$ano] . '-' . $d[$mes] . '-' . $d[$dia];
    }
    
  }

  /**
   * Retorna data atual sem hora
   *
   * @return String com data no formato ISO
   */
  static function current_date() {
    return adodb_date('Y-m-d');
  }

  /**
   * Retorna data/hora atual
   *
   * @return String com data/hora no formato ISO
   */
  static function current_time() {
    return adodb_date('Y-m-d H:i:s');
  }
  
  /**
   * Retorna data no formato unix (de uma data br)
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function data_unix($data) {

    if (!nwx_time::data_valida($data))
      return false;

    $s = self::date_format('/');
    $dia = self::date_format('d');
    $mes = self::date_format('m');
    $ano = self::date_format('a');
    $df = self::date_format();
    
    $pos = strpos($data,$s);
      
    if (!is_int($pos)) {
      $dt = adodb_date($df) . " " . $data;
    } else {
      $dt = $data;
    }
    $p = explode(" ",$dt);
    $d = explode($s,$p[0]);

    if (count($p) == 1)
      $h = array(0,0,0);
    else {
      $h = explode(":",$p[1]);
      if (sizeof($h) == 2)
        $h[2] = 0;
      if (sizeof($h) == 1) {
        $h[1] = 0;
        $h[2] = 0;
      }
    }

    return adodb_mktime($h[0],$h[1],$h[2],$d[$mes],$d[$dia],$d[$ano]);

  }

  /**
   * Retorna data no formato unix (de uma data iso)
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function iso_unix($data1) {

    $df = self::date_format();
    $data = adodb_date2($df.' H:i:s',$data1);
    
    return self::data_unix($data);

  }

  /**
   * Soma dias na data
   *
   * @param $data String com data
   * @param $dias Nr de dias
   * @return Nova data com dias somados 
   */
  static function soma_dias($data, $dias) {

    $df = self::date_format();
    return adodb_date($df, self::data_unix($data) + ($dias * 86400));
    
  }
    
  /**
   * Diferenca de dias entre datas
   *
   * @param $data1 String com Data 1
   * @param $data2 String com Data 2
   * @return Diferena em dias entre as datas 
   */
  static function diff_dias($data1, $data2) {

    return ceil((self::data_unix($data2) - self::data_unix($data1)) / 86400);
    
  }

  /**
   * Retorna total de minutos da hora
   *
   * @param $hora String com hora no formato HH:MM
   * @return Numero de minutos no dia da hora
   */
  static function minutos($hora = '') {

    if (!$hora) {
      $hr = adodb_date("H:i");      
    } else {
      $hr = $hora;
    }
    $h = intval(substr($hr, 0, 2));
    $m = intval(substr($hr, 3 ,2));
    return ($h * 60) + $m;
    
  }

  /**
   * Retorna data do BD no formato D/M/Y
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function date_db($data) {

    $df = self::date_format();
    return adodb_date2($df, $data);

  }
  
  /**
   * Retorna data do BD no formato D/M/Y HH:MM
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function datetime_db($data) {

    $df = self::date_format();
    return adodb_date2($df.' H:i:s', $data);

  }

  /**
   * Retorna mes por extenso de data
   *
   * @param $mes Mes
   * @param $abrev nome abreviado
   * @return Mes por extendo
   */
  static function mes_extenso($mes, $abrev = false) {

    $dom = textdomain(null);
    textdomain('nwx');
    $meses = array(_('Janeiro'),_('Fevereiro'),_('Maro'),_('Abril'),_('Maio'),_('Junho'),
                   _('Julho'),_('Agosto'),_('Setembro'),_('Outubro'),_('Novembro'),_('Dezembro'));
    textdomain($dom);
    $m = intval($mes) - 1;
    if ($m >= 0 && $m <= 11) {
      return $abrev ? substr($meses[$m],0,3) : $meses[$m];
    } else {
      return '';
    }
    
  }

  /**
   * Retorna data de inicio da semana de outra data
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function semana_inicio($data) {

    $iso = self::data_iso($data, false);
    $w = adodb_date2('w', $iso) - 1;
    if ($w < 0) $w = 6;  
    
    if ($w == 0) return $data;
    
    return self::soma_dias($data, $w * -1);
    
  }
  
  /**
   * Retorna data de fim da semana de outra data
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function semana_fim($data) {

    $iso = self::data_iso($data, false);
    $w = adodb_date2('w', $iso) - 1;
    if ($w < 0) $w = 6;  
    
    if ($w == 6) return $data;
    
    return self::soma_dias($data, 6 - $w);
    
  }
  
  /**
   * Retorna data de inicio do mes
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function mes_inicio($data) {

    $df = self::date_format();
    $s = self::date_format('/');
    $dia = self::date_format('d');
    $mes = self::date_format('m');
    $ano = self::date_format('a');
    $d = explode($s, $data);
    $d[$dia] = 1;
    return date($df, adodb_mktime(0,0,0,$d[$mes],$d[$dia],$d[$ano]));
    
  }
  
  /**
   * Retorna data do fim do mes
   *
   * @param $data String com data
   * @return Data no formato Unix
   */
  static function mes_fim($data) {

    $df = self::date_format();
    $iso = nwx_time::data_iso($data, false);
    $dia = intval(adodb_date2('d', $iso));
    $mes = intval(adodb_date2('m', $iso));  
    $ano = intval(adodb_date2('Y', $iso));  
    ++$mes;
    if ($mes > 12) {
      $mes = 1;
      ++$ano;
    }
    $data2 = date($df, adodb_mktime(0,0,0,$mes,1,$ano));
    return self::soma_dias($data2, -1); 
    
  }
  
  /**
   * Retorna locales da lingua
   *
   * @param $tipo Tipo de retorno desejado (/,d,m,a ou null para formato)
   * @return string
   */
  static function date_format($tipo = null) {
    
    // Le uma data modelo (31/Jan/2000)
    if ($_SESSION['nwx_locale'] == 'pt_BR') {
      $d = '31/01/2011';
    } else {
      $d = strftime('%c',mktime(0,0,0,1,31,2011));
    }
    // Descobre o caracter de separacao
    $mat = array();
    preg_match('/[^0-9]/', $d, $mat);
    $s = $mat[0];
    // Se pediu separador
    if ($tipo == '/') {
      return $s;
    }
    // Explode a data pelo caracter de separacao
    $a = explode($s, $d);
    // Monta a mascara percorrendo a matriz gerada
    $ret = '';
    $dia = null;
    $mes = null;
    $ano = null;
    $ind = 0;
    for ($i = 0; $i < 3; ++$i) {
      if ($a[$i] == 1) {
        $ret .= 'm';
        $mes = $ind;
      } else if ($a[$i] == 31) {
        $ret .= 'd';
        $dia = $ind;
      } else if ($a[$i] == 2011 || $a[$i] == 11) {
        $ret .= 'Y';
        $ano = $ind;
      }
      ++$ind;
    }
    if (is_null($tipo)) {
      return substr($ret,0,1) . $s . substr($ret,1,1) . $s . substr($ret,2,1);  
    } else if ($tipo == 'd') {
      return $dia;
    } else if ($tipo == 'm') {
      return $mes;
    } else if ($tipo == 'a') {
      return $ano;
    }
               
  }
  
} //class nwx_time
// vim:et:sw=2:ts=2:nowrap:
