<?php
/**
 * Usuarios conectados
 *
 * @file nwx_usrls.php
 * @author Gonalo Franco
 * @version $Id: nwx_usrls.php 924 2007-01-11 18:36:37Z goncalo $
 */

require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_form.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_quadro.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_grid.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_util.php");
require_once(NWX_DIR . DIRECTORY_SEPARATOR . "nwx_time.php");

/**
 * Formulario para Alteracao,Inclusao e Exclusao de usuarios
 */
class nwx_usrls_form extends nwx_form {

  /**
   * Carrega dados do BD nos campos do formulario
   */
  function carrega() {

    $db = nwx_db::conexao();
    $stmt = "select * from nwx_usr where id_usr = ?";
    $rs = $db->execute($stmt, array($this->id[0]));
    if (!$rs->EOF) {
      $this->valor('id_usr',$rs->fields['id_usr']);
      $this->valor('codigo',$rs->fields['codigo']);
      $this->valor('nome',$rs->fields['nome']);
      $this->valor('adm',$rs->fields['adm']);
      $this->valor('itno',$rs->fields['itno']);
      $this->valor('email',$rs->fields['email']);
      $this->valor('blo',$rs->fields['blo']);
      $this->valor('grupos',$rs->fields['id_usr']);
    }
  
  }

  /**
   * Verificacao dos campos para confirmacao
   */
  function verifica() {

  }

  /**
   * Processamento do formulario
   */
  function processa($_sair) {

    $db = nwx_db::conexao();

  }

} //class nwx_usr_form

/**
 * Cria o quadro que contem o grid de manutencao
 */
class nwx_usrls extends nwx_quadro {

  /**
   * Construtor: ajusta o titulo e tipo
   */
  function __construct($id) {
    
    parent::__construct($id);
    $this->titulo = "Usurios Conectados";
    $this->fixo = 0;

  }

  /**
   * Monta o conteudo do quadro
   */
  function monta() {

    $sql = "select a.id_usr, b.codigo,
                   coalesce(b.nome,'Publico (Usurio Annimo)') as nomex,
                   b.adm, count(a.id_usr) as qtd from nwx_sess a
             left join nwx_usr b on (a.id_usr = b.id_usr)
             group by a.id_usr, b.codigo, b.nome, b.adm";
             
    // Objeto grid
    $grid = new nwx_grid($this,$sql,'','b.codigo');

    // Prepara os campos de filtro ou busca (campo, nome a mostrar, tipo)
    $grid->filtro = array(array('b.codigo',  'Cdigo', 'C'),
                          array('b.nomex',    'Nome',   'C')
                         );

    // Colunas do grid (campo,label,largura,alinhamento,tipo,formato)
    $grid->colunas = array(array('codigo', 'Cdigo', '15%','E','C','','b.codigo'),
                           array('nomex',   'Nome',   '70%','E','C','','b.nomex'),
                           array('qtd',    'Logins', '10%','E','C','','a.qtd'),
                           array('adm',    'Adm',    '5%','C','C',array('-','S'),'b.adm')
                          );

    // Nome da coluna que identifica a linha
    $grid->pk = array('id_usr');

    // Numero de linhas por pagina
    $grid->linhas(10,18);

/*
    // Cria o formulario para processamento do registros
    $form = new nwx_usr_form("nwx_usrls_form","nwx_usrls");

    // Guarda o nome do grid internamente no formulario
    $form->grid = $grid->nome;

    // Cria os campos do formulario e sua representacao
    $f1 = new nwx_form_text('codigo','C',20,0,false,false);
    $f2 = new nwx_form_text('nome', 'C',100,0,false,false);
    $f3 = new nwx_form_text('email','EMAIL',50,'',true,false);
    $f4 = new nwx_form_check('adm','C',1,0,true,false);
    $f5 = new nwx_form_check('itno','C',1,0,true,false);
    $f6 = new nwx_form_lista('grupos','C',10,0,true,false);
    $f7 = new nwx_form_check('blo','C',1,0,true,false);

    $f1->ajuda = "Cdigo interno do usurio (Obrigatrio)";
    $f2->ajuda = "Nome completo do usurio (Obrigatrio)";
    $f3->ajuda = "Endereo de e-mail do usurio (Opcional)";
    $f4->ajuda = "Indica se o usurio tem privilgios de administrador do sistema";
    $f5->ajuda = "Indica se o usurio  interno ao sistema";
    $f6->ajuda = "Grupos a que o usurio pertence";
    $f7->ajuda = "Indica se o usurio esta bloquado (No pode acessar sistema)";

    $c1 = new nwx_form_cabec('Dados Cadastrais');
    $c2 = new nwx_form_cabec('Posio no Sistema');

    $f6->query = "select id_grp, descricao from nwx_grp where id_grp in (select id_grp from nwx_mbr where id_usr = 0%s) order by descricao";
    $f6->query2 = "select id_grp, descricao from nwx_grp where id_grp not in (select id_grp from nwx_mbr where id_usr = 0%s) order by descricao";

    $form->input($f1,'Codigo','','size="20"',true);
    $form->input($c1);
    $form->input($f2,'Nome','','size="80"',true);
    $form->input($f3,'E-Mail','','size="50"',true);
    $form->input($c2);
    $form->input($f4,'Administrador','','',false);
    $form->input($f5,'Interno','','',false);
    $form->input($f7,'Bloqueado','','',true);
    $form->input($f6,'Grupos','','size="4" multiple="yes"',true);

    // Cria os campos do formulario e sua representacao
    $fp1 = new nwx_form_pass('senha1','C',20,0,false,false);
    $fp2 = new nwx_form_pass('senha2','C',20,0,false,false);
    $fp1->ajuda = "Nova senha para o usurio";
    $fp2->ajuda = "Repetir senha para confirmao";

    $form2->input($fp1,'Nova Senha','','size="20"',true);
    $form2->input($fp2,'Repetir Senha','','size="20"',true);

    // Cria os botoes para funcoes do grid
    // Array indexado pelo label do botao, contendo :
    // (nome da funcao p/ form, o form, se campos read-only, se reg.novo)
    $grid->oper = array('Incluir' => array('Incluir',$form,false,true,"Incluir novo registro"),
                        'Alterar' => array('Alterar',$form,false,false,"Alterar registro"),
                        'Senha'   => array('Senha',  $form2,false,false,"Alterar senha do usurio"),
                        'Excluir' => array('Excluir',$form,true,false,"Escluir registro")
                       );
*/
    // Mostra o grid na pagina
    $grid->mostra($this);
  
  }

} //class nwx_usrls
// vim:et:sw=2:ts=2:nowrap:
