<?php
/**
 * Funcoes utilitarias diversas
 *
 * @author Gonalo Franco
 * @version $Id: nwx_util.php 921 2007-01-11 17:39:07Z goncalo $
 */

require_once("nwx_db.php");
require_once("nwx_time.php");
require_once('safecrypt/StonePhpSafeCrypt.php');

/**
 * Classe utilitaria com funoes comuns
 */
final class nwx
{
	static $_db;
	static $_session;

	private function __construct() {}

	/**
	 * Inicia gerenciamento de sessoes
	 */
	static function session_start() {

		// Definicoes basicas
		if (!defined('NWX_SESSIONS_DB')) define('NWX_SESSIONS_DB',false);
		if (!defined('NWX_SESSIONS_MC')) define('NWX_SESSIONS_MC',false);
		if (!defined('NWX_SESSIONS_EA')) define('NWX_SESSIONS_EA',false);

		// Gerenciamento de sessoes em Banco de Dados
		if (NWX_SESSIONS_DB) {
			require_once("nwx_session_db.php");
			if (nwx_session_db::start(NWX_DSN)) {
				nwx_session_db::gc_method();
				self::$_session = 'Database';
			}
		}
		// Gerenciamento de sessoes em memcache
		if (!self::$_session && NWX_SESSIONS_MC) {
			require_once("nwx_session_mc.php");
			if (nwx_session_mc::start()) {
				nwx_session_mc::gc();
				self::$_session = 'Memcache';
			}
		}
		// Gerenciamento de sessoes em eaccelerator
		if (!self::$_session && NWX_SESSIONS_EA) {
			eaccelerator_set_session_handlers();      
			self::$_session = 'eAccelerator';
		}
		// Gerenciamento de sessao com arquivos
		if (!self::$_session) {
			self::$_session = 'Files';
		}
	
		// Inicia sessao
		session_start();

		return true;
	
	}

}


/**
 * Le parametro do sistema
 *
 * @param $id Codigo do Parametro
 */
function nwx_param($id) {

	$k = strtoupper($id);
	
	$db = nwx_db::conexao();
	if (!$db) return false;
	
	// Le o titulo original
	$st = "select * from nw_param where id_param = ?";
	$rs = $db->execute($st, array($k));
	if (!$rs->EOF)
		return $rs->fields['valor'];
	else
		return false;

}

/**
 * Recria a pagina atual
 */
function nwx_repaginar($dest = '', $sub = false) {
	
	if (!$sub) {
		$comp = isset($_SESSION[NWX_SIS . '_tab']) ? '?tab='.$_SESSION[NWX_SIS . '_tab'] : '';
		//session_write_close();
		header("Location: ". NWX_RDX . NWX_APL . '/' . NWX_IDX . $comp . $dest);
	} else {
		$pag = @$_GET['pag'];
		$key = @$_GET['key'];
		//session_write_close();
		header("Location: ". NWX_RDX . NWX_APL . "/nwx_load.php?pag=$pag&key=$key".$dest);
	}

} //nwx_repaginar 

/**
 * Mostra alerta com Javascript
 */
function nwx_alerta($msg) {
	
	$_SESSION['nwx_alr'] = $msg;

} //nwx_alerta 

/**
 * URL para recarregar a pagina
 *
 * @return string com Url para recarregar pagina atual
 */
function nwx_reload() {

	$comp = isset($_SESSION[NWX_SIS . '_tab']) ? '?tab='.$_SESSION[NWX_SIS . '_tab'] : '';
	return NWX_RDX . NWX_APL . '/' . NWX_IDX . $comp;

} // nwx_reload 

/**
 * Fecha bloco aberto
 *
 * @param $bloco Bloco a fechar
 */
function nwx_fecha_bloco($bloco) {

	if (isset($_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']][$bloco])) {
		unset($_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']][$bloco]);
		if (count($_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']]) == 0)
			unset($_SESSION[NWX_SIS . '_abre'][$_SESSION[NWX_SIS . '_tab']]);
		if (count($_SESSION[NWX_SIS . '_abre']) == 0)
			unset($_SESSION[NWX_SIS . '_abre']);
	}
	// fecha estruturas internas de form, se existirem
	nwx_fecha_form_bloco($bloco);

} //nwx_flexa_bloco 

/**
 * Fecha estruturas de form do bloco
 *
 * @param $bloco Bloco a fechar
 */
function nwx_fecha_form_bloco($bloco) {
	if (isset($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']][$bloco])) {
		unset($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']][$bloco]);
		if (count($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']]) == 0)
			unset($_SESSION[NWX_SIS . '_det'][$_SESSION[NWX_SIS . '_tab']]);
		if (count($_SESSION[NWX_SIS . '_det']) == 0)
			unset($_SESSION[NWX_SIS . '_det']);
	}
	if (isset($_SESSION['nwx_lov'][$bloco])) {
		unset($_SESSION['nwx_lov'][$bloco]);
		if (count($_SESSION['nwx_lov']) == 0)
			unset($_SESSION['nwx_lov']);
	}
	if (isset($_SESSION['nwx_md5_'.$bloco])) {
		unset($_SESSION['nwx_md5_'.$bloco]);
	}
	if (isset($_SESSION['nwx_sbb'][$bloco]) && is_array($_SESSION['nwx_sbb'][$bloco])) {
		foreach ($_SESSION['nwx_sbb'][$bloco] as $blc) {
			nwx_fecha_bloco($blc);
			foreach ($_SESSION[NWX_SIS . '_grid'] as $k => $a)
				if ($a['gid'] == $blc && $a['gtb'] == $_SESSION[NWX_SIS . '_tab'])
					nwx_fecha_grid($k);
		}
		unset($_SESSION['nwx_sbb'][$bloco]);  
	}
	if (isset($_SESSION[NWX_SIS . '_grid']) && is_array($_SESSION[NWX_SIS . '_grid'])) {
		foreach ($_SESSION[NWX_SIS . '_grid'] as $g => $d) {
			if (substr($g,0,4) == 'LOV_' && $d['gid'] == $bloco) {
				nwx_fecha_grid($g);  
			}
		}
	}
	
	
} //nwx_fecha_form_bloco 

/**
 * Fecha grid
 *
 * @param $nome Nome do grid a fechar
 */
function nwx_fecha_grid($nome) {
	
	if (isset($_SESSION[NWX_SIS . '_grid'][$nome])) {
		unset($_SESSION[NWX_SIS . '_grid'][$nome]);
		if (count($_SESSION[NWX_SIS . '_grid']) == 0)
			unset($_SESSION[NWX_SIS . '_grid']);
	}

} //nwx_fecha_grid 

/**
 * Retorna a coluna do bloco na pagina
 *
 * @param $bloco Nome do bloco
 * @param $tab Pagina tab
 *
 * @return Coluna do bloco na pagina ou falso se nao existir
 */
function nwx_qcol($bloco, $tab = '') {

	if (!$tab) $tab = $_SESSION[NWX_SIS . '_tab'];
	
	if (isset($_SESSION[NWX_SIS . '_abre'][$tab])) {
		foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $val)
			if ($blo == $bloco && is_array($val))
				return $val[0];
	}
	return false;

} //nwx_qcol 

/**
 * Retorna a sequencia do bloco na pagina
 *
 * @param $bloco Nome do bloco
 * @param $tab Pagina tab
 *
 * @return Sequencia do bloco na pagina ou false se nao existir
 */
function nwx_qseq($bloco, $tab = '') {

	if (!$tab) $tab = $_SESSION[NWX_SIS . '_tab'];

	if (isset($_SESSION[NWX_SIS . '_abre'][$tab]) && $_SESSION[NWX_SIS . '_abre'][$tab]) {
		foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $val) {
			if ($blo == $bloco && is_array($val)) {
				return $val[1];
			}
		}
	}

	return false;

} //nwx_qseq 

/**
 * Retorna o status do bloco na pagina
 *
 * @param $bloco Nome do bloco
 * @param $tab Pagina tab
 *
 * @return Status do bloco na pagina ou falso se nao existir
 */
function nwx_qsta($bloco, $tab = '') {

	if (!$tab) $tab = $_SESSION[NWX_SIS . '_tab'];
	
	if (isset($_SESSION[NWX_SIS . '_abre'][$tab])) {
		foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $val) {
			if ($blo == $bloco && is_array($val)) {
				return $val[2];
			}
		}
	}
	return false;

} //nwx_qsta 

/**
 * Retorna o valor armazenado pelo bloco pai do bloco
 *
 * @param $bloco Nome do bloco
 * @param $tab Pagina tab
 *
 * @return Valor armazenado ou falso se nao existir
 */
function nwx_qval($bloco, $tab = '') {

	if (!isset($_SESSION[NWX_SIS . '_tab'])) return false;
	
	if (!$tab) $tab = $_SESSION[NWX_SIS . '_tab'];
	
	if (isset($_SESSION[NWX_SIS . '_abre'][$tab])) {
		foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $val)
			if ($blo == $bloco && is_array($val))
				return $val[3];
	}
		
	return false;

} //nwx_qval 

/**
 * Retorna o icone que o bloco foi chamado
 *
 * @param $bloco Nome do bloco
 * @param $tab Pagina tab
 *
 * @return Valor armazenado ou falso se nao existir
 */
function nwx_qico($bloco, $tab = '') {

	if (!$tab) $tab = $_SESSION[NWX_SIS . '_tab'];
	
	$p = '';
	if (isset($_SESSION[NWX_SIS . '_abre'][$tab])) {
		foreach ($_SESSION[NWX_SIS . '_abre'][$tab] as $blo => $val)
			if ($blo == $bloco && is_array($val)) {
				$p = $val[3];
				break;
			}
	}
	if ($p && isset($p['ico']))
		return $p['ico'];
	else    
		return '';

} 

/**
 * Retorna o valor armazenado pelo bloco pai do bloco (Para subgrids)
 *
 * @return Valor armazenado ou falso se nao existir
 */
function nwx_key_subgrid() {

	// Set tem $_GET['key'] e' um subgrid
	if (isset($_GET['key']) && $_GET['key']) {
		return explode('.',$_GET['key']);
	}

	return false;

} //nwx_key_subgrid 

/**
 * Retorna usuario do sistema operacional
 *
 * @return String com identificao do Usuario
 */
function nwx_osusr() {

	if (!isset($_SERVER['REMOTE_USER']))
		return '';
		
	//$u = stripslashes($_SERVER['REMOTE_USER']);
	$u = $_SERVER['REMOTE_USER'];
	$n = strrpos($u,'\\');
	if ($n === false)
		return $u;
	return strtoupper(substr($u,$n+1));  

} //nwx_osusr 

/**
 * Retorna string limpa de caracteres perigosos
 *
 * @param $arg String a limpar
 * @return String "limpa"
 */
function nwx_filtra($arg) {

	//return htmlspecialchars(strip_tags(trim($arg)));
	//return strip_tags(trim($arg));
	return trim($arg);

} //nwx_filtra 

/**
 * Retorna string de entrada
 *
 * @param $arg String a limpar
 * @return String sem backtags
 */
function nwx_filtra_entra($arg) {

	$s = str_replace('\\"','"',trim($arg));
	$s = str_replace("\\'","'",$s);
	return $s;

} //nwx_filtra_entra 

/**
 * Verifica CPF
 *
 * @param $cpf String com CPF
 * @return Se CPF valido
 */
function VerifCPF($cpf) {

	$RecebeCPF = $cpf;

	if (strlen($RecebeCPF) != 11 || $RecebeCPF == "00000000000")
		return false;

	for ($x = 1; $x <= strlen($RecebeCPF); $x = $x+1) {
		$ch = substr($RecebeCPF, $x - 1, 1);
		if (ord($ch) < 48 || ord($ch) > 57)
			return false;
	}

	$Numero[1]=intval(substr($RecebeCPF,1-1,1));
	$Numero[2]=intval(substr($RecebeCPF,2-1,1));
	$Numero[3]=intval(substr($RecebeCPF,3-1,1));
	$Numero[4]=intval(substr($RecebeCPF,4-1,1));
	$Numero[5]=intval(substr($RecebeCPF,5-1,1));
	$Numero[6]=intval(substr($RecebeCPF,6-1,1));
	$Numero[7]=intval(substr($RecebeCPF,7-1,1));
	$Numero[8]=intval(substr($RecebeCPF,8-1,1));
	$Numero[9]=intval(substr($RecebeCPF,9-1,1));
	$Numero[10]=intval(substr($RecebeCPF,10-1,1));
	$Numero[11]=intval(substr($RecebeCPF,11-1,1));

	$soma = (10 * $Numero[1]) + (9 * $Numero[2]) + (8 * $Numero[3]) + (7 * $Numero[4]) +
					(6 * $Numero[5]) + (5 * $Numero[6]) + (4 * $Numero[7]) + (3 * $Numero[8]) +
					(2 * $Numero[9]);
	$soma = $soma - (11 * (intval($soma / 11)));

	if ($soma == 0 || $soma == 1)
		$resultado1 = 0;
	else
		$resultado1 = 11 - $soma;

	if ($resultado1 == $Numero[10]) {
		$soma = ($Numero[1] * 11) + ($Numero[2] * 10) + ($Numero[3] * 9) + ($Numero[4] * 8) +
						($Numero[5] * 7) + ($Numero[6] * 6) + ($Numero[7] * 5) + ($Numero[8] * 4) +
						($Numero[9] * 3) + ($Numero[10] * 2);
		$soma = $soma - (11 * (intval($soma / 11)));
		if ($soma==0 || $soma==1)
			$resultado2 = 0;
		else
			$resultado2 = 11 - $soma;
	 if ($resultado2 == $Numero[11])
		 return true;
	}

	return false;

} //VerifCPF 

/**
 * Verifica CNPJ
 *
 * @param $cnpj String com CNPJ
 * @return Se CNPJ valido
 */
function VerifCNPJ($cnpj) {

	$RecebeCNPJ = $cnpj;

	if (strlen($RecebeCNPJ) != 14 || $RecebeCNPJ == "00000000000000")
		return false;

	for ($x = 1; $x <= strlen($RecebeCNPJ); $x = $x+1) {
		$ch = substr($RecebeCNPJ, $x - 1, 1);
		if (ord($ch) < 48 || ord($ch) > 57)
			return false;
	}

	$Numero[1]=intval(substr($RecebeCNPJ,1-1,1));
	$Numero[2]=intval(substr($RecebeCNPJ,2-1,1));
	$Numero[3]=intval(substr($RecebeCNPJ,3-1,1));
	$Numero[4]=intval(substr($RecebeCNPJ,4-1,1));
	$Numero[5]=intval(substr($RecebeCNPJ,5-1,1));
	$Numero[6]=intval(substr($RecebeCNPJ,6-1,1));
	$Numero[7]=intval(substr($RecebeCNPJ,7-1,1));
	$Numero[8]=intval(substr($RecebeCNPJ,8-1,1));
	$Numero[9]=intval(substr($RecebeCNPJ,9-1,1));
	$Numero[10]=intval(substr($RecebeCNPJ,10-1,1));
	$Numero[11]=intval(substr($RecebeCNPJ,11-1,1));
	$Numero[12]=intval(substr($RecebeCNPJ,12-1,1));
	$Numero[13]=intval(substr($RecebeCNPJ,13-1,1));
	$Numero[14]=intval(substr($RecebeCNPJ,14-1,1));

	$soma = ($Numero[1] * 5) + ($Numero[2] * 4) + ($Numero[3] * 3) + ($Numero[4] * 2) +
					($Numero[5] * 9) + ($Numero[6] * 8) + ($Numero[7] * 7) + ($Numero[8] * 6) +
					($Numero[9] * 5) + ($Numero[10] * 4) + ($Numero[11] * 3) + ($Numero[12] * 2);

	$soma = $soma - (11 * (intval($soma / 11)));

	if ($soma == 0 || $soma == 1)
		$resultado1 = 0;
	else
		$resultado1 = 11 - $soma;

	if ($resultado1 == $Numero[13]) {
		$soma = ($Numero[1] * 6) + ($Numero[2] * 5) + ($Numero[3] * 4) + ($Numero[4] * 3) +
						($Numero[5] * 2) + ($Numero[6] * 9) + ($Numero[7] * 8) + ($Numero[8] * 7) +
						($Numero[9] * 6) + ($Numero[10] * 5) + ($Numero[11] * 4) + ($Numero[12] * 3) +
						($Numero[13] * 2);
		$soma = $soma - (11 * (intval($soma / 11)));
		if ($soma == 0 || $soma == 1)
			$resultado2 = 0;
		else
			$resultado2 = 11 - $soma;
		if ($resultado2 == $Numero[14])
			return true;
	}

	return false;

} //VerifCNPJ 

/**
 * Retorna icone em funcao do tipo MIME
 */
function mime_ico($tipo) {
	
  if ($tipo == 'application/vnd.openxmlformats-officedocument.wordprocessingml.document') {
    $tipo = 'msword';
  } else if ($tipo == 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet') {
    $tipo = 'vnd.ms-excel';
  }
  	
	$tipos = array();
	$tipos[] = 'msword';
	$tipos[] = 'vnd.ms-excel';
	$tipos[] = 'vnd.ms-powerpoint';
	$tipos[] = 'vnd.ms-project';
	$tipos[] = 'vnd.visio';
	$tipos[] = 'x-zip-compressed';
	$tipos[] = 'plain';
	$tipos[] = 'pdf';
	$tipos[] = 'gif';
	$tipos[] = 'x-png';
	$tipos[] = 'bmp';
	$tipos[] = 'x-icon';
	$tipos[] = 'pjpeg';
	$tipos[] = 'octet-stream';
	$tipos[] = 'html';
		
	$p = strpos($tipo,'/');
	if ($p === false)
		$nome = $tipo;
	else
		$nome = substr($tipo,$p+1);
		
	$n = array_search($nome,$tipos);  
	if ($n === false)
		return 'page.gif';
	else
		return $tipos[$n].'.gif';
		
}

/**
 * Conexao via LDAP
 */
function nwx_ldap_bind($servidor, $username, $password, $dominio) {

	if (!$servidor || !$username || !$password || !$dominio)
		return false;
	
	$conn = ldap_connect($servidor);
	
	if (!$conn)
		return false;
	
	ldap_set_option($conn, LDAP_OPT_PROTOCOL_VERSION, 3);
	ldap_set_option($conn, LDAP_OPT_REFERRALS, 0);

	$ident = str_ireplace('?', $username, $dominio);
	if (@ldap_bind($conn, $ident, $password))
		return true;
	else  
		return false;

}

/**
 * Verifica se bloco liberado para uso
 *
 * @param $bloco Nome do bloco
 * @return Se bloco liberado (true/false)
 */
function nwx_acs_bloco($bloco) {

	$db = nwx_db::conexao();
	$aplic = NWX_SIS;
	
	// Procura pelo usuario ou grupos PUBLIC, EXT e ANON
	if (isset($_SESSION['nwx_usr']))
		$ua = "or usr = '" . $_SESSION['nwx_usr'] . "' or usr = 'PUBLIC' or usr = 'EXT' or usr = 'ANON'";
	else
		$ua = "or usr = 'ANON'";

	//$u = (!isset($_SESSION['nwx_usr'])) ? "$ua or usr = 'PUBLIC' or usr = 'EXT' or usr = 'ANON'" : "";

	$st = "select usr from nw_acs where aplic = " . $db->quote($aplic) .
				" and bloco = " . $db->quote($bloco) .
				" and (usr is null $ua)";
	$rs = $db->execute($st);
		
	// Se liberado para publico, anonimo ou externos : verifica consistencia
	if (!$rs->EOF && (($rs->fields['usr'] == 'ANON' && isset($_SESSION['nwx_usr'])) ||
			($rs->fields['usr'] == 'PUBLIC' && !isset($_SESSION['nwx_usr'])) ||
			($rs->fields['usr'] == 'EXT' && !isset($_SESSION['nwx_uex']))))
		return false;

	// Se for administrador : libera
	if (!empty($bloco) && isset($_SESSION['nwx_adm']) && $_SESSION['nwx_adm'] == 1)
		return true;

	// Se nao encontrou ate agora : procura nos grupos do usuario
	if ($rs->EOF && isset($_SESSION['nwx_usr'])) {
		$st2 = "select grupo from nw_mbr where usr = '" . $_SESSION['nwx_usr'] . "'";
		$rs2 = $db->execute($st2);
		while (!$rs2->EOF) {
			$st = "select usr from nw_acs where aplic = " . $db->quote($aplic) .
						" and bloco = " . $db->quote($bloco) .
						" and usr = '" . $rs2->fields['grupo'] ."'";
			$rs = $db->execute($st);
			if (!$rs->EOF)
				break;
			$rs2->MoveNext();
		}
	}

	return !$rs->EOF;

}

/**
 * Verifica se menu2 subordinado a menu1
 *
 * @param $t1 Codigo do menu 1
 * @param $t2 Codigo do menu 2
 */
function menu_subordinado($t1, $t2) {

	if ($t1 == $t2) {
		return true;
	}
	
		// Le o registro
	$db = nwx_db::conexao();
	$st = "select * from nw_mnu where aplic = ? and id = ?";
	$rs = $db->execute($st, array(NWX_SIS, $t2));
	$p = $rs->fields['pai'];
	$ok = false;

	// Procura por titulo1 subindo pela arvore
	$ok = false;
	while ($p && !$ok) {
		$st = "select * from nw_mnu where aplic = ? and id = ?";
		$rs = $db->execute($st, array(NWX_SIS, $p));
		if ($rs->EOF)
			break;
		if ($rs->fields['id'] == $t1)
			$ok = true;
		$p = $rs->fields['pai'];
	}

	return $ok;
	
}

/**
 * Cria arvore dinamica
 *
 * @param $func string Nome da funcao que gera XML
 */
function nwx_tree($func, $id = '', $w = 18, $h = 18) {

	$base = NWX_RDX.NWX_APL;
	$ret = 
	"<div id=\"tre\" style=\"width:100%;\"></div>
	<script>
		tr = new dhtmlXTreeObject('tre','100%','100%',0);
		tr.setImagePath('../../nwx/img/');
		tr.enableCheckBoxes(false);
		tr.enableDragAndDrop(false);
    tr.setIconSize($w,$h);
    //tr.enableLoadingItem('Aguarde...');
    //tr.enableTreeLines('false');
    //tr.enableMultiLineItems('300px');
		tr.setXMLAutoLoading('$base/index_xml.php?rel=$func');
		tr.loadXML('$base/index_xml.php?rel=$func&id=0',function(){tr.loadOpenStates('{$func}{$id}');});
		tr.setOnClickHandler(doOnClick);
    //tr.setOnNodeSelectHandler(doOpenClose);
		function doOnClick(nodeId) {
			var dest = tr.getUserData(nodeId, 'des');
			var targ = tr.getUserData(nodeId, 'target');
      tr.saveOpenStates('{$func}{$id}');
      if (dest) {
				if (targ) {
					window.open(unescape(dest));
				} else {
					location.href = unescape(dest);
				}
			}
		}
    function doOpenClose(nodeId) {
      tr.saveOpenStates('{$func}{$id}');
    }
	</script>
	";

	return $ret; 

}

/**
 * Copia arquivo ou diretorio recursivamente
 *
 * @param $source String Origem
 * @param $dest String Destino
 * @return bool TRUE successo, FALSE erro
 */
function xcopy($source, $dest) {
	
	$ori = $source;
	$des = $dest;
	
	// Ajusta separadores de diretorios
	$ori = str_replace("/",DIRECTORY_SEPARATOR,$ori);
	$ori = str_replace("\\",DIRECTORY_SEPARATOR,$ori);
	$des = str_replace("/",DIRECTORY_SEPARATOR,$des);
	$des = str_replace("\\",DIRECTORY_SEPARATOR,$des);

	// Se nao existe, retorna
	if (!file_exists($ori)) {
		return false;
	}

	// Simple copy for a file
	if (is_file($ori)) {
		return copy($ori, $des);
	}

	// Make destination directory
	if (!is_dir($des)) {
		mkdir($des);
	}
	// Loop through the folder
	$dir = dir($ori);
	while (false !== ($entry = $dir->read())) {
		// Skip pointers
		if ($entry == '.' || $entry == '..') {
			continue;
		}
		// Deep copy directories
		if ($des !== "$source/$entry") {
			xcopy("$source/$entry", "$des/$entry");
		}
	}
	// Clean up
	$dir->close();
	return true;
}

/**
 * Excluir arquivo ou diretorio e seu conteudo
 *
 * @param $dirname String Diretorio a deletar
 * @return bool TRUE successo, FALSE erro
 */
function xrmdir($dirname) {
	
	// Sanity check
	if (!file_exists($dirname)) {
		return true;
	}
	// Simple delete for a file
	if (is_file($dirname)) {
		return unlink($dirname);
	}
	// Loop through the folder
	$dir = dir($dirname);
	while (false !== ($entry = $dir->read())) {
		// Skip pointers
		if ($entry == '.' || $entry == '..') {
			continue;
		}
		// Recurse
		xrmdir("$dirname/$entry");
	}
	// Clean up
	$dir->close();
	return rmdir($dirname);
}

/**
 * Executa script SQL
 *
 * @param $dirname String Diretorio a deletar
 * @return bool TRUE successo, FALSE erro
 */
function script_sql($db, $origem) {
	
	// Le conteudo do arquivo
	$arq = file_get_contents($origem);
	$aex = explode(';',$arq);
	if (!$_SESSION['nwx_adm']) return -1;
	$cmd = array();
	$key = '';
	$k = 0;
	foreach ($aex as $item) {
		// Verifica assinatura digital
		/*
		$i = stripos($item, 'key');
		if ($i !== false) {
			if ($k != 0) {
				return -2;
			}  
			$key = substr($item, $i+4);
			++$k;
			continue; 
		} else {
			if ($k == 0) {
				return -2;
			}  
		}
		if (NWX_SERIAL && $key) {
			if ($k == 1) {
				if ($key != NWX_SERIAL) {
					return -2;
				}
			}
		} 
		*/
		// Comandos possiveis
		$i = stripos($item, 'create');
		if ($i === false) {
			$i = stripos($item, 'alter');
			if ($i === false) {
				$i = stripos($item, 'insert');
				if ($i === false) {
					$i = stripos($item, 'update');
					if ($i === false) {
						$i = stripos($item, 'drop');
					}
				}
			}
		}
		if ($i !== false) {
			$cmd[] = substr($item, $i);
		}
	}
	
	// Matriz $cmd contem todos os comandos a executar
	$er = 0;
	foreach ($cmd as $c) {
		if (!$db->execute($c)) {
			++$er;
		}
	}
	return $er;
	
}

/**
 * Limpa cache de paginas
 *
 * @return void
 */
function nwx_clear_cache() {
	unset($_SESSION['nwx_etc']['pgs'][NWX_SIS]);
	unset($_SESSION['nwx_etc']['fix'][NWX_SIS]);
}

/**
 * Retorna locales da lingua
 *
 * @return string
 */
function nwx_locale($lang) {

	// Se nao for Windows: nada a modificar
	if (strtoupper(substr(PHP_OS, 0, 3)) != 'WIN') return $lang;
	
	// Se for Windows, altera de acordo com o locale
	switch ($lang) {
		case 'en_US' :
			return 'english_us';
			break;
		case 'en_GB' :
			return 'english_uk';
			break;
		case 'es_ES' :
			return 'spanish';
			break;
		case 'fr_FR' :
			return 'french';
			break;
		case 'de_DE' :
			return 'german';
			break;
		case 'it_IT' :
			return 'italian';
			break;
		default :
			return 'ptb';
	}  
							 
}

/**
 * Determina se codigo do usuario ou grupo de que faz parte
 *
 * @param $id_grp Codigo do grupo
 * @param $id_usr Usuario
 */
function nw_usr_grupo($id_grp, $id_usr) {

	// Se codigo for de usuario retorna true 
	if ($id_usr == $id_grp) return true;
	
	// Se nao, verifica se codigo de grupo do usuario
	$db = nwx_db::conexao();
	$st = "select 1 from nw_mbr where grupo = '$id_grp' and usr = '$id_usr'";
	$rs = $db->execute($st);
	return (!$rs->EOF);

}  

/**
 * Determina se chegaram novas mensagens para usuario
 *
 * @param $id_usr Usuario
 */
function nwx_mensagens() {

	if (!isset($_SESSION['nwx_usr'])) return false;
	
	if (!defined('NWX_TMS')) define('NWX_TMS', 60);
	if (NWX_TMS == 0) return false;
	
	// Verificacao de novas mensagens
	$usr = $_SESSION['nwx_usr'];
	$ck_um = "nwx_um_$usr";
	$ck_ul = "nwx_ul_$usr";
	
	$t = time();
	$d = 0;
	if (!isset($_SESSION['nwx_t'])) $_SESSION['nwx_t'] = 0;
	$u = $_SESSION['nwx_t'];
	if ($t - $u >= NWX_TMS) {
		$db = nwx_db::conexao();
		$rs = $db->execute("select max(dt_msg) as dtm from nw_msgs where id_usr=?", array($usr)); 
		if (!$rs->EOF && $rs->fields['dtm']) {
			$d = nwx_time::iso_unix($rs->fields['dtm']);
			setcookie($ck_um, $d, time()+NWX_COOKIE, '/');
		}  
		$_SESSION['nwx_t'] = $t;
	} 
	
	$um = (isset($_COOKIE[$ck_um])) ? $_COOKIE[$ck_um] : 0;
	$ul = (isset($_COOKIE[$ck_ul])) ? $_COOKIE[$ck_ul] : 0;
	return $um > $ul;

}


/**
 * Determina se senha do usuario expirou
 *
 * @param $usr Usuario
 * @returns True/False 
 */
function nwx_xsen($usr) {

	// Le parametros de seguranca
	if (!nwx_param('PASS_EXP')) return false;
	
	$db = nwx_db::conexao();
	$rs = $db->execute("select xsen from nw_usr where usr = ?", array($usr));
	if ($rs->fields['xsen'] && $rs->fields['xsen'] <= nwx_time::current_time()) {
		return true;
	}
	
	return false;  
	
}

/**
 * Determina se senha muito simples
 *
 * @param $usr Usuario
 * @param $senha Senha
 * @returns True/False 
 */
function nwx_ssen($usr, $senha) {

	// Le parametros de seguranca
	$min = nwx_param('PASS_MIN');
	$cpl = nwx_param('PASS_CPLX');
	
	// Verifica tamanho minimo
	if (strlen($senha) < $min) return true;
	
	// Se nao testa complexidade 
	if (!$cpl) return false;
	
	// Nao pode conter o proprio codigo
	if (preg_match("/$usr/i", $senha)) return true;
	
	// Deve sempre conter digitos
	if (!preg_match('/[0-9]/', $senha)) return true;
	
	// Complexidade 1: Letras, numeros e pontuacao
	if ($cpl == 1) {
		if (!preg_match('/[A-Za-z]/', $senha)) return true;
		if (!preg_match('/[^A-Za-z0-9]/', $senha)) return true;
	// Complexidade maxima: Letras maiusculas, minusculas, numeros e pontuacao
	} else {
		if (!preg_match('/[A-Z]/', $senha)) return true;
		if (!preg_match('/[a-z]/', $senha)) return true;
		if (!preg_match('/[^A-Za-z0-9]/', $senha)) return true;
	}
	
	return false;  
	
}

/**
 * Determina se senha reutilizada
 *
 * @param $usr Usuario
 * @param $senha Senha
 * @returns True/False 
 */
function nwx_rsen($usr, $senha) {

	// Le parametros de seguranca
	$int = nwx_param('PASS_REUT');
	
	if (!$int) return false;
	
	$pass = md5($senha);
	
	$db = nwx_db::conexao();
	
	// Verifica se ja utilizou a senha
	$rs = $db->execute("select data from nw_usr_sen where usr = ? and senha = ?", array($usr, $pass));
	if ($rs->EOF) {
		return false;
	}
		
	// Se utilizou, verifica data anterior ao intervalo minimo
	if (nwx_time::diff_dias(nwx_time::date_db($rs->fields['data']), date(nwx_time::date_format())) <= $int) {
		return true;
	}
	
	return false;  
	
}

/**
 * Mantem log de senhas
 *
 * @param $usr Usuario
 * @param $senha Senha
 * @returns True/False 
 */
function nwx_hist_senhas($usr, $senha) {

	$pass = md5($senha);
	
	$db = nwx_db::conexao();
	
	// Verifica se ja utilizou a senha
	$rs = $db->execute("select data from nw_usr_sen where usr = ? and senha = ?", array($usr, $pass));
	if ($rs->EOF) {
		$db->execute("insert into nw_usr_sen values(?,?,?)", array($usr, $pass, nwx_time::current_date()));
		return true;
	}
	$db->execute("update nw_usr_sen set data = ? where usr = ? and senha = ?", array(nwx_time::current_date(), $usr, $pass));
	return true;
	
}

define('NWX_CRYPT_PASS', 'evc7_Aht1.yi64S$ehtY');

/**
 * Encripta string
 *
 * @param $data String a encriptar
 * @returns String encriptada e condificada com encode64
 */
function nwx_crypt($data) {

	$er = error_reporting(0);
  $enc = false;
	if (function_exists('mcrypt_module_open'))
    $enc = PackCrypt($data, NWX_CRYPT_PASS);
	error_reporting($er);
	if ($enc && @$enc['success']) {
		return '0'.base64_encode($enc['output']);
	} else {
		return $data;
	}
	
}

/**
 * Encripta string
 *
 * @param $data String a encriptar
 * @returns String encriptada e condificada com encode64
 */
function nwx_decrypt($data) {

	$er = error_reporting(0);
  if (!function_exists('mcrypt_module_open')) return $data;
	$data_d = base64_decode(substr($data,1));
	$des = UnpackCrypt($data_d, NWX_CRYPT_PASS);
	error_reporting($er);
	if (@$des['success']) {
		return $des['output'];
	} else {
		return false;
	}
	
}

/**
 * Determina se pode acessar sub-funcao
 *
 * @param $bloco Codigo do bloco
 * @param $func Codigo da funcao
 * @returns boolean Se usuario pode acessar funcao em bloco
 */
function acessa_fnc($bloco, $func) {

  // Administrador: acesso liberado
	if ($_SESSION['nwx_adm'] || $_SESSION['nwx_adm2']) return true;
	
	$fnc = strtoupper($func);
	
	// Se tiver funcao extendida para acessos: usa-la para determinar acesso
	if (defined('NWX_EXT_FNC') && NWX_EXT_FNC) {
		if (file_exists(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_FNC . ".php")) {
			include_once(NWX_DIR . DIRECTORY_SEPARATOR . NWX_EXT_FNC . ".php");
			if (function_exists('nwx_ext_fnc')) {
				return nwx_ext_fnc($bloco, $fnc);
			}
		}
	}

	$usr = $_SESSION['nwx_usr'];
	$db = nwx_db::conexao();
	
	// Verifica se tem algum registro. Se nao, libera acesso
	$rs = $db->execute("select * from nw_acs_sub where aplic=? and bloco=?", array(NWX_SIS, $bloco));
	if (!$rs || $rs->EOF) return true;
	
	// Monta um array de usuarios/grupos a verificar
	$users = array($usr, 'PUBLIC');
	// Adiciona todos os grupos de que o usuario e membro
	if (isset($_SESSION['nwx_cache'][NWX_SIS]['mbr'])) {
		foreach($_SESSION['nwx_cache'][NWX_SIS]['mbr'] as $u) {
			$users[] = $u;
		}
	}
	 
	// Para cada usuario/grupo
	foreach ($users as $u) {
		// Verifica se tem acesso a todos as funcoes (func = *)
		$rs = $db->execute("select * from nw_acs_sub where aplic=? and bloco=? and func='*' and usr = ?", array(NWX_SIS, $bloco, $u));
		if (!$rs->EOF) return true;
		// Verifica se tem acesso explicito a funcao
		$rs = $db->execute("select * from nw_acs_sub where aplic=? and bloco=? and func=? and usr = ?", array(NWX_SIS, $bloco, $fnc, $u));
		if (!$rs->EOF) return true;
	}
	
	return false;
  
}
// vim:et:sw=2:ts=2:nowrap:
