<?php
/**
 * Elementos grafico pre-formatados
 *
 * @file nwx_widg.php
 * @author Gonalo Franco
 * @version $Id: nwx_widg.php 908 2007-01-02 12:34:05Z goncalo $
 */

/**
 * Prepara janela de tooptip
 *
 * @param $tip Texto do tooltip
 * @param $lgr Largura em pixels (default 150)
 * @return string com link para janela tooltip
 * @access public
 */
function nwx_ttip($tip, $lgr = 150) {

	$txt = htmlentities($tip);
	return "onmouseover=\" " .
				 "overlib('$txt'," .
				 "TEXTFONT,'Arial'," .
				 "TEXTSIZE,'12px'," .
				 "FGCOLOR,'#ffff99'," .
				 "DELAY,750," .
				 "WIDTH,$lgr," .
				 "HAUTO,VAUTO" .
				 ");return true;\"" .
				 "onmouseout=\"nd();\"";

} //nwx_ttip 

/**
 * Janela de ajuda sobre controle
 *
 * @param $cab Cabealho do Texto
 * @param $tip Texto de ajuda
 * @param $lgr Largura em pixels (default 320)
 * @return string com link para janela de ajuda
 * @access public
 */
function nwx_hctl($cab, $tip, $lgr = 300) {

	$tip = str_replace("\n","<br>",$tip);
	$cab = str_replace("\n","<br>",$cab);
	$tip = str_replace("\r","",$tip);
	$cab = str_replace("\r","",$cab);

	$txt = htmlentities($tip);
	$tcb = htmlentities($cab);

	return "onmouseover=\"return " .
				 "overlib('$txt'," .
				 "CAPTION,'$tcb'," .
				 "TEXTFONT,'Arial'," .
				 "TEXTSIZE,'12px'," .
				 "DELAY,600," .
				 "WIDTH,$lgr," .
				 "HAUTO,VAUTO" .
				 ");\"" .
				 "onmouseout=\"nd();\"";

} 

/**
 * Botao para fechar janela
 *
 * @param $bloco Nome do Bloco 
 * @return string com html do botao
 * @access public
 */
function bt_fechar($bloco) {

	$dom = textdomain(null);
	textdomain('nwx');
	$t1 = _('Fechar a tela');
	$t2 = _("Fechar");
	textdomain($dom);
	return "<a ".nwx_ttip($t1)."class=\"nav\" href=\"index.php?blc=$bloco&x\">$t2</a>\n";

}

/**
 * Botao para imprimir janela
 *
 * @param $relat Nome do Relatorio
 * @return string com html do botao
 * @access public
 */
function bt_imprimir($relat) {

	$dom = textdomain(null);
	textdomain('nwx');
	$t1 = _('Abrir Janela para Impresso do documento');
	textdomain($dom);
	return "<a href=\"index_ldr.php?pag=nwx_relat_prn&rel=$relat\" target=\"_blank\" " . 
				 nwx_ttip($t1) .
				 "><img src=\"/nwx/img/printer.gif\" align=\"absmiddle\" border=\"none\"></a>&nbsp;";

}

/**
 * Botao para gerar planilha
 *
 * @param $plan Nome da Planilha 
 * @return string com html do botao
 * @access public
 */
function bt_xls($plan) {

	$dom = textdomain(null);
	textdomain('nwx');
	$t1 = _('Criar planilha Excel');
	textdomain($dom);
	return "<a href=\"index_xls.php?rel=$plan\" target=\"_blank\" " . 
				 nwx_ttip($t1) .
				 "><img src=\"/nwx/img/vnd.ms-excel.gif\" align=\"absmiddle\" border=\"none\"></a>&nbsp;";

}

/**
 * Botao de comando generico
 *
 * @param $texto Texto do botao
 * @param $bloco Bloco a ativar
 * @param $param Parametros a passar
 * @param $ajuda Texto de ajuda
 * @param $col Coluna
 * @param $seq Sequencia
 * @param $sta Status
 * @param $ico Icone 
 * @return string com html do botao
 * @access public
 */
function bt_comado($texto, $bloco, $param, $ajuda, $col, $seq, $sta, $ico) {

	$par = $param ? "&$param" : "";
	return "<a ".nwx_ttip($ajuda)."class=\"nav\" href=\"index.php?blc=$bloco$par&col=$col&seq=$seq&sta=$sta&ico=$ico\">$texto</a>\n";

}


/**
 * Cabecalho e rodape de relatorios
 *
 * @param $titulo Titulo do relatorio
 * @param $header Texto do cabecalho
 * @return string com header e footer
 * @access public
 */
function print_head($titulo, $header) {

	// Monta itens do rodape
	$footer1 = $_SESSION['nwx_nom'];
	$footer2 = date('d/m/Y H:i');
	$footer3 = $_SERVER['REMOTE_ADDR'] . '&nbsp;';
	
	// Maximo de colunas
	$cols = count($header);
	
	// Imagem
	$img_prn = nwx_param('IMG_PRN');
	if ($img_prn) {
		$img = "<img src=\"/nwx/img/{$img_prn}\">";
	} else {
		$img = "<span style=\"color:#060;\">" . NWX_LICENCEE . "</span>";
	}
	
	$p = "<thead style=\"display:table-header-group;\">";
	$p .= "<tr><th colspan=\"$cols\">";
	$p .= "<div class=\"reltit\" style=\"padding:2px;\">\n";
	$p .= $img . '<br>';
	$p .= $titulo;
	$p .= "</div>\n";
	$p .= "</th></tr>";
	$p .= "<tr>";
	
	$n = 0;
	foreach ($header as $col) {
		$bw = ($n == 0) ? 'border-width:1px 1px 2px 1px;' : 'border-width:1px 1px 2px 0px;';
		$w = $col[1] ? "width=\"{$col[1]}\"" : "";
		$p .= "<th $w class=\"hdplan\" style=\"$bw\">{$col[0]}&nbsp;</th>";
		++$n;
	}
	$p .= "</tr>";
	$p .= "</thead>";

	// Footer
	$p .= "<tfoot style=\"display:table-footer-group;\">";
	$p .= "<tr><td colspan=\"$cols\"><td>&nbsp;</td></tr>";
	$p .= "<tr><td colspan=\"$cols\">";
	$p .= "<table class=\"layout\" cellspacing=\"0\">";
	$p .= "<tr>";
	$p .= "<td width=\"60%\" class=\"ftplan\" style=\"font-weight:bold;border-width:1px 0px 1px 1px;\">Impresso por</td>";
	$p .= "<td width=\"20%\" class=\"ftplan\" style=\"font-weight:bold;border-width:1px 0px 1px 1px;\">Data/Hora</td>";
	$p .= "<td width=\"20%\" class=\"ftplan\" style=\"font-weight:bold;border-width:1px 1px 1px 1px;\">Endereo</td>";
	$p .= "</tr>";
	$p .= "<tr>";
	$p .= "<td class=\"ftplan\" style=\"border-width:0px 0px 1px 1px;\">$footer1</td>";
	$p .= "<td class=\"ftplan\" style=\"border-width:0px 0px 1px 1px;\">$footer2</td>";
	$p .= "<td class=\"ftplan\" style=\"border-width:0px 1px 1px 1px;\">$footer3</td>";
	$p .= "</tr>";
	$p .= "</table>";
	$p .= "</td>";
	$p .= "</tr>";
	$p .= "</tfoot>";                    

	return $p;

}
// vim:et:sw=2:ts=2:nowrap:
